@@ -1,10 +1,9 @@
 """GnuMed allergy related business object.
-
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmAllergy.py,v $
-# $Id: gmAllergy.py,v 1.23 2006/10/28 15:02:24 ncq Exp $
-__version__ = "$Revision: 1.23 $"
+# $Id: gmAllergy.py,v 1.26 2007/03/26 16:48:34 ncq Exp $
+__version__ = "$Revision: 1.26 $"
 __author__ = "Carlos Moro <cfmoro1976@yahoo.es>"
 __license__ = "GPL"
 
@@ -13,10 +12,13 @@ import types, sys
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
 
-from Gnumed.pycommon import gmLog, gmPG2, gmExceptions, gmI18N, gmBusinessDBObject
+from Gnumed.pycommon import gmLog, gmPG2, gmI18N, gmBusinessDBObject
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
+
+
+allergic_states = [None, -1, 0, 1]
 #============================================================
 class cAllergy(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one allergy event.
@@ -30,12 +32,12 @@ class cAllergy(gmBusinessDBObject.cBusinessDBObject):
 				generics=%(generics)s,
 				allergene=%(allergene)s,
 				atc_code=%(atc_code)s,
-				id_type=%(pk_type)s,
+				fk_type=%(pk_type)s,
 				generic_specific=%(generic_specific)s::boolean,
 				definite=%(definite)s::boolean,
 				narrative=%(reaction)s
 			where
-				id=%(pk_allergy)s and
+				pk=%(pk_allergy)s and
 				xmin=%(xmin_allergy)s""",
 		u"""select xmin_allergy from clin.v_pat_allergies where pk_allergy=%(pk_allergy)s"""
 	]
@@ -51,6 +53,15 @@ class cAllergy(gmBusinessDBObject.cBusinessDBObject):
 		'definite',
 		'reaction'
 	]
+	#--------------------------------------------------------
+	def __setitem__(self, attribute, value):
+		if attribute == 'pk_type':
+			if value in ['allergy', 'sensitivity']:
+				cmd = u'select pk from clin._enum_allergy_type where value=%s'
+				rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [value]}])
+				value = rows[0][0]
+
+		gmBusinessDBObject.cBusinessDBObject.__setitem__(self, attribute, value)
 #============================================================
 # convenience functions
 #------------------------------------------------------------
@@ -68,38 +79,55 @@ def create_allergy(substance=None, allg_type=None, episode_id=None, encounter_id
 	cmd = u"""
 		select pk_patient from clin.v_pat_episodes where pk_episode=%s
 			union
-		select pk_patient from clin.v_pat_encounters where pk_encounter=%s"""
+		select fk_patient from clin.encounter where pk=%s"""
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [episode_id, encounter_id]}])
+
 	if len(rows) == 0:
-		_log.Log(gmLog.lErr, 'error checking episode [%s] <-> encounter [%s] consistency' % (episode_id, encounter_id))
-		return (None, _('internal error, check log'))
+		raise ValueError('error checking episode [%s] <-> encounter [%s] consistency' % (episode_id, encounter_id))
+
 	if len(rows) > 1:
-		_log.Log(gmLog.lErr, 'episode [%s] and encounter [%s] belong to more than one patient !?!' % (episode_id, encounter_id))
-		return (None, _('consistency error, check log'))
+		raise ValueError('episode [%s] and encounter [%s] belong to different patients !?!' % (episode_id, encounter_id))
+
 	pat_id = rows[0][0]
+
+	cmd = u'select pk_allergy from clin.v_pat_allergies where pk_patient=%(pat)s and substance=%(substance)s'
+	args = {'pat': pat_id, 'substance': substance}
+	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
+	if len(rows) > 0:
+		# don't implicitely change existing data
+		return cAllergy(aPK_obj = rows[0][0])
+
 	# insert new allergy
 	queries = []
+
 	if type(allg_type) == types.IntType:
 		cmd = u"""
-			insert into clin.allergy (id_type, fk_encounter, fk_episode, substance)
+			insert into clin.allergy (fk_type, fk_encounter, fk_episode, substance)
 			values (%s, %s, %s, %s)"""
 	else:
 		cmd = u"""
-			insert into clin.allergy (id_type, fk_encounter, fk_episode,  substance)
-			values ((select id from clin._enum_allergy_type where value=%s), %s, %s, %s)"""
-		allg_type = str(allg_type)
+			insert into clin.allergy (fk_type, fk_encounter, fk_episode,  substance)
+			values ((select pk from clin._enum_allergy_type where value = %s), %s, %s, %s)"""
 	queries.append({'cmd': cmd, 'args': [allg_type, encounter_id, episode_id, substance]})
-	# set patient has_allergy status
-	cmd = u"delete from clin.allergy_state where fk_patient=%s"
-	queries.append({'cmd': cmd, 'args': [pat_id]})
-	cmd = u"insert into clin.allergy_state (fk_patient, has_allergy) values (%s, 1)"
-	queries.append({'cmd': cmd, 'args': [pat_id]})
-	# get PK of inserted row
+
 	cmd = u"select currval('clin.allergy_id_seq')"
 	queries.append({'cmd': cmd})
+
 	rows, idx = gmPG2.run_rw_queries(queries=queries, return_data=True)
 	allergy = cAllergy(aPK_obj = rows[0][0])
-	return (True, allergy)
+
+	return allergy
+#============================================================
+def allergic_state2str(state=None):
+	if state is None:
+		return _('unknown allergic state')
+	if state == -1:
+		return _('undisclosed allergic state')
+	if state == 0:
+		return _('no known allergies')
+	if state == 1:
+		return _('does have allergies')
+
 #============================================================
 # main - unit testing
 #------------------------------------------------------------
@@ -128,6 +156,19 @@ if __name__ == '__main__':
 	print allg
 #============================================================
 # $Log: gmAllergy.py,v $
+# Revision 1.26  2007/03/26 16:48:34  ncq
+# - various id -> pk/fk type fixes
+#
+# Revision 1.25  2007/03/21 08:09:07  ncq
+# - add allergic_states
+# - add allergic_state2str()
+#
+# Revision 1.24  2007/03/18 12:54:39  ncq
+# - allow string and integer for setting pk_type on allergy
+#
+# Revision 1.24  2007/03/12 12:23:23  ncq
+# - error handling now more exception centric
+#
 # Revision 1.23  2006/10/28 15:02:24  ncq
 # - remove superfluous xmin_allergy
 #
