@@ -9,8 +9,8 @@ called for the first time).
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmClinicalRecord.py,v $
-# $Id: gmClinicalRecord.py,v 1.228 2007/01/09 18:01:12 ncq Exp $
-__version__ = "$Revision: 1.228 $"
+# $Id: gmClinicalRecord.py,v 1.243 2007/04/25 21:59:15 ncq Exp $
+__version__ = "$Revision: 1.243 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -28,12 +28,16 @@ __license__ = "GPL"
 #===================================================
 
 # standard libs
-import sys, string, time, copy
+import sys, string, time, copy, locale
+
 
 # 3rd party
-import mx.DateTime as mxDT
+import mx.DateTime as mxDT, psycopg2
 
-from Gnumed.pycommon import gmLog, gmExceptions, gmPG2, gmSignals, gmDispatcher, gmI18N, gmCfg
+
+if __name__ == '__main__':
+	sys.path.insert(0, '../../')
+from Gnumed.pycommon import gmLog, gmExceptions, gmPG2, gmSignals, gmDispatcher, gmI18N, gmCfg, gmTools
 from Gnumed.business import gmAllergy, gmEMRStructItems, gmClinNarrative
 
 _log = gmLog.gmDefLog
@@ -43,10 +47,8 @@ _me = None
 
 _func_ask_user = None
 #============================================================
-class cClinicalRecord:
+class cClinicalRecord(object):
 
-	# handlers for __getitem__()
-	_get_handler = {}
 	_clin_root_item_children_union_query = None
 
 	def __init__(self, aPKey = None):
@@ -83,10 +85,13 @@ select fk_encounter from
 		}
 
 		# load current or create new encounter
-		# FIXME: this should be configurable (for explanation see the method source)
+		self.remove_empty_encounters()
+		self.__encounter = None
 		if not self.__initiate_active_encounter():
 			raise gmExceptions.ConstructorError, "cannot activate an encounter for patient [%s]" % aPKey
 
+		self.ensure_has_allergic_state()
+
 		# register backend notification interests
 		# (keep this last so we won't hang on threads when
 		#  failing this constructor for other reasons ...)
@@ -113,8 +118,6 @@ select fk_encounter from
 #		sig = "%s:%s" % (gmSignals.allg_mod_db(), self.pk_patient)
 #		self._conn_pool.Unlisten(service = 'historica', signal = sig, callback = self._db_callback_allg_modified)
 
-		self.remove_empty_encounters()
-
 		return True
 	#--------------------------------------------------------
 	# messaging
@@ -184,7 +187,7 @@ select fk_encounter from
 	#--------------------------------------------------------
 	# Narrative API
 	#--------------------------------------------------------
-	def add_clin_narrative(self, note = '', soap_cat='s', episode=None):
+	def add_clin_narrative(self, note='', soap_cat='s', episode=None):
 		if note.strip() == '':
 			_log.Log(gmLog.lInfo, 'will not create empty clinical note')
 			return None
@@ -267,17 +270,6 @@ where
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient, search_term]}])
 		return rows
 	#--------------------------------------------------------
-	# __getitem__ handling
-	#--------------------------------------------------------
-	def __getitem__(self, aVar = None):
-		"""Return any attribute if known how to retrieve it.
-		"""
-		try:
-			return cClinicalRecord._get_handler[aVar](self)
-		except KeyError:
-			_log.LogException('Missing get handler for [%s]' % aVar, sys.exc_info())
-			return None
-	#--------------------------------------------------------
 	def get_text_dump_old(self):
 		# don't know how to invalidate this by means of
 		# a notify without catching notifies from *all*
@@ -593,7 +585,7 @@ where
 	#--------------------------------------------------------
 	# allergy API
 	#--------------------------------------------------------
- 	def get_allergies(self, remove_sensitivities=None, since=None, until=None, encounters=None, episodes=None, issues=None, ID_list=None):
+ 	def get_allergies(self, remove_sensitivities=False, since=None, until=None, encounters=None, episodes=None, issues=None, ID_list=None):
 		"""Retrieves patient allergy items.
 
 			remove_sensitivities
@@ -609,20 +601,16 @@ where
 			issues
 				- list of health issues whose allergies are to be retrieved
         """
-		try:
-			self.__db_cache['allergies']
-		except KeyError:
-			# FIXME: check allergy_state first, then cross-check with select exists(... from allergy)
-			cmd = u"select * from clin.v_pat_allergies where pk_patient=%s"
-			rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient]}], get_col_idx=True)
-			# Instantiate allergy items and keep cache
-			self.__db_cache['allergies'] = []
-			for r in rows:
-				self.__db_cache['allergies'].append(gmAllergy.cAllergy(row = {'data': r, 'idx': idx, 'pk_field': 'pk_allergy'}))
+		cmd = u"select * from clin.v_pat_allergies where pk_patient=%s order by descriptor"
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient]}], get_col_idx=True)
+		allergies = []
+		for r in rows:
+			allergies.append(gmAllergy.cAllergy(row = {'data': r, 'idx': idx, 'pk_field': 'pk_allergy'}))
 
 		# ok, let's constrain our list
 		filtered_allergies = []
-		filtered_allergies.extend(self.__db_cache['allergies'])
+		filtered_allergies.extend(allergies)
+
 		if ID_list is not None:
 			filtered_allergies = filter(lambda allg: allg['pk_allergy'] in ID_list, filtered_allergies)
 			if len(filtered_allergies) == 0:
@@ -631,7 +619,8 @@ where
 				return None
 			else:
 				return filtered_allergies
-		if remove_sensitivities is not None:
+
+		if remove_sensitivities:
 			filtered_allergies = filter(lambda allg: allg['type'] == 'allergy', filtered_allergies)
 		if since is not None:
 			filtered_allergies = filter(lambda allg: allg['date'] >= since, filtered_allergies)
@@ -649,19 +638,54 @@ where
 	def add_allergy(self, substance=None, allg_type=None, encounter_id=None, episode_id=None):
 		if encounter_id is None:
 			encounter_id = self.__encounter['pk_encounter']
-		status, data = gmAllergy.create_allergy(
-			substance=substance,
-			allg_type=allg_type,
-			encounter_id=encounter_id,
-			episode_id=episode_id
+
+		if episode_id is None:
+			issue = self.add_health_issue(issue_name = _('allergies/intolerances'))
+			epi = self.add_episode(episode_name = substance, pk_health_issue = issue['pk'])
+			episode_id = epi['pk_episode']
+
+		new_allergy = gmAllergy.create_allergy (
+			substance = substance,
+			allg_type = allg_type,
+			encounter_id = encounter_id,
+			episode_id = episode_id
 		)
-		if not status:
-			_log.Log(gmLog.lErr, str(data))
-			return None
-		return data
+
+		gmDispatcher.send(signal = gmSignals.allergy_updated())
+
+		return new_allergy
 	#--------------------------------------------------------
-	def set_allergic_state(self, status=None):
-		pass
+	def delete_allergy(self, pk_allergy=None):
+		cmd = u'delete from clin.allergy where pk=%(pk_allg)s'
+		args = {'pk_allg': pk_allergy}
+		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
+		gmDispatcher.send(signal = gmSignals.allergy_updated())
+	#--------------------------------------------------------
+	def ensure_has_allergic_state(self):
+		cmd = u'insert into clin.allergy_state (fk_patient, has_allergy) values (%(pat)s, %(state)s)'
+		args = {'pat': self.pk_patient, 'state': None}
+		try:
+			gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
+		except psycopg2.IntegrityError:
+			pass		# ignore, row seems to exist already
+		return True
+	#--------------------------------------------------------
+	def _set_allergic_state(self, state):
+		if state not in gmAllergy.allergic_states:
+			raise ValueError('[%s].__set_allergic_state(): <state> must be one of %s' % (self.__class__.__name__, gmAllergy.allergic_states))
+		cmd = u'update clin.allergy_state set has_allergy = %(state)s where fk_patient = %(pat)s'
+		args = {'pat': self.pk_patient, 'state': state}
+		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
+		gmDispatcher.send(signal = gmSignals.allergy_updated())
+		return True
+
+	def _get_allergic_state(self):
+		cmd = u'select has_allergy from clin.allergy_state where fk_patient = %(pat)s'
+		args = {'pat': self.pk_patient}
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
+		return rows[0][0]
+
+	allergic_state = property(_get_allergic_state, _set_allergic_state)
 	#--------------------------------------------------------
 	# episodes API
 	#--------------------------------------------------------
@@ -698,12 +722,11 @@ where
 		cmd = u"""select distinct pk_episode
 					from clin.v_pat_items
 					where pk_encounter=%(enc)s and pk_patient=%(pat)s"""
-		rows, idx = gmPG2.run_ro_queries (
-			queries = [{
-				'cmd': cmd,
-				'args': {'enc': self.__encounter['pk_encounter'], 'pat': self.pk_patient}
-			}]
-		)
+		args = {
+			'enc': gmTools.coalesce(pk_encounter, self.__encounter['pk_encounter']),
+			'pat': self.pk_patient
+		}
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
 		if len(rows) == 0:
 			return []
 		epis = []
@@ -876,11 +899,6 @@ where
 	#------------------------------------------------------------------
 	def add_health_issue(self, issue_name=None):
 		"""Adds patient health issue."""
-		# FIXME: use constraints to get*
-		issues = self.get_health_issues()
-		for issue in issues:
-			if issue['description'] == issue_name:
-				return False
 		success, issue = gmEMRStructItems.create_health_issue(patient_id=self.pk_patient, description=issue_name)
 		if not success:
 			_log.Log(gmLog.lErr, 'cannot create health issue [%s] for patient [%s]' % (issue_name, self.pk_patient))
@@ -1147,13 +1165,7 @@ where
 		# 2) "fairly recent" encounter recorded ?
 		if self.__activate_fairly_recent_encounter():
 			return True
-		# 3) no encounter yet or too old, create new one
-		successful, enc = gmEMRStructItems.create_encounter(fk_patient = self.pk_patient)
-		if not successful:
-			return False
-		self.__encounter = enc
-		_log.Log(gmLog.lData, 'new encounter [%s] initiated' % enc['pk_encounter'])
-		_log.Log(gmLog.lData, str(enc))
+		self.start_new_encounter()
 		return True
 	#------------------------------------------------------------------
 	def __activate_very_recent_encounter(self):
@@ -1166,7 +1178,7 @@ where
 		cfg_db = gmCfg.cCfgSQL()
 		min_ttl = cfg_db.get2 (
 			option = u'encounter.minimum_ttl',
-			workplace = _me.get_workplace(),
+			workplace = _me.workplace,
 			bias = u'user',
 			default = u'1 hour 30 minutes'
 		)
@@ -1174,12 +1186,13 @@ where
 			select pk_encounter
 			from clin.v_most_recent_encounters
 			where
-				pk_patient=%s
+				pk_patient = %s
 					and
 				last_affirmed > (now() - %s::interval)"""
 		enc_rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient, min_ttl]}])
 		# none found
 		if len(enc_rows) == 0:
+			_log.Log(gmLog.lData, 'no <very recent> encounter (younger than [%s]) found' % min_ttl)
 			return False
 		# attach to existing
 		self.__encounter = gmEMRStructItems.cEncounter(aPK_obj=enc_rows[0][0])
@@ -1194,19 +1207,16 @@ where
 			False: no "fairly recent" encounter, create new one
 	    	True: success
 		"""
-		# if we find one will we even be able to ask the user ?
-		if _func_ask_user is None:
-			return False
 		cfg_db = gmCfg.cCfgSQL()
 		min_ttl = cfg_db.get2 (
 			option = u'encounter.minimum_ttl',
-			workplace = _me.get_workplace(),
+			workplace = _me.workplace,
 			bias = u'user',
 			default = u'1 hour 30 minutes'
 		)
 		max_ttl = cfg_db.get2 (
 			option = u'encounter.maximum_ttl',
-			workplace = _me.get_workplace(),
+			workplace = _me.workplace,
 			bias = u'user',
 			default = u'6 hours'
 		)
@@ -1217,50 +1227,58 @@ where
 				pk_patient=%s
 					and
 				last_affirmed between (now() - %s::interval) and (now() - %s::interval)"""
-		enc_rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient, min_ttl, max_ttl]}])
+		enc_rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient, max_ttl, min_ttl]}])
 		# none found
 		if len(enc_rows) == 0:
+			_log.Log(gmLog.lData, 'no <fairly recent> encounter (between [%s] and [%s] old) found' % (min_ttl, max_ttl))
 			return False
 		encounter = gmEMRStructItems.cEncounter(aPK_obj=enc_rows[0][0])
 		# ask user whether to attach or not
 		cmd = u"""
 			select title, firstnames, lastnames, gender, dob
-			from clin.v_basic_person where pk_identity=%s"""
+			from dem.v_basic_person where pk_identity=%s"""
 		pats, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient]}])
-		if len(pats) == 0:
-			return False
-		pat_str = '%s %s %s (%s), %s, #%s' % (
-			pat[0][0][:5],
-			pat[0][1][:12],
-			pat[0][2][:12],
-			pat[0][3],
-			pat[0][4].strftime('%Y-%m-%d'),
+		pat = pats[0]
+		pat_str = u'%s %s %s (%s), %s, #%s' % (
+			gmTools.coalesce(pat[0], u'')[:5],
+			pat[1][:15],
+			pat[2][:15],
+			pat[3],
+			pat[4].strftime('%Y-%m-%d'),
 			self.pk_patient
 		)
+		enc = gmI18N.get_encoding()
 		msg = _(
-			'A fairly recent encounter exists for patient:\n'
+			'Very recently (between "%s" and "%s" ago)\n'
+			'a consultation has been recorded for the patient:\n'
+			'\n'
 			' %s\n'
-			'started  : %s\n'
-			'type     : %s\n'
-			'RFE      : %s\n'
-			'affirmed : %s\n'
-			'AOE      : %s\n\n'
-			'Do you want to reactivate this encounter ?\n'
-			'Hitting "No" will start a new one.'
+			'\n'
+			'with the following details:\n'
+			'\n'
+			' date: %s\n'
+			' time: %s - %s\n'
+			' type: %s\n'
+			' request: %s\n'
+			' outcome: %s\n'
+			'\n'
+			'Do you want to continue this consultation\n'
+			'or do you want to start a new one ?\n'
 		) % (
+			max_ttl,
+			min_ttl,
 			pat_str,
-			encounter['started'],
+			encounter['started'].strftime('%x').decode(enc),
+			encounter['started'].strftime('%H:%M'), encounter['last_affirmed'].strftime('%H:%M'),
 			encounter['l10n_type'],
-			encounter['reason_for_encounter'],
-			encounter['last_affirmed'],
-			encounter['assessment_of_encounter']
+			gmTools.coalesce(encounter['reason_for_encounter'], _('none given')),
+			gmTools.coalesce(encounter['assessment_of_encounter'], _('none given')),
 		)
-		title = _('recording patient encounter')
 		attach = False
 		try:
-			attach = _func_ask_user(msg, title)
+			attach = _func_ask_user(msg = msg, caption = _('starting patient encounter'))
 		except:
-			_log.LogException('cannot ask user for guidance', sys.exc_info(), verbose=0)
+			_log.LogException('cannot ask user for guidance')
 			return False
 		if not attach:
 			return False
@@ -1270,6 +1288,11 @@ where
 		_log.Log(gmLog.lData, '"fairly recent" encounter [%s] found and re-activated' % enc_rows[0][0])
 		return True
 	#------------------------------------------------------------------
+	def start_new_encounter(self):
+		self.__encounter = gmEMRStructItems.create_encounter(fk_patient = self.pk_patient)
+		self.__encounter.set_active(staff_id = _me['pk_staff'])
+		_log.Log(gmLog.lData, 'new encounter [%s] initiated' % self.__encounter['pk_encounter'])
+	#------------------------------------------------------------------
 	def get_active_encounter(self):
 		return self.__encounter
 	#------------------------------------------------------------------
@@ -1399,7 +1422,6 @@ where
 	def remove_empty_encounters(self):
 		# remove empty encounters
 		# FIXME: this should be done async
-		# FIXME: au.referral is missing
 		cmd = u"""
 delete from clin.encounter where 
 	fk_patient = %(pat)s and
@@ -1498,6 +1520,20 @@ def set_func_ask_user(a_func = None):
 # main
 #------------------------------------------------------------
 if __name__ == "__main__":
+
+	gmI18N.activate_locale()
+	gmI18N.install_domain()
+
+	def test_allergic_state():
+		emr = cClinicalRecord(aPKey=1)
+		state = emr.allergic_state
+		print "allergic state is:", state
+		print "setting state to -1"
+		emr.allergic_state = 'abc'
+
+	test_allergic_state()
+	sys.exit(1)
+
 	import traceback
 	gmLog.gmDefLog.SetAllLogLevels(gmLog.lData)
 	try:
@@ -1588,6 +1624,61 @@ if __name__ == "__main__":
 		_log.LogException('unhandled exception', sys.exc_info(), verbose=1)
 #============================================================
 # $Log: gmClinicalRecord.py,v $
+# Revision 1.243  2007/04/25 21:59:15  ncq
+# - improve message on very-recent-encounter
+#
+# Revision 1.242  2007/04/06 23:12:58  ncq
+# - move remove_empty_encounters() from cleanup() to init()
+#
+# Revision 1.241  2007/04/02 18:32:51  ncq
+# - start_new_encounter()
+#
+# Revision 1.240  2007/04/01 15:25:25  ncq
+# - safely get encoding
+#
+# Revision 1.239  2007/03/31 21:18:13  ncq
+# - fix get_episodes_by_encounter()
+#
+# Revision 1.238  2007/03/26 16:49:26  ncq
+# - settle on health issue/episode naming for newly added allergies
+#
+# Revision 1.237  2007/03/23 15:01:14  ncq
+# - cleanup get_allergies() API
+#
+# Revision 1.236  2007/03/21 08:12:14  ncq
+# - allergic_state property
+# - send allergy_modified() signal
+# - make cClinicalRecord a new-style class
+#
+# Revision 1.235  2007/03/18 13:01:16  ncq
+# - re-add lost 1.235
+# - add ensure_has_allergic_state()
+# - remove allergies cache
+# - add delete_allergy()
+#
+# Revision 1.235  2007/03/12 12:23:54  ncq
+# - create_allergy() now throws exceptions so deal with that
+#
+# Revision 1.234  2007/03/02 15:29:33  ncq
+# - need to decode() strftime() output to u''
+#
+# Revision 1.233  2007/02/19 14:06:56  ncq
+# - add_health_issue() should return True if health_issue already exists
+#
+# Revision 1.232  2007/02/17 14:08:52  ncq
+# - gmPerson.gmCurrentProvider.workplace now a property
+#
+# Revision 1.231  2007/02/09 14:58:43  ncq
+# - honor <pk_encounter> in get_episodes_by_encounter
+#   instead of always assuming the current encounter
+#
+# Revision 1.230  2007/01/31 23:30:33  ncq
+# - fix __activate_fairly_recent_encounter()
+#
+# Revision 1.229  2007/01/29 11:58:53  ncq
+# - cleanup
+# - let _ask_user_func fail so programmers knows early
+#
 # Revision 1.228  2007/01/09 18:01:12  ncq
 # - error policy is now exceptions
 #
