@@ -3,7 +3,7 @@
 license: GPL
 """
 #============================================================
-__version__ = "$Revision: 1.94 $"
+__version__ = "$Revision: 1.99 $"
 __author__ = "Carlos Moro <cfmoro1976@yahoo.es>"
 
 import types, sys, string, datetime
@@ -143,13 +143,18 @@ class cEpisode(gmBusinessDBObject.cBusinessDBObject):
 		'pk_patient'
 	]
 	#--------------------------------------------------------
-	def __init__(self, aPK_obj=None, id_patient=None, name='xxxDEFAULTxxx', row=None):
+	def __init__(self, aPK_obj=None, id_patient=None, name='xxxDEFAULTxxx', health_issue=None, row=None):
 		pk = aPK_obj
 		if pk is None and row is None:
-			cmd = u"select * from clin.v_pat_episodes where pk_patient=%s and description=%s"
-			rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [id_patient, name]}], get_col_idx=True)
+			cmd = u"select * from clin.v_pat_episodes where pk_patient=%s and description=%s and pk_health_issue=%s"
+			rows, idx = gmPG2.run_ro_queries(queries = [{
+					'cmd': cmd,
+					'args': [id_patient, name, health_issue]
+				}],
+				get_col_idx=True
+			)
 			if len(rows) == 0:
-				raise gmExceptions.NoSuchBusinessObjectError, 'no episode for [%s:%s]' % (id_patient, name)
+				raise gmExceptions.NoSuchBusinessObjectError, 'no episode for [%s:%s:%s]' % (id_patient, name, health_issue)
 			r = {'idx': idx, 'data': rows[0], 'pk_field': 'pk_episode'}
 			gmBusinessDBObject.cBusinessDBObject.__init__(self, row=r)
 		else:
@@ -198,9 +203,6 @@ from (
 	def get_patient(self):
 		return self._payload[self._idx['pk_patient']]
 	#--------------------------------------------------------
-	def get_description(self):
-		return self._payload[self._idx['description']]
-	#--------------------------------------------------------
 	def rename(self, description=None):
 		"""Method for episode editing, that is, episode renaming.
 
@@ -276,21 +278,27 @@ class cEncounter(gmBusinessDBObject.cBusinessDBObject):
 		@param target_episode The episode the elements will be relinked to.
 		@type target_episode A cEpisode intance.
 		"""
-		# sanity check
 		if source_episode['pk_episode'] == target_episode['pk_episode']:
-			return (True, True)
+			return True
+
 		queries = []
 		cmd = u"""
 			UPDATE clin.clin_root_item
-			SET fk_episode = %s
+			SET fk_episode = %(trg)s
  			WHERE
-				fk_encounter = %s AND
-				fk_episode = %s
+				fk_encounter = %(enc)s AND
+				fk_episode = %(src)s
 			"""
-		# run queries
-		rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': [target_episode['pk_episode'], self.pk_obj, source_episode['pk_episode']]}])
+		rows, idx = gmPG2.run_rw_queries(queries = [{
+			'cmd': cmd,
+			'args': {
+				'trg': target_episode['pk_episode'],
+				'enc': self.pk_obj,
+				'src': source_episode['pk_episode']
+			}
+		}])
 		self.refetch_payload()
-		return (True, True)
+		return True
 	#--------------------------------------------------------
 	def has_clinical_data(self):
 		cmd = u"""
@@ -368,21 +376,22 @@ def create_health_issue(patient_id=None, description=None):
 	patient_id - given patient PK
 	description - health issue name
 	"""
-	# already there ?
 	try:
 		h_issue = cHealthIssue(patient_id=patient_id, name=description)
 		return (True, h_issue)
 	except gmExceptions.ConstructorError:
-		_log.Log(gmLog.lData, 'health issue does not yet exist')
-	# insert new health issue
+		pass
+
 	queries = []
 	cmd = u"insert into clin.health_issue (fk_patient, description) values (%s, %s)"
 	queries.append({'cmd': cmd, 'args': [patient_id, description]})
-	# get PK of inserted row
+
 	cmd = u"select currval('clin.health_issue_pk_seq')"
 	queries.append({'cmd': cmd})
+
 	rows, idx = gmPG2.run_rw_queries(queries=queries, return_data=True)
 	h_issue = cHealthIssue(aPK_obj = rows[0][0])
+
 	return (True, h_issue)
 #-----------------------------------------------------------
 def create_episode(pk_health_issue=None, episode_name=None, patient_id=None, is_open=False):
@@ -392,7 +401,7 @@ def create_episode(pk_health_issue=None, episode_name=None, patient_id=None, is_
 	episode_name - name of episode
 	"""
 	try:
-		episode = cEpisode(id_patient=patient_id, name=episode_name)
+		episode = cEpisode(id_patient=patient_id, name=episode_name, health_issue=pk_health_issue)
 		if episode['episode_open'] != is_open:
 			episode['episode_open'] = is_open
 			episode.save_payload()
@@ -409,6 +418,19 @@ def create_episode(pk_health_issue=None, episode_name=None, patient_id=None, is_
 	episode = cEpisode(row={'data': rows[0], 'idx': idx, 'pk_field': 'pk_episode'})
 	return episode
 #-----------------------------------------------------------
+def delete_episode(episode=None):
+	if isinstance(episode, cEpisode):
+		pk = episode['pk_episode']
+	else:
+		pk = int(episode)
+
+	try:
+		gmPG2.run_rw_queries(queries = [{'cmd': u'delete from clin.episode where pk=%(pk)s', 'args': {'pk': pk}}])
+	except gmPG2.dbapi.IntegrityError:
+		# should be parsing pgcode/and or error message
+		_log.LogException('cannot delete episode')
+		raise gmExceptions.DatabaseObjectInUseError('cannot delete episode, it is in use')
+#-----------------------------------------------------------
 def create_encounter(fk_patient=None, fk_location=-1, enc_type=None):
 	"""Creates a new encounter for a patient.
 
@@ -443,7 +465,7 @@ def create_encounter(fk_patient=None, fk_location=-1, enc_type=None):
 	queries.append({'cmd': cEncounter._cmd_fetch_payload % u"currval('clin.encounter_pk_seq')"})
 	rows, idx = gmPG2.run_rw_queries(queries=queries, return_data=True, get_col_idx=True)
 	encounter = cEncounter(row={'data': rows[0], 'idx': idx, 'pk_field': 'pk_encounter'})
-	return (True, encounter)
+	return encounter
 #-----------------------------------------------------------
 def get_encounter_types():
 	cmd = u"SELECT _(description) from clin.encounter_type"
@@ -504,7 +526,7 @@ if __name__ == '__main__':
 		print "updatable:", episode.get_updatable_fields()
 		raw_input('ENTER to continue')
 
-		old_description = episode.get_description()
+		old_description = episode['description']
 		old_enc = cEncounter(aPK_obj = 1)
 
 		desc = '1-%s' % episode['description']
@@ -543,6 +565,22 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmEMRStructItems.py,v $
+# Revision 1.99  2007/05/18 13:25:56  ncq
+# - fix cEncounter.transfer_clinical_data()
+#
+# Revision 1.98  2007/05/14 10:32:50  ncq
+# - raise DatabaseObjectInUseError on psycopg2 integrity error
+#
+# Revision 1.97  2007/04/27 22:54:13  ncq
+# - when checking for existing episodes need to check
+#   associated health issue, too, of course
+#
+# Revision 1.96  2007/04/02 18:35:20  ncq
+# - create_encounter now more exception-y
+#
+# Revision 1.95  2007/03/18 13:01:55  ncq
+# - a bit of cleanup
+#
 # Revision 1.94  2007/01/09 18:01:32  ncq
 # - let exceptions report errors
 #
