@@ -4,8 +4,8 @@
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmMedDoc.py,v $
-# $Id: gmMedDoc.py,v 1.89 2007/01/10 22:27:53 ncq Exp $
-__version__ = "$Revision: 1.89 $"
+# $Id: gmMedDoc.py,v 1.94 2007/05/20 01:27:31 ncq Exp $
+__version__ = "$Revision: 1.94 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
 import sys, tempfile, os, shutil, os.path, types, time
@@ -142,7 +142,8 @@ class cMedDocPart(gmBusinessDBObject.cBusinessDBObject):
 		u"""update blobs.doc_obj set
 				seq_idx=%(seq_idx)s,
 				comment=%(obj_comment)s,
-				fk_intended_reviewer=%(pk_intended_reviewer)s
+				fk_intended_reviewer=%(pk_intended_reviewer)s,
+				filename=%(filename)s
 			where
 				pk=%(pk_obj)s and
 				xmin=%(xmin_doc_obj)s""",
@@ -151,7 +152,8 @@ class cMedDocPart(gmBusinessDBObject.cBusinessDBObject):
 	_updatable_fields = [
 		'seq_idx',
 		'obj_comment',
-		'pk_intended_reviewer'
+		'pk_intended_reviewer',
+		'filename'
 	]
 	#--------------------------------------------------------
 	def __del__(self):
@@ -374,6 +376,20 @@ where
 		rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
 
 		return True
+	#--------------------------------------------------------
+	def set_as_active_photograph(self):
+		if self._payload[self._idx['type']] != u'patient photograph':
+			return False
+		# set seq_idx to current max + 1
+		rows, idx = gmPG2.run_ro_queries (
+			queries = [{
+				'cmd': u'select coalesce(max(seq_idx)+1, 1) from blobs.doc_obj where fk_doc=%(doc_id)s',
+				'args': {'doc_id': self._payload[self._idx['pk_doc']]}
+			}]
+		)
+		self._payload[self._idx['seq_idx']] = rows[0][0]
+		self._is_modified = True
+		self.save_payload()
 #============================================================
 class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one medical document."""
@@ -478,10 +494,9 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 				return (False, msg, filename)
 			new_parts.append(new_part)
 
-			if reviewer is None:
-				continue
+			new_part['filename'] = filename
+			new_part['pk_intended_reviewer'] = reviewer			# None == Null
 
-			new_part['pk_intended_reviewer'] = reviewer
 			success, data = new_part.save_payload()
 			if not success:
 				msg = 'cannot set reviewer to [%s]' % reviewer
@@ -495,8 +510,10 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 		fnames = []
 		for part in self.get_parts():
 			# FIXME: add guess_extension_from_mimetype
-			# FIXME: use original_filename from archive
-			fname = u'%s%s%s_%s' % (part['l10n_type'], gmTools.coalesce(part['ext_ref'], '-', '-%s-'), _('part'), part['seq_idx'])
+			fname = os.path.basename(gmTools.coalesce (
+				part['filename'],
+				u'%s%s%s_%s' % (part['l10n_type'], gmTools.coalesce(part['ext_ref'], '-', '-%s-'), _('part'), part['seq_idx'])
+			))
 			if export_dir is not None:
 				fname = os.path.join(export_dir, fname)
 			fnames.append(part.export_to_file(aChunkSize = chunksize, filename = fname))
@@ -548,8 +565,11 @@ class cDocumentType(gmBusinessDBObject.cBusinessDBObject):
 		rows, idx = gmPG2.run_rw_queries (
 			queries = [
 				{'cmd': u'select i18n.i18n(%s)', 'args': [self._payload[self._idx['type']]]},
-				{'cmd': u'select i18n.upd_tx(%s, %s, (select lang from i18n.curr_lang where user = CURRENT_USER))',
-				 'args': [self._payload[self._idx['type']], translation]
+				{'cmd': u'select i18n.upd_tx((select lang from i18n.curr_lang where user = CURRENT_USER), %(orig)s, %(tx)s)',
+				 'args': {
+				 	'orig': self._payload[self._idx['type']],
+					'tx': translation
+					}
 				}
 			],
 			return_data = True
@@ -585,8 +605,7 @@ def search_for_document(patient_id=None, type_id=None):
 	"""
 	# sanity checks
 	if patient_id is None:
-		_log.Log(gmLog.lErr, 'need patient id to create document')
-		return None
+		raise ValueError('need patient id to create document')
 
 	args = {'pat_id': patient_id, 'type_id': type_id}
 	if type_id is None:
@@ -726,6 +745,21 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmMedDoc.py,v $
+# Revision 1.94  2007/05/20 01:27:31  ncq
+# - fix set_translation() - lang needs to go first in i18n.upd_tx()
+#
+# Revision 1.93  2007/04/23 01:02:05  ncq
+# - add set_as_active_photograph()
+#
+# Revision 1.92  2007/04/11 14:51:06  ncq
+# - raising exception on error
+#
+# Revision 1.91  2007/03/31 21:18:40  ncq
+# - apply basename to original filename on save
+#
+# Revision 1.90  2007/03/08 16:17:47  ncq
+# - support blobs.doc_obj.filename
+#
 # Revision 1.89  2007/01/10 22:27:53  ncq
 # - return a list of filenames from export_parts_to_files()
 #
