@@ -2,8 +2,8 @@
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmVaccination.py,v $
-# $Id: gmVaccination.py,v 1.33 2006/11/24 14:15:36 ncq Exp $
-__version__ = "$Revision: 1.33 $"
+# $Id: gmVaccination.py,v 1.35 2007/03/08 11:31:08 ncq Exp $
+__version__ = "$Revision: 1.35 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -370,7 +370,7 @@ def put_patient_on_schedule(patient_id=None, course=None):
 		* patient_id = Patient's PK
 		* course = course object or Vaccination course's PK
 	"""
-	# FIXME: add method schedule_vaccination_course() to gmPerson.cPerson
+	# FIXME: add method schedule_vaccination_course() to gmPerson.cPatient
 	if isinstance(course, cVaccinationCourse):
 		course_id = course['pk_course']
 	else:
@@ -392,7 +392,7 @@ def remove_patient_from_schedule(patient_id=None, course=None):
 		* patient_id = Patient's PK
 		* course = course object or Vaccination course's PK
 	"""
-	# FIXME: add method schedule_vaccination_course() to gmPerson.cPerson
+	# FIXME: add method schedule_vaccination_course() to gmPerson.cPatient
 	if isinstance(course, cVaccinationCourse):
 		course_id = course['pk_course']
 	else:
@@ -535,7 +535,6 @@ if __name__ == '__main__':
 		print '\nPutting patient id 12 on schedule id 1... %s (%s)' % (result, msg)
 	#--------------------------------------------------------
 
-	gmPG.set_default_client_encoding('latin1')
 	test_vaccination_course()
 	#test_put_patient_on_schedule()
 	test_scheduled_vacc()
@@ -544,6 +543,12 @@ if __name__ == '__main__':
 #	test_due_booster()
 #============================================================
 # $Log: gmVaccination.py,v $
+# Revision 1.35  2007/03/08 11:31:08  ncq
+# - just cleanup
+#
+# Revision 1.34  2007/02/22 17:27:44  ncq
+# - no more cPerson
+#
 # Revision 1.33  2006/11/24 14:15:36  ncq
 # - u'' one query
 #
