@@ -1,12 +1,12 @@
-# -*- encoding: latin-1 -*-
+# -*- encoding: utf8 -*-
 """GnuMed German XDT mapping data.
 
 This maps XDT fields in various ways.
 """
 #==============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmXdtMappings.py,v $
-# $Id: gmXdtMappings.py,v 1.37 2007/01/21 15:13:46 ncq Exp $
-__version__ = "$Revision: 1.37 $"
+# $Id: gmXdtMappings.py,v 1.40 2007/05/14 10:37:31 ncq Exp $
+__version__ = "$Revision: 1.40 $"
 __author__ = "S.Hilbert, K.Hilbert"
 __license__ = "GPL"
 
@@ -29,15 +29,15 @@ xdt_id_map = {
 	'6298':'??',
 	'6299':'??',
 
-	#KBV-Prfnummer 
-	'0101':'KBV-Prfnummer',
+	#KBV-Prüfnummer 
+	'0101':'KBV-Prüfnummer',
 	#responsible software vendor 
 	'0102':'Softwareverantwortlicher',
 	#software package 
 	'0103':'Software',
 	#PC hardware 
 	'0104':'Hardware',
-	'0105':'KBV-Prfnummer',
+	'0105':'KBV-Prüfnummer',
 	'0111':'Email-Adresse des SV',
 	'0121':'Strasse des SV',
 	'0122':'PLZ des SV',
@@ -62,20 +62,20 @@ xdt_id_map = {
 	'0208': 'Telefonnummer',
 	'0209': 'Telefaxnummer',
 	'0210': ' Modemnummer',
-	'0211': 'Arztname fr Leistungsdifferenzierung',
+	'0211': 'Arztname für Leistungsdifferenzierung',
 	'0213': 'Leistungskennzeichen',
-	'0214': 'Erluterung zum Leistungskennzeichen',
+	'0214': 'Erläuterung zum Leistungskennzeichen',
 	'0215': 'PLZ der Praxisadresse',
 	'0216': 'Ort der Praxisadresse',
 	'0218': 'E-Mail der Praxis/des Arztes',
-	'0225': 'Anzahl der rzte',
+	'0225': 'Anzahl der Ärzte',
 
 	'0250':'Name erste freie Kategorie',
 	'0251':'Inhalt erste freie Kategorie',
 
 	'0915':'PZN Medikament auf Kassenrezept',
-	'0917':'Packungsgrsse Medikament auf Kassenrezept',
-	'0918':'Packungsgrsse Medikament auf Privatrezept',
+	'0917':'Packungsgrösse Medikament auf Kassenrezept',
+	'0918':'Packungsgrösse Medikament auf Privatrezept',
 	'0919':'Hilfsmittelbezeichnung',
 	'0920':'Hilfsmittelnummer',
 	'0922':'PZN Hilfsmittel',
@@ -83,17 +83,17 @@ xdt_id_map = {
 	'0925':'Heilmittel',
 	'0950':'PZN Dauermedikament',
 	'0951':'PZN Medikament auf Privatrezept',
-	'0952':'PZN rztemuster',
-	'0953':'Packungsgrsse rztemuster',
-	'0960':'Kennzeichnung Gebhrenpflichtig',
+	'0952':'PZN Ärztemuster',
+	'0953':'Packungsgrösse Ärztemuster',
+	'0960':'Kennzeichnung Gebührenpflichtig',
 	'0961':'Kennzeichnung aut idem',
 	'0962':'Kennzeichnung noctu',
 	'0970':'Anzahl (Packungen) Medikament auf Rezept',
 	'0971':'Anzahl (Packungen) Medikament auf Privatrezept',
 	'2700':'IK des Krankenhauses',
 	'2701':'Fachgebiet laut LKA',
-	'2702':'Arztnummer des Ansthesisten',
-	'2706':'Indikationsschlssel',
+	'2702':'Arztnummer des Anästhesisten',
+	'2706':'Indikationsschlüssel',
 	'2709':'Lfd. OP-Nummer',
 	'2710':'Lfd. OP-Nummer',
 	'2711':'OP-Datum',
@@ -101,37 +101,37 @@ xdt_id_map = {
 	'2721':'Narkosezwischenfall',
 	'2722':'Pneumonie',
 	'2723':'Wundinfektion',
-	'2724':'Gefss- oder Nervenlsion',
-	'2725':'Lagerungsschden',
+	'2724':'Gefäss- oder Nervenläsion',
+	'2725':'Lagerungsschäden',
 	'2726':'Venenthrombose',
 	'2727':'Komplikation',
 	'2728':'Erfolgsbeurteilung hinsichtlich Indikationsstellung',
 	'2729':'Erfolgsbeurteilung hinsichtlich Histologie',
 	'2730':'Revisionseingriff',
-	'2731':'Stationre Aufnahme',
+	'2731':'Stationäre Aufnahme',
 	'2732':'Angaben zu implantierten Materialien',
 	'2740':'Art der Operation',
 	'2741':'Dauer der Operation',
 	'2742':'Operierte Seite',
-	'2743':'Art der Ansthesie',
-	'2744':'Art der Ansthesie gemss Klassifikation Strukturvertrag',
+	'2743':'Art der Anästhesie',
+	'2744':'Art der Anästhesie gemäss Klassifikation Strukturvertrag',
 	'2750':'Operateur hat Facharztstatus',
-	'2751':'Anzahl rztl. Assistenten bei OP',
+	'2751':'Anzahl ärztl. Assistenten bei OP',
 	'2752':'(Ein) OP-Assistent hat Facharztstatus',
-	'2753':'Anzahl nichtrzticher Assistenten bei OP',
-	'2760':'Art der Ansthesie',
-	'2761':'Ansthesie erbracht',
-	'2762':'Dauer der Ansthesie',
+	'2753':'Anzahl nichtärzticher Assistenten bei OP',
+	'2760':'Art der Anästhesie',
+	'2761':'Anästhesie erbracht',
+	'2762':'Dauer der Anästhesie',
 	'2770':'Blutung',
 	'2771':'Narkosezwischenfall',
 	'2772':'Pneumonie',
 	'2773':'Wundinfektion',
-	'2774':'Gefss- oder Nervenlsion',
-	'2775':'Lagerungsschden',
+	'2774':'Gefäss- oder Nervenläsion',
+	'2775':'Lagerungsschäden',
 	'2776':'Venenthrombose',
 	'2780':'Revisionseingriff erforderlich',
 	'2781':'Histologie',
-	'2782':'Stationre Weiterbehandlung erforderlich',
+	'2782':'Stationäre Weiterbehandlung erforderlich',
 	#Patientennummer/Patientenkennung
 	'3000':'Patientennummer',
 	#Namenszusatz/Vorsatzwort des Patienten
@@ -157,12 +157,12 @@ xdt_id_map = {
 	'3111':'Geburtsjahr des Patienten',
 	'3112':'PLZ des Patienten',
 	'3113':'Wohnort des Patienten',
-	'3114':'Wohnsitzlndercode',
+	'3114':'Wohnsitzländercode',
 	'3116':'KV-Bereich',
 	#Arbeitgeber -- nur bei header 0191 --
 	'3150':'Arbeitgeber',
-	#Bezeichnung des Unfallversicherungstrgers -- nur bei header 0191 --
-	'3152':'Unfallversicherungstrger',
+	#Bezeichnung des Unfallversicherungsträgers -- nur bei header 0191 --
+	'3152':'Unfallversicherungsträger',
 	#Name des Hauptversicherten
 	'3200':'Namenszusatz/Vorsatzwort des Hauptversicherten',
 	'3201':'Name des Hauptversicherten',
@@ -181,28 +181,26 @@ xdt_id_map = {
 	'3209':'Wohnort des Hauptversicherten',
 	#Geschlecht des Hauptversicherten -- nur bei header 0190 --
 	'3210':'Geschlecht des Hauptversicherten',
-	#Rntgennummer -- nur bei header 6100 --
-	'3601':'Rntgennummer',
-	#Archivnummer -- nur bei header 6100 --
-	 '3602':'Archivnummer',
-	#BG-Nummer -- nur bei header 6100 --
-	'3603':'BG-Nummer',
+	'3600': 'Patientennummer (alter BDT ?, beobachtet bei Medistar)',
+	'3601': 'Röntgennummer',
+	'3602': 'Archivnummer',
+	'3603': 'BG-Nummer',
 	#Datum Patient seit -- nur bei header 6100 --
 	'3610':'Datum Patient seit',
 	#Datum Versichertenbeginn bei Kassenwechsel -- nur bei header 6100 --
 	 '3612':'Datum Versichertenbeginn bei Wechsel',
 	#Beruf des Patienten -- nur bei header 6100 --
 	'3620':'Beruf des Patienten',
-	#Grsse des Patienten -- nur bei header 6200 --
-	'3622':'Grsse des Patienten',
+	#Grösse des Patienten -- nur bei header 6200 --
+	'3622':'Grösse des Patienten',
 	#Gewicht des Patienten -- nur bei header 6200 --
 	'3623':'Gewicht des Patienten',
 	#Arbeitgeber des Patienten -- nur bei header 6100 --
 	'3625':'Arbeitgeber des Patienten',
 	#Telefonnummer des Patienten -- nur bei header 6100 --
 	'3626':'Telefonnummer des Patienten',
-	#Nationalitt des Patienten -- nur bei header 6100 --
-	'3627':'Nationalitt des Patienten',
+	#Nationalität des Patienten -- nur bei header 6100 --
+	'3627':'Nationalität des Patienten',
 	#Muttersprache Patient -- nur bei header 6100 --
 	'3628':'Muttersprache des Patienten',
 	#Arztnummer des Hausarztes -- nur bei header 6100 --
@@ -225,8 +223,8 @@ xdt_id_map = {
 	'3654':'Risikofaktoren',
 	#Allergien -- nur bei header 6100 --
 	'3656':'Allergien',
-	#Unflle -- nur bei header 6100 --
-	'3658':'Unflle',
+	#Unfälle -- nur bei header 6100 --
+	'3658':'Unfälle',
 	#Operationen -- nur bei header 6100 --
 	'3660':'Operationen',
 	#Anamnese -- nur bei header 6100 --
@@ -253,33 +251,33 @@ xdt_id_map = {
 	'4101':'Quartal',
 	#Ausstellungsdatum
 	'4102':'Ausstellungsdatum',
-	#Gltigkeitsdatum
-	'4103':'Gltigkeitsdatum',
+	#Gültigkeitsdatum
+	'4103':'Gültigkeitsdatum',
 	#VKNR- Vertragskassenarztnummer
 	'4104':'Abrechnungs-VKNR',
-	#Geschftsstelle
-	'4105':'Geschftsstelle',
-	#Kostentrgergruppe
-	'4106':'Kostentrger-Abrechnungsbereich(KTAB)',
+	#Geschäftsstelle
+	'4105':'Geschäftsstelle',
+	#Kostenträgergruppe
+	'4106':'Kostenträger-Abrechnungsbereich(KTAB)',
 	#Abrechnungsart
 	'4107':'Abrechnungsart',
 	#letzter Einlesetag der VK im Quartal TTMMJJ
 	'4109':'letzter Einlesetag der KVK im Quartal',
-	#Bis-Datum der Gltigkeit MMJJ
-	'4110':'Bis-Datum der Gltigigkeit',
+	#Bis-Datum der Gültigkeit MMJJ
+	'4110':'Bis-Datum der Gültigigkeit',
 	#Krankenkassennummer
 	'4111':'Krankenkassennummer (IK)',
 	#Versichertenstatus VK
 	'4112':'Versichertenstatus VK',
-	##'4113':'Statusergnzung/DMP-Kennzeichnung',
+	##'4113':'Statusergänzung/DMP-Kennzeichnung',
 	'4113':'Ost/West-Status VK',
-	#Gebhrenordnung
-	'4121':'Gebhrenordnung',
+	#Gebührenordnung
+	'4121':'Gebührenordnung',
 	#Abrechnungsgebiet
 	'4122':'Abrechnungsgebiet',
 	'4123':'Personenkreis/Untersuchungskategorie',
 	'4124':'SKT-Zusatzangaben',
-	'4125':'Gltigkeitszeitraum von ... bis ...',
+	'4125':'Gültigkeitszeitraum von ... bis ...',
 	#Ursache des Leidens 
 	'4201':'Ursache des Leidens',
 	'4202':'Unfall, Unfallfolgen',
@@ -287,8 +285,8 @@ xdt_id_map = {
 	'4206':'mutmasslicher Tag der Entbindung',
 	#Diagnose/Verdacht -- nur bei header 0102 --
 	'4207':'Diagnose/Verdacht',
-	#erluternder Text zur berweisung -- nur bei header 0102 --
-	'4209':'erluternder Text zur berweisung',
+	#erläuternder Text zur Überweisung -- nur bei header 0102 --
+	'4209':'erläuternder Text zur Überweisung',
 	#Ankreuzfeld LSR  -- nur bei header 0102 --
 	'4210':'Ankreuzfeld LSR',
 	#Ankreuzfeld HAH  -- nur bei header 0102 --
@@ -297,20 +295,20 @@ xdt_id_map = {
 	'4212':'Ankreuzfeld ABO.RH',
 	#Ankreuzfeld AK  -- nur bei header 0102 --
 	'4213':'Ankreuzfeld AK',
-	#berweisung von Arztnummer  -- nur bei header 0102 --
+	#Überweisung von Arztnummer  -- nur bei header 0102 --
 	'4217':'Vertragsarzt-Nr. des Erstveranlassers',
-	'4218':'berweisung von Arztnummer',
-	#berweisung an  -- nur bei header 0102 --
-	'4219':'berweisung von anderen rzten',
-	'4220':'berweisung an',
-	'4221':'Kurativ / Prventiv / Sonstige Hilfen / bei belegrztlicher Behandlung',
+	'4218':'Überweisung von Arztnummer',
+	#Überweisung an  -- nur bei header 0102 --
+	'4219':'Überweisung von anderen Ärzten',
+	'4220':'Überweisung an',
+	'4221':'Kurativ / Präventiv / Sonstige Hilfen / bei belegärztlicher Behandlung',
 	'4222':'Kennziffer OI./O.II.',
 	'4223':'Kennziffer OIII.',
-	#stationre Behandlung von bis -- nur bei header 0103/0190 --
-	'4233':'stationre Behandlung von... bis...',
+	#stationäre Behandlung von bis -- nur bei header 0103/0190 --
+	'4233':'stationäre Behandlung von... bis...',
 	'4234':'anerkannte Psychotherapie',
 	'4235':'Datum des Anerkennungsbescheides',
-	#Klasse bei stationrer Behandlung -- nur bei header 0190 --
+	#Klasse bei stationärer Behandlung -- nur bei header 0190 --
 	'4236':'Klasse bei Behandlung',
 	#Krankenhausname -- nur bei header 0190 --
 	'4237':'Krankenhausname',
@@ -321,16 +319,16 @@ xdt_id_map = {
 	#weiterbehandelnder Arzt -- nur bei header 0104 --
 	'4243':'weiterbehandelnder Arzt',
 	'4261':'Kurart',
-	'4262':'Durchfhrung als Kompaktkur',
+	'4262':'Durchführung als Kompaktkur',
 	'4263':'genehmigte Kurdauer in Wochen',
 	'4264':'Anreisetag',
 	'4265':'Abreisetag',
 	'4266':'Kurabbruch am',
-	'4267':'Bewilligte Kurverlngerung in Wochen',
-	'4268':'Bewilligungsdatum Kurverlngerung',
-	'4269':'Verhaltensprventive Massnahmen angeregt',
-	'4270':'Verhaltensprventive Massnahmen durchgefhrt',
-	'4271':'Kompaktkur nicht mglich',
+	'4267':'Bewilligte Kurverlängerung in Wochen',
+	'4268':'Bewilligungsdatum Kurverlängerung',
+	'4269':'Verhaltenspräventive Massnahmen angeregt',
+	'4270':'Verhaltenspräventive Massnahmen durchgeführt',
+	'4271':'Kompaktkur nicht möglich',
 	#Unfalltag -- nur bei header 0191 --
 	'4500':'Unfalltag',
 	#Uhrzeit des Unfalls -- nur bei header 0191 --
@@ -343,12 +341,12 @@ xdt_id_map = {
 	'4504':'Beginn der Arbeitszeit',
 	#Unfallort -- nur bei header 0191 --
 	'4505':'Unfallort',
-	#Beschftigung als -- nur bei header 0191 --
-	'4506':'Beschftigung als',
-	#Beschftigung seit -- nur bei header 0191 --
-	'4507':'Beschftigung seit',
-	#Staatsangehrigkeit -- nur bei header 0191 --
-	'4508':'Staatsangehrigkeit',
+	#Beschäftigung als -- nur bei header 0191 --
+	'4506':'Beschäftigung als',
+	#Beschäftigung seit -- nur bei header 0191 --
+	'4507':'Beschäftigung seit',
+	#Staatsangehörigkeit -- nur bei header 0191 --
+	'4508':'Staatsangehörigkeit',
 	#Unfallbetrieb -- nur bei header 0191 --
 	'4509':'Unfallbetrieb',
 	#Unfallhergang -- nur bei header 0191 --
@@ -359,8 +357,8 @@ xdt_id_map = {
 	'4513':'Erstmalige_Behandlung',
 	#Behandlung durch -- nur bei header 0191 --
 	'4514':'Behandlung_durch',
-	#Art dieser ersten rztlichen Behandlung -- nur bei header 0191 --
-	'4515':'Art dieser ersten rztlichen Behandlung',
+	#Art dieser ersten ärztlichen Behandlung -- nur bei header 0191 --
+	'4515':'Art dieser ersten ärztlichen Behandlung',
 	#Alkoholeinfluss -- nur bei header 0191 --
 	'4520':'Alkoholeinfluss',
 	#Anzeichen eines Alkoholeinflusses -- nur bei header 0191 --
@@ -369,12 +367,12 @@ xdt_id_map = {
 	'4522':'Blutentnahme',
 	#Befund -- nur bei header 0191 --
 	'4530':'Befund',
-	#Rntgenergebniss -- nur bei header 0191 --
-	'4540':'Rntgenergebniss',
+	#Röntgenergebniss -- nur bei header 0191 --
+	'4540':'Röntgenergebniss',
 	#Art etwaiger Erstversorgung durch D-Arzt -- nur bei header 0191 --
 	'4550':'Art etwaiger Versorgung durch D-Arzt',
-	#krankhafte Vernderungen unabhngig vom Unfall -- nur bei header 0191 --
-	'4551':'krankhafte Verndrungen unabhngig vom Unfall',
+	#krankhafte Veränderungen unabhängig vom Unfall -- nur bei header 0191 --
+	'4551':'krankhafte Verändrungen unabhängig vom Unfall',
 	#Bedenken gegen Angaben -- nur bei header 0191 --
 	'4552':'Bedenken gegen Angaben',
 	#Art der Bedenken bei allegemeinen Bedenken-- nur bei header 0191 --
@@ -383,10 +381,10 @@ xdt_id_map = {
 	'4554':'Bedenken gegen Arbeistunfall',
 	#Art der Bedenken gegen Arbeitsunfall -- nur bei header 0191 --
 	'4555':'Art_Bedenken gegen Arbeitsunfall',
-	#arbeitsfhig -- nur bei header 0191 --
-	'4560':'arbeitsfhig',
-	#wieder arbeitsfhig ab -- nur bei header 0191 --
-	'4561':'wieder arbeitsfhig ab',
+	#arbeitsfähig -- nur bei header 0191 --
+	'4560':'arbeitsfähig',
+	#wieder arbeitsfähig ab -- nur bei header 0191 --
+	'4561':'wieder arbeitsfähig ab',
 	#AU-Bescheinigung ausgestellt -- nur bei header 0191 --
 	'4562':'AU ausgestellt',
 	#besondere Heilbehandlung erforderlich -- nur bei header 0191 --
@@ -403,24 +401,24 @@ xdt_id_map = {
 	'4580':'Rechnungsart',
 	#allgemeine Heilbehandlung durch -- nur bei header 0191 --
 	'4581':'allgemeine Heilbehandlung durch',
-	#AU ber 3 Tage -- nur bei header 0191 --
-	'4582':'AU ber 3 Tage',
+	#AU über 3 Tage -- nur bei header 0191 --
+	'4582':'AU über 3 Tage',
 	#AU bescheinigt als -- nur bei header 0191 --
 	'4583':'AU bescheinigt als',
 	#Nachschau erforderlich -- nur bei header 0191 --
 	'4584':'Nachschau erforderlich',
 	#Rechnungsnummer -- nur bei header 0190 --
 	'4601':'Rechnungsnummer',
-	#Anschrift des Rechnungsadressaten (Empfnger) -- nur bei header 0190 --
+	#Anschrift des Rechnungsadressaten (Empfänger) -- nur bei header 0190 --
 	'4602':'Rechnungsanschrift',
-	#berweisender Arzt -- nur bei header 0190 --
-	'4603':'berweisender Arzt',
+	#überweisender Arzt -- nur bei header 0190 --
+	'4603':'überweisender Arzt',
 	#Rechnungsdatum -- nur bei header 0190 --
 	'4604':'Rechnungsdatum',
 	#Endsumme -- nur bei header 0190 --
 	'4605':'Endsumme',
-	#Abdingungserklrung vorhanden -- nur bei header 0190 --
-	'4608':'Abdingungserklrung vorhanden',
+	#Abdingungserklärung vorhanden -- nur bei header 0190 --
+	'4608':'Abdingungserklärung vorhanden',
 	#Unterkonto Arzt -- nur bei header 0190 --
 	'4611':'Unterkonto Arzt',
 	#Anlage erforderlich -- nur bei header 0190 --
@@ -428,27 +426,27 @@ xdt_id_map = {
 	#Kopfzeile -- nur bei header 0190 --
 	'4615':'Kopfzeile',
 	#Fusszeile -- nur bei header 0190 --
-	'4617': 'Fuzeile',
+	'4617': 'Fußzeile',
 	'5000': 'Leistungstag',
 	'5001': 'GNR',
 	#Art der Untersuchung
 	'5002':'Art der Untersuchung',
-	#Empfnger des Briefes
-	'5003':'Empfnger des Briefes',
+	#Empfänger des Briefes
+	'5003':'Empfänger des Briefes',
 	#Kilometer (nur bei GOA)
 	'5004':'Kilometer',
 	#Multiplikator
 	'5005':'Multiplikator',
 	#Um-Uhrzeit
 	'5006':'Um-Uhrzeit',
-	#Bestellzeit-Ausfhrungszeit
-	'5007':'Bestellzeit-Ausfhrungszeit',
+	#Bestellzeit-Ausführungszeit
+	'5007':'Bestellzeit-Ausführungszeit',
 	#DKM=Doppelkilometer
 	'5008':'Doppel-KM',
-	#freier Begrndungstext
-	'5009':'freier Begrndungstext',
-	#Medikament als Begrndung -- nur bei header 0190 --
-	'5010':'Medikament als Begrndung',
+	#freier Begründungstext
+	'5009':'freier Begründungstext',
+	#Medikament als Begründung -- nur bei header 0190 --
+	'5010':'Medikament als Begründung',
 	#Sachkosten-Bezeichnung
 	'5011':'Sachkosten-Bezeichnung',
 	#Sachkosten/Materialkosten (Dpf)
@@ -462,13 +460,13 @@ xdt_id_map = {
 	'5017':'Besuchsort bei Hausbesuchen',
 	#Zone bei Besuchen
 	'5018':'Zone bei Besuchen',
-	'5019':'Erbringungsort,Standort des Gertes',
+	'5019':'Erbringungsort,Standort des Gerätes',
 	'5023':'GO-Nummern-Zusatz',
-	'5024':'GNR-Zusatzkennzeichen fr poststationr erbrachte Leistungen',
+	'5024':'GNR-Zusatzkennzeichen für poststationär erbrachte Leistungen',
 	#Beschreibung der GNR -- nur bei header 0190 --
 	'5060':'Beschreibung der GNR',
-	#Gebhr -- nur bei header 0190 --
-	'5061':'Gebhr',
+	#Gebühr -- nur bei header 0190 --
+	'5061':'Gebühr',
 	#Faktor -- nur bei header 0190 --
 	'5062':'Faktor',
 	#Betrag -- nur bei header 0190 --
@@ -481,12 +479,12 @@ xdt_id_map = {
 	'5091':'Gutachtenbezeichnung',
 	#Abrechnungsdiagnosen -- nur bei header 0102 --
 	'6000':'Abrechnungsdiagnosen',
-	#ICD-Schlssel
-	'6001':'ICD-Schlssel',
+	#ICD-Schlüssel
+	'6001':'ICD-Schlüssel',
 	'6003':'Diagnosensicherheit',
 	'6004':'Seitenlokalisation',
-	'6005':'Histologischer Befund bei Malignitt',
-	'6006':'Diagnosenerluterung',
+	'6005':'Histologischer Befund bei Malignität',
+	'6006':'Diagnosenerläuterung',
 	#Tag der Speicherung von Behandlungsdaten -- nur bei header 6200 --
 	'6200':'gespeichert am',
 	#aktuelle Diagnose -- nur bei header 6200 --
@@ -495,17 +493,17 @@ xdt_id_map = {
 	'6210':'Medikament verordnet auf Kassenrezept',
 	#ausserhalb Rezept verordnetes Medikament -- nur bei header 6200 --
 	'6211':'Medikament verordnet auf Privatrezept',
-	#rztenummer -- nur bei header 6200 --
-	 ##'6215':'rztenummer',
-	'6215':'rztemuster',
+	#Ärztenummer -- nur bei header 6200 --
+	 ##'6215':'Ärztenummer',
+	'6215':'Ärztemuster',
 	#Befund -- nur bei header 6200 --
 	'6220':'Befund',
 	#Fremdbefund -- nur bei header 6200 --
 	'6221':'Fremdbefund',
 	#Laborbefund -- nur bei header 6200 --
 	'6222':'Laborbefund',
-	#Rntgenbefund -- nur bei header 6200 --
-	'6225':'Rntgenbefund',
+	#Röntgenbefund -- nur bei header 6200 --
+	'6225':'Röntgenbefund',
 	#Blutdruck -- nur bei header 6200 --
 	'6230':'Blutdruck',
 	#Symptome -- nur bei header 6200 --
@@ -514,8 +512,8 @@ xdt_id_map = {
 	'6260':'Therapie',
 	#physikalische Therapie -- nur bei header 6200 --
 	'6265':'physikalische Therapie',
-	#berweisung Inhalt -- nur bei header 6200 --
-	'6280':'berweisung Inhalt',
+	#Überweisung Inhalt -- nur bei header 6200 --
+	'6280':'Überweisung Inhalt',
 	#AU-Dauer -- nur bei header 6200 --
 	'6285':'AU Dauer (von - bis)',
 	#AU-wegen -- nur bei header 6200 --
@@ -538,8 +536,8 @@ xdt_id_map = {
 	'6306':'Attest',
 	#Inhalt des Attestes -- nur bei header 6200 --
 	'6307':'Inhalt des Attestes',
-	#Name des Briefempfngers -- nur bei header 6200 --
-	'6310':'Name des Briefempfngers',
+	#Name des Briefempfängers -- nur bei header 6200 --
+	'6310':'Name des Briefempfängers',
 	#Anrede -- nur bei header 6200 --
 	'6311':'Anrede',
 	#Strasse -- nur bei header 6200 --
@@ -552,29 +550,23 @@ xdt_id_map = {
 	'6315':'Schlusssatz',
 	#Telefonnummer -- nur bei header 6200 --
 	'6316':'Telefonnummer',
-	#Telefax -- nur bei header 6200 --
-	'6317':'Telefax',
-	#Arztnummer/Arztident -- nur bei header 6200 --
-	'6319':'Arztnummer/Arztident',
-	#Briefinhalt -- nur bei header 6200 --
-	'6320':'Briefinhalt',
-	#Bild-Archivierungsnummer -- nur bei header 6200 --
-	'6325':'Bild-Archivierungsnummer',
-	#Graphikformat -- nur bei header 6200 --
-	'6326':'Graphikformat',
-	#Bildinhalt -- nur bei header 6200 --
-	'6327':'Bildinhalt',
-	#Name der ersten freien Kategorie -- nur bei header 6200 --
-	'6330':'Name der ersten freien Kategorie',
-	#Inhalt der ersten freien Kategorie -- nur bei header 6200 --
-	'6331':'Inhalt der ersten freien Kategorie',
+	'6317': 'Telefax',
+	'6319': 'Arztnummer/Arztident',
+	'6320': 'Briefinhalt',
+
+	'6325': 'Bild-Archivierungsnummer',
+	'6326': 'Graphikformat',
+	'6327': 'Bildinhalt',
+
+	# 63xx und 63xx+1 each belong together in pairs up to 6398/99
+	'6330': 'freie Kategorie 1: Name',
+	'6331': 'freie Kategorie 1: Inhalt',
 
 	#--------------------------------------------------------
-	# more free categories
 	# Satzidentifikation
 	'8000':'Satzidentifikation >>===============',
-	# Satzlnge
-	'8100': 'Satzlnge',
+	# Satzlänge
+	'8100': 'Satzlänge',
 
 	# LDT
 	'8301': 'UNBEKANNT Datum',       ## nicht in GDT 2.1 Specs (KS)
@@ -585,7 +577,7 @@ xdt_id_map = {
 
 	'8311': 'UNBEKANNT Integer lang',## nicht in GDT 2.1 Specs (KS)
 	'8312': 'UNBEKANNT Integer kurz',## nicht in GDT 2.1 Specs (KS)
-	'8315': 'GDT-ID Empfnger',
+	'8315': 'GDT-ID Empfänger',
 	'8316': 'GDT-ID Sender',
 
 	'8320': 'Labor Bezeichnung',     ## nicht in GDT 2.1 Specs (KS)
@@ -595,10 +587,10 @@ xdt_id_map = {
 
 	# Befundstatus -- nur bei header 6200/8202 --
 	'8401': 'Befundstatus',
-	#Gerte- bzw. Verfahrensspezifisches Kennfeld -- nur bei header 6200 --
-	'8402':'Gertespezifisches Kennfeld',
+	#Geräte- bzw. Verfahrensspezifisches Kennfeld -- nur bei header 6200 --
+	'8402':'Gerätespezifisches Kennfeld',
 	# LDT
-	'8403': 'Gebhrenordnung',
+	'8403': 'Gebührenordnung',
 	# LDT
 	'8404': 'Kosten in Doppelpfennigen',
 	'8406': 'Kosten in Cent',
@@ -656,22 +648,22 @@ xdt_id_map = {
 	#Abschluss-Zeile -- nur bei header 6200 --
 	'8490':'Abschluss-Zeile',
 	# LDT
-	'8609': 'Gebhrenordung',
+	'8609': 'Gebührenordung',
 	#Signatur -- nur bei header 6200 --
 	'8990':'Signatur',
 	'9100':'Arztnummer des Absenders',
-	'9102':'Empfnger',
+	'9102':'Empfänger',
 	'9103':'Erstellungsdatum',
-	'9105':'Lfd.Nr. Datentrger im Paket',	
+	'9105':'Lfd.Nr. Datenträger im Paket',	
 	'9106':'verwendeter Zeichensatz',
 	'9115':'Erstellungsdatum ADT-Datenpaket',
 	'9116':'Erstellungsdatum KADT-Datenpaket',
 	'9117':'Erstellungsdatum AODT-Datenpaket',
 	'9118':'Erstellungsdatum STDT-Datenpaket',
 	'9132':'enthaltene Datenpakete dieser Datei',
-	'9202':'Gesamtlnge Datenpaket',
+	'9202':'Gesamtlänge Datenpaket',
 	#number of media for this data package     
-	'9203':'Anzahl Datentrger im Paket',
+	'9203':'Anzahl Datenträger im Paket',
 	'9204':'Abrechnungsquartal',
 	'9206': 'Zeichensatz (encoding)',
 	#ADT-version
@@ -685,22 +677,22 @@ xdt_id_map = {
 	#storage timeframe
 	'9601':'Zeitraum der Speicherung',
 	#time of transfer start
-	'9602':'Beginn der bertragung',
+	'9602':'Beginn der Übertragung',
 	'9901':'Systeminterner Parameter'
 }
 #--------------------------------------------------------------
 # 8000
 xdt_packet_type_map = {
-	'0020': "========<< Anfang Datentrger >>========",
-	'0021': "========<< Ende Datentrger >>========",
+	'0020': "========<< Anfang Datenträger >>========",
+	'0021': "========<< Ende Datenträger >>========",
 	'0022': "========<< Anfang Datenpaket >>========",
 	'0023': "========<< Ende Datenpaket >>========",
 	'0010': "========<< Praxisdaten >>========",
-	'0101': "========<< Fall: Primrarzt >>========",
-	'0102': "========<< Fall: berweisung >>========",
+	'0101': "========<< Fall: Primärarzt >>========",
+	'0102': "========<< Fall: Überweisung >>========",
 	'0103': "========<< Fall: Belegarzt  >>========",
 	'0104': "========<< Fall: Notfall/Dienst/Vertretung >>========",
-	'0109': "========<< Kurrztliche Abrechnung >>========",
+	'0109': "========<< Kurärztliche Abrechnung >>========",
 	'0190': "========<< Fall: Privat >>========",
 	'0191': "========<< Fall: BG >>========",
 	'0199': "========<< Fall: unstrukturiert >>========",
@@ -713,9 +705,9 @@ xdt_packet_type_map = {
 	'con9': "========<< Container-Abschluss >>========",
 	'prax': "========<< Praxisdaten >>========",
 	'kad0': "========<< KADT-Datenpaket-Header >>========",
-	'kad9': "========<< KADT-Datenpaket-Abschlu >>========",
+	'kad9': "========<< KADT-Datenpaket-Abschluß >>========",
 	'std0': "========<< STDT-Datenpaket-Header >>========",
-	'std9': "========<< STDT-Datenpaket-Abschlu >>========",
+	'std9': "========<< STDT-Datenpaket-Abschluß >>========",
 	'st13': "========<< Statistiksatz >>========"
 }
 #--------------------------------------------------------------
@@ -746,6 +738,14 @@ map_gender_xdt2gm = {
 	'5': 'f'
 }
 
+map_gender_gm2xdt = {
+	'm': '1',
+	'f': '2',
+	'tm': '1',
+	'tf': '2',
+	'h': '?'
+}
+
 # LDT "gender", 8407
 map_8407_2str = {
 	'0': _('unknown gender'),
@@ -792,11 +792,11 @@ xdt_Archivierungsart_map = {
 xdt_Praxistyp_map = {
 	'1':'Einzelpraxis',
 	'2':'Gemeinschaftspraxis',
-	'3':'Fachbergreifende GP',
+	'3':'Fachübergreifende GP',
 	'4':'Praxisgemeinschaft',
-	'5':'Fachbergreifende GP ohne Kennzeichen Leistung',
-	'6':'ermchtigter Arzt',
-	'7':'Krankenhaus oder rztlich geleitete Einrichtung'
+	'5':'Fachübergreifende GP ohne Kennzeichen Leistung',
+	'6':'ermächtigter Arzt',
+	'7':'Krankenhaus oder ärztlich geleitete Einrichtung'
 }
 # Versichertenart MFR : 3108
 xdt_Versichertenart_map = {
@@ -804,24 +804,24 @@ xdt_Versichertenart_map = {
 	'3':'Familienversicherter',
 	'5':'Rentner',
 }
-# Kostentrgeruntergruppe : 4106
+# Kostenträgeruntergruppe : 4106
 xdt_Kostentraegeruntergruppe_map = {
 	'00':'default',
 	'01':'SVA(Sozialversicherungsabkommen)',
 	'02':'BVG(Bundesversorgungsgesetz)',
-	'03':'BEG(Bundesentschdigungsgesetz)',
-	'04':'Grenzgnger',
+	'03':'BEG(Bundesentschädigungsgesetz)',
+	'04':'Grenzgänger',
 	'05':'Rheinschiffer',
-	'06':'SHT(Sozialhilfetrger, ohne Asylstellen)',
+	'06':'SHT(Sozialhilfeträger, ohne Asylstellen)',
 	'07':'BVFG(Bundesvertriebenengesetz)',
 	'08':'Asylstellen(AS)',
-	'09':'Schwangerschaftsabbrche'
+	'09':'Schwangerschaftsabbrüche'
 }
 # Abrechnungsart : 4107
 xdt_Abrechnungsart_map = {
-	'1':'PKA(Primrkassen)',
+	'1':'PKA(Primärkassen)',
 	'2':'EKK(Ersatzkassen)',
-	'3':'SKT(Sonstige Kostentrger)',
+	'3':'SKT(Sonstige Kostenträger)',
 }
 # Ost/West-Status VK : 4113
 xdt_Ost_West_Status_map = {
@@ -830,12 +830,12 @@ xdt_Ost_West_Status_map = {
 	'7':'SVA',
 	'8':'SVA',
 	'9':'Ost',
-	'M':'eingeschriebene Versicherte in Disease-Management-Programmen fr Diabetes mellitus Typ2 - RK West',
-	'X':'eingeschriebene Versicherte in Disease-Management-Programmen fr Diabetes mellitus Typ2 - RK Ost',
-	'A':'eingeschriebene Versicherte in Disease-Management-Programmen fr Brustkrebs - RK West',
-	'C':'eingeschriebene Versicherte in Disease-Management-Programmen fr Brustkrebs - RK Ost',
+	'M':'eingeschriebene Versicherte in Disease-Management-Programmen für Diabetes mellitus Typ2 - RK West',
+	'X':'eingeschriebene Versicherte in Disease-Management-Programmen für Diabetes mellitus Typ2 - RK Ost',
+	'A':'eingeschriebene Versicherte in Disease-Management-Programmen für Brustkrebs - RK West',
+	'C':'eingeschriebene Versicherte in Disease-Management-Programmen für Brustkrebs - RK Ost',
 }
-# Gebhrenordnung : 4121
+# Gebührenordnung : 4121
 xdt_Gebuehrenordnung_map = {
 	'1':'BMA',
 	'2':'E-GO',
@@ -848,14 +848,14 @@ xdt_Abrechnungsgebiet_map = {
 	'02':'Dialyse-Sachkosten',
 	'03':'Methadon-Substitutionsbehandlung',
 	'04':'Grosse Psychotherapie',
-	##'04':'persnlich erbrachte Notfallleistungen durch ermchtigte Krankenhausrzte',
+	##'04':'persönlich erbrachte Notfallleistungen durch ermächtigte Krankenhausärzte',
 	'05':'Verhaltenstherapie',
-	##'05':'sonstige Notfallleistungen durch ermchtigte Krankenhausrzte',
+	##'05':'sonstige Notfallleistungen durch ermächtigte Krankenhausärzte',
 	'06':'Fremde Zytologie',
 	'07':'Diabestesabrechnung',
 	'08':'Umweltmedizin',
 	'09':'Rheuma',
-	'10':'Hirnleistungsstrungen',
+	'10':'Hirnleistungsstörungen',
 	'11':'Kodex-Anhangsarzt',
 	'12':'Kodex-Arzt',
 	'13':'Kodex-Listenarzt',
@@ -878,13 +878,13 @@ xdt_Scheinuntergruppe_map = {
 	'22':'Rahmenauftrag',
 	'23':'Konsillaruntersuchung',
 	'24':'Mit/Weiterbehandlung (Defaultwert ausser bei Einsendepraxen)',
-	'25':'berweisung aus anderen Grnden',
-	'26':'Stat. Mitbehandlung, Vergtung nach amb. Grundstzen',
-	'27':'berweisungs-/Abrechnungssschein fr Laboratoriumsuntersuchungen als Auftragsleistung',
-	'30':'Belegrztliche Behandlung (Default bei SA 0103)',
-	'31':'Belegrztliche Mitbehandlung',
-	'32':'Urlaubs-/bzw. Krankheitsvertretung bei belegrztlicher Behandlung',
-	'41':'rztlicher Notfalldienst',
+	'25':'Überweisung aus anderen Gründen',
+	'26':'Stat. Mitbehandlung, Vergütung nach amb. Grundsätzen',
+	'27':'Überweisungs-/Abrechnungssschein für Laboratoriumsuntersuchungen als Auftragsleistung',
+	'30':'Belegärztliche Behandlung (Default bei SA 0103)',
+	'31':'Belegärztliche Mitbehandlung',
+	'32':'Urlaubs-/bzw. Krankheitsvertretung bei belegärztlicher Behandlung',
+	'41':'ärztlicher Notfalldienst',
 	'42':'Urlaubs-bzw. Krankheitsvertretung',
 	'43':'Notfall',
 	'44':'Notfalldienst bei Taxi',
@@ -892,16 +892,16 @@ xdt_Scheinuntergruppe_map = {
 	'46':'Zentraler Notfalldienst',
 	'90':'default bei SA 0190',
 	'91':'Konsillaruntersuchung',
-	'92':'stat. Mitbehandlung Vergtung nach stat. Grundstzen',
-	'93':'stat. Mitbehandlung Vergtung nach ambul. Grundstzen',
-	'94':'belegrztliche Behandlung im Krankenhaus'
+	'92':'stat. Mitbehandlung Vergütung nach stat. Grundsätzen',
+	'93':'stat. Mitbehandlung Vergütung nach ambul. Grundsätzen',
+	'94':'belegärztliche Behandlung im Krankenhaus'
 }
-# Gesetzlicher Abzug zur stationren Behandlung gemss Paragraph 6a GOA
+# Gesetzlicher Abzug zur stationären Behandlung gemäss Paragraph 6a GOA
 xdt_gesetzlicher_Abzug_map = {
 	'1':'nein',
 	'2':'ja'
 }
-# Klasse bei stationrer Behandlung
+# Klasse bei stationärer Behandlung
 xdt_Klasse_stationaere_Behandlung_map = {
 	'1':'Einbettzimmer',
 	'2':'Zweibettzimmer',
@@ -920,13 +920,13 @@ xdt_Rechnungsart_map = {
 	'70':'Justizvollzugsanstalt',
 	'71':'Jugendarbeitsschutz',
 	'72':'Landesversicherungsanstalt',
-	'73':'Bundesversicherungsanstalt fr Angestellte',
+	'73':'Bundesversicherungsanstalt für Angestellte',
 	'74':'Sozialamt',
 	'75':'Sozialgericht',
 	'80':'Studenten-Deutsche',
-	'81':'Studenten-Auslnder'
+	'81':'Studenten-Ausländer'
 }
-# Abdingungserklrung vorhanden
+# Abdingungserklärung vorhanden
 xdt_Abdingungserklaerung_map = {
 	'1':'nein',
 	'2':'ja'
@@ -951,14 +951,14 @@ xdt_Arbeitsunfall_map = {
 	'1':'nein',
 	'2':'ja'
 }
-# arbeitsfhig
+# arbeitsfähig
 xdt_arbeitsfaehig_map = {
 	'1':'angekreuzt'
 }
 # Besondere Heilbehandlung erforderlich
 xdt_Heilbehandlung_erforderlich_map = {
 	'1':'ambulant',
-	'2':'stationr'
+	'2':'stationär'
 }
 # Besondere Heilbehandlung durch
 xdt_Besondere_Heilbehandlung_durch_map = {
@@ -970,7 +970,7 @@ xdt_Allgemeine_Heilbehandlung_durch_map = {
 	'1':'selbst',
 	'2':'anderer Arzt'
 }
-# AU ber 3 Tage
+# AU über 3 Tage
 xdt_AU_3Tage_map = {
 	'1':'angekreuzt'
 }
@@ -1009,7 +1009,7 @@ xdt_Resistenzmethode_map = {
 xdt_Resistenzinterpretation_map = {
 	'0':'nicht getestet',
 	'1':'sensibel/wirksam',
-	'2':'mssig sensibel/schwach wirksam',
+	'2':'mässig sensibel/schwach wirksam',
 	'3':'resistent/unwirksam',
 	'4':'wirksam in hohen Konzentrationen'
 }
@@ -1017,8 +1017,8 @@ xdt_Resistenzinterpretation_map = {
 kvdt_enthaltene_Datenpakete_map = {
 	'1':'ADT-Datenpaket',
 	'2':'AODT-Datenpaket(roter Erhebungsbogen)',
-	'3':'Kurrztliches Abrechnungsdatenpaket',
-	'4':'AODT-Hessen-Datenpaket (grner Erhebungsbogen der KV Hessen)',
+	'3':'Kurärztliches Abrechnungsdatenpaket',
+	'4':'AODT-Hessen-Datenpaket (grüner Erhebungsbogen der KV Hessen)',
 	'5':'STDT-Datenpaket'
 }
 #KV-Bereich : 3116
@@ -1035,9 +1035,9 @@ kvdt_KV_Bereich_map = {
 	'49':'Pfalz',
 	'50':'Trier',
 	'55':'Nordbaden',
-	'60':'Sdbaden',
-	'61':'Nordwrtemberg',
-	'62':'Sdwrtemberg',
+	'60':'Südbaden',
+	'61':'Nordwürtemberg',
+	'62':'Südwürtemberg',
 	'71':'Bayern',
 	'72':'Berlin',
 	'73':'Saarland',
@@ -1049,41 +1049,41 @@ kvdt_KV_Bereich_map = {
 }
 # Personenkreis / Untersuchungskategorie : 4123
 kvdt_Personenkreis_Untersuchungskategorie_map = {
-	'01':'Beschdigter',
-	'02':'Schwerbeschdigter',
-	'03':'Angehriger',
+	'01':'Beschädigter',
+	'02':'Schwerbeschädigter',
+	'03':'Angehöriger',
 	'04':'Hinterbliebener',
 	'05':'Pflegeperson',
 	'06':'Tauglichkeitsuntersuchung',
-	'07':'rztl. Versorgung',
+	'07':'ärztl. Versorgung',
 	'08':'Bewerber',
 	'09':'Erstuntersuchung',
 	'10':'Nachuntersuchung',
-	'11':'Ergnzungsuntersuchung',
+	'11':'Ergänzungsuntersuchung',
 	'12':'Verfolgte'
 }
 #Unfall, Unfallfolgen : 4202
 kvdt_Unfallfolgen_map = {
 	'1':'ja'
 }
-#belegrztliche Behandlung : 4221
+#belegärztliche Behandlung : 4221
 kvdt_belegaerztliche_Behandlung_map = {
 	'1':'kurativ',
-	'2':'prventiv',
+	'2':'präventiv',
 	'3':'sonstige Hilfen',
-	'4':'bei belegrztlicher Behandlung'
+	'4':'bei belegärztlicher Behandlung'
 }
 # anerkannte Psychotherapie : 4234
 kvdt_anerkannte_Psychotherapie_map = {
 	'1':'ja'
 }
-# Abklrung somatischer Ursachen : 4236
+# Abklärung somatischer Ursachen : 4236
 kvdt_somatische_Ursachen_map = {
 	'1':'ja'
 }
-# GNR-Zusatzkennzeichen fr poststationr erbrachte Leistungen : 5024
+# GNR-Zusatzkennzeichen für poststationär erbrachte Leistungen : 5024
 kvdt_Zusatzkennzeichen_poststationaere_Leistungen_map = {
-	'N':'poststationre Leistung'	
+	'N':'poststationäre Leistung'	
 }
 # Diagnosensicherheit : 6003
 kvdt_Diagnosensicherheit_map = {
@@ -1097,29 +1097,29 @@ kvdt_Seitenlokalisation_map = {
 	'L':'Links',
 	'B':'beiderseits'
 }
-# Empfnger : 9102
+# Empfänger : 9102
 kvdt_Empfaenger_map = {
 	'01':'Schleswig-Holstein',
 	'02':'Hamburg',
 	'03':'Bremen',
 	'06':'Aurich',
 	'07':'Braunschweig',
-	'08':'Gttingen',
+	'08':'Göttingen',
 	'09':'Hannover',
 	'10':'Hildesheim',
-	'11':'Lneburg',
+	'11':'Lüneburg',
 	'12':'Oldenburg',
-	'13':'Osnabrck',
+	'13':'Osnabrück',
 	'14':'Stade',
 	'15':'Verden',
 	'16':'Wilhelmshaven',
 	'18':'Dortmund',
-	'19':'Mnster',
+	'19':'Münster',
 	'20':'KV Westfalen Lippe',
 	'21':'Aachen',
-	'24':'Dsseldorf',
+	'24':'Düsseldorf',
 	'25':'Duisburg',
-	'27':'Kln',
+	'27':'Köln',
 	'28':'Linker Niederrhein',
 	'31':'Ruhr',
 	'37':'Bergisch-Land',
@@ -1141,9 +1141,9 @@ kvdt_Empfaenger_map = {
 	'57':'Freiburg',
 	'58':'Konstanz',
 	'59':'Offenburg',
-	'61':'Nord-Wrtemberg',
-	'62':'Sd-Wrtemberg',
-	'63':'Mnchen Sadt u. Land',
+	'61':'Nord-Würtemberg',
+	'62':'Süd-Würtemberg',
+	'63':'München Sadt u. Land',
 	'64':'Oberbayern',
 	'65':'Oberfranken',
 	'66':'Mittelfranken',
@@ -1173,10 +1173,10 @@ kvdt_Facharztstatus_map = {
 	'0':'nein',
 	'1':'ja'	
 }
-# Ansthesie erbracht : 2761
+# Anästhesie erbracht : 2761
 kvdt_Anaesthesie_erbracht_map = {
 	'1':'vom Operateur',
-	'2':'vom Ansthesisten'
+	'2':'vom Anästhesisten'
 }
 # Blutung : 2770-2776,2720-2726
 kvdt_Zwischenfall_map = {
@@ -1194,18 +1194,18 @@ kvdt_Histologie_map = {
 	'0':'nein',
 	'1':'ja'
 }
-# stationre Weiterbehandlung erforderlich : 2782
+# stationäre Weiterbehandlung erforderlich : 2782
 kvdt_stationaere_Weiterbehandlung_map = {
 	'1':'unmittelbare Aufnahme zur Weiterbehandlung',
-	'2':'stationre Aufnahme zur Weiterbehandlung bis zum 12.Tag'
+	'2':'stationäre Aufnahme zur Weiterbehandlung bis zum 12.Tag'
 }
-# stationre Aufnahme : 2731
+# stationäre Aufnahme : 2731
 kvdt_stationaere_Aufnahme_map = {
 	'0':'nein',
 	'1':'unmittelbare Aufnahme zur Weiterbehandlung',
-	'2':'stationre Aufnahme zur Weiterbehandlung bis zum 12.Tag'
+	'2':'stationäre Aufnahme zur Weiterbehandlung bis zum 12.Tag'
 }
-# Indikationsschlssel : 2706
+# Indikationsschlüssel : 2706
 kvdt_Indikationsschluessel_map = {
 	'0':'keine Angabe'
 }
@@ -1246,29 +1246,29 @@ kvdt_operierte_Seite_map = {
 	'2':'rechts',
 	'3':'beidseitig'
 }
-# Art der Ansthesie gem Klassifikation Strukturvertrag : 2744
+# Art der Anästhesie gemäß Klassifikation Strukturvertrag : 2744
 kvdt_Anaesthesie_Art_map = {
 	'1':'Intubationsnarkose',
-	'2':'Spinalansthesie',
+	'2':'Spinalanästhesie',
 	'3':'Maskennarkose',
 	'4':'Stand-By',
-	'5':'Plexusansthesie',
-	'6':'Periduralansthesie',
-	'7':'intravense Region',
-	'8':'Lokalansthesie',
-	'9':'Retrobulbr-/Peribulbransthesie'
+	'5':'Plexusanästhesie',
+	'6':'Periduralanästhesie',
+	'7':'intravenöse Region',
+	'8':'Lokalanästhesie',
+	'9':'Retrobulbär-/Peribulbäranästhesie'
 }
 # Kurart : 4261
 kvdt_Kurart_map = {
-	'1':'Ambulante Vorsorgeleistung zur Krankheitsverhtung',
+	'1':'Ambulante Vorsorgeleistung zur Krankheitsverhütung',
 	'2':'Ambulante Vorsorgeleistung bei bestehenden Krankheiten',
-	'3':'Ambulante Vorsorgeleistung fr Kinder'
+	'3':'Ambulante Vorsorgeleistung für Kinder'
 }
-# Packungsgre bei Kassenrezept und Privatrezept : 0917,0918
+# Packungsgröße bei Kassenrezept und Privatrezept : 0917,0918
 kvdt_Packungsgroesse_map = {
 	'N1':'Kleine Packung',
 	'N2':'Mittlere Packung',
-	'N3':'Groe Packung',
+	'N3':'Große Packung',
 	'kA':'keine Angabe'
 }
 # Heilmittel : 0925
@@ -1277,19 +1277,19 @@ kvdt_Packungsgroesse_map = {
 #	'02':'Bewegungstherapie',
 #	'03':'Krankengymnastik',
 #	'04':'Elektrotherapie',
-#	'06':'Thermotherapie(Wrme- und Kltetherapie)',
-#	'08':'Kohlensurebder',
+#	'06':'Thermotherapie(Wärme- und Kältetherapie)',
+#	'08':'Kohlensäurebäder',
 #	'09':'Inhalalationtherapie',
 #	'10':'Traktionsbehandlung',
 #	'20':'Stimmtherapie',
 #	'25':'Sprechtherapie',
 #	'30':'Sprachtherapie',
 #	'35':'Sprech- und/oder Sprachtherapie bei Kindern und Jugendlichen',
-#	'40':'Beschftigungs- und Arbeitstherapie (Ergotherapie)',
+#	'40':'Beschäftigungs- und Arbeitstherapie (Ergotherapie)',
 #	'90':'Sonstiges',
 #}
 
-# Kennzeichnung gebhrenpflichtig, aut idem, noctu
+# Kennzeichnung gebührenpflichtig, aut idem, noctu
 kvdt_Kennzeichnung_map = {
 	'0':'nein',
 	'1':'ja'
@@ -1391,6 +1391,15 @@ def xdt_8date2iso(date=None):
 	return '%s-%s-%s' % (date[-4:], date[2:4], date[:2])
 #==============================================================
 # $Log: gmXdtMappings.py,v $
+# Revision 1.40  2007/05/14 10:37:31  ncq
+# - recoded to utf8
+#
+# Revision 1.39  2007/03/10 15:13:05  ncq
+# - improved mappings, added code 3600
+#
+# Revision 1.38  2007/02/21 10:29:43  ncq
+# - map_gender_gm2xdt
+#
 # Revision 1.37  2007/01/21 15:13:46  ncq
 # - add a few more codes
 #
