@@ -10,16 +10,19 @@ TODO:
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/exporters/gmPatientExporter.py,v $
-# $Id: gmPatientExporter.py,v 1.96 2007/01/18 22:03:58 ncq Exp $
-__version__ = "$Revision: 1.96 $"
+# $Id: gmPatientExporter.py,v 1.106 2007/05/21 14:46:44 ncq Exp $
+__version__ = "$Revision: 1.106 $"
 __author__ = "Carlos Moro"
 __license__ = 'GPL'
 
-import os.path, sys, traceback, string, types, time, codecs
+import os.path, sys, traceback, string, types, time, codecs, datetime as pyDT, locale
 
 import mx.DateTime.Parser as mxParser
 import mx.DateTime as mxDT
 
+if __name__ == '__main__':
+	sys.path.insert(0, '../../')
+
 from Gnumed.pycommon import gmLog, gmI18N, gmCLI, gmCfg, gmExceptions, gmNull, gmPG2, gmTools
 from Gnumed.business import gmClinicalRecord, gmPerson, gmAllergy, gmMedDoc, gmDemographicRecord
 
@@ -88,17 +91,14 @@ class cEmrExport:
             return
         self.__patient = patient
     #--------------------------------------------------------
-    def set_output_file(self, file_name=None):
+    def set_output_file(self, target=None):
         """
             Sets exporter output file
             
             @param file_name - The file to dump the EMR to
             @type file_name - FileType
         """
-        if not isinstance(file_name, types.FileType) :
-            _log.Log(gmLog.lErr, "can't set output file [%s] for exporter" % file_name)
-            return
-        self.__target = file_name
+        self.__target = target
     #--------------------------------------------------------
     def get_patient(self):
         """
@@ -119,8 +119,7 @@ class cEmrExport:
         emr = self.__patient.get_emr()
         # patient dob
         
-        #patient_dob = mxParser.DateFromString(self.__patient.get_identity().getDOB(aFormat = 'YYYY-MM-DD'), formats= ['iso']) 
-        patient_dob = self.__patient.get_identity()['dob']
+        patient_dob = self.__patient['dob']
         date_length = len(patient_dob.strftime('%Y-%m-%d')) + 2 # (YYYY-mm-dd)
 
         # dictionary of pairs indication : scheduled vaccination
@@ -328,7 +327,7 @@ class cEmrExport:
         for a_field in field_list:
             if type(a_field) is not types.UnicodeType:
                 a_field = unicode(a_field, encoding='latin1', errors='replace')
-            txt += u'%s%s%s' % ((offset * u' '), a_field, gmTools.coalesce(item[a_field], u'', template = u': %s\n'))
+            txt += u'%s%s%s' % ((offset * u' '), a_field, gmTools.coalesce(item[a_field], u'\n', template_initial = u': %s\n'))
         return txt
     #--------------------------------------------------------
     def get_allergy_output(self, allergy, left_margin = 0):
@@ -515,18 +514,17 @@ class cEmrExport:
             emr_tree.SetPyData(issue_node, a_health_issue)
             episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk']])
             for an_episode in episodes:
-	       self._add_episode_to_tree( emr, emr_tree, issue_node,a_health_issue,  an_episode)
-
-
+                self._add_episode_to_tree( emr, emr_tree, issue_node,a_health_issue,  an_episode)
     #--------------------------------------------------------             
     def _add_episode_to_tree( self, emr , emr_tree, issue_node, a_health_issue, an_episode):
-               episode_node =  emr_tree.AppendItem(issue_node, an_episode['description'])
-               emr_tree.SetPyData(episode_node, an_episode)
-#	       encounters = self._get_encounters( a_health_issue, an_episode, emr )
-	       encounters = self._get_encounters( an_episode, emr )
-	       self._add_encounters_to_tree( encounters,  emr_tree, episode_node )
-	       return episode_node
-	       
+        episode_node =  emr_tree.AppendItem(issue_node, an_episode['description'])
+        emr_tree.SetPyData(episode_node, an_episode)
+        if an_episode['episode_open']:
+            emr_tree.SetItemBold(issue_node, True)
+#       encounters = self._get_encounters( a_health_issue, an_episode, emr )
+        encounters = self._get_encounters( an_episode, emr )
+        self._add_encounters_to_tree( encounters,  emr_tree, episode_node )
+        return episode_node
     #--------------------------------------------------------             
     def _add_encounters_to_tree( self, encounters, emr_tree, episode_node):
                for an_encounter in encounters:
@@ -680,7 +678,7 @@ class cEmrExport:
         last_encounter = emr.get_last_encounter(issue_id = issue['pk'])
         if first_encounter is None or last_encounter is None:
             txt += _('%s%s episode(s)\n\n%sNo encounters found for this health issue.\n') % (
-                left_margin * ' ' +
+                left_margin * ' ',
                 str(no_epis),
                 left_margin * ' ')
             return txt
@@ -895,8 +893,7 @@ class cEmrExport:
         """
             Dumps in ASCII format some basic patient's demographic data
         """
-        ident = self.__patient.get_identity()
-        if ident is None:
+        if self.__patient is None:
             _log.Log(gmLog.lErr, 'cannot get Demographic export')
             print(_(
                 'An error occurred while Demographic record export\n'
@@ -906,18 +903,18 @@ class cEmrExport:
 
         self.__target.write('\n\n\nDemographics')
         self.__target.write('\n------------\n')
-        self.__target.write('    Id: %s \n' % ident.getId())
+        self.__target.write('    Id: %s \n' % self.__patient['pk_identity'])
         cont = 0
-        for name in ident.get_all_names():
+        for name in self.__patient.get_all_names():
             if cont == 0:
                 self.__target.write('    Name (Active): %s, %s\n' % (name['first'], name['last']) )
             else:
                 self.__target.write('    Name %s: %s, %s\n' % (cont, name['first'], name['last']))
             cont += 1
-        self.__target.write('    Gender: %s\n' % ident['gender'])
-        self.__target.write('    Title: %s\n' % ident['title'])
-        self.__target.write('    Dob: %s\n' % ident['dob'].strftime('%Y-%m-%d'))
-        self.__target.write('    Medical age: %s\n' % gmPerson.dob2medical_age(ident['dob']))
+        self.__target.write('    Gender: %s\n' % self.__patient['gender'])
+        self.__target.write('    Title: %s\n' % self.__patient['title'])
+        self.__target.write('    Dob: %s\n' % self.__patient['dob'].strftime('%Y-%m-%d'))
+        self.__target.write('    Medical age: %s\n' % gmPerson.dob2medical_age(self.__patient['dob']))
     #--------------------------------------------------------
     def dump_constraints(self):
         """
@@ -964,14 +961,7 @@ class cEMRJournalExporter:
 
 	Note that this export will emit u'' strings only.
 	"""
-	def __init__(self, patient=None):
-		if patient is None:
-			self.__pat = gmPerson.gmCurrentPatient()
-		else:
-			if not isinstance(patient, gmPerson.cPerson):
-				raise gmExceptions.ConstructorError, '<patient> argument must be instance of <cPerson>, but is: %s' % type(gmPerson.cPerson)
-			self.__pat = patient
-
+	def __init__(self):
 		self.__part_len = 72
 		self.__tx_soap = {
 			u's': _('S'),
@@ -982,39 +972,53 @@ class cEMRJournalExporter:
 	#--------------------------------------------------------
 	# external API
 	#--------------------------------------------------------
-	def export_to_file(self, filename=None):
-		if not self.__pat.is_connected():
-			return (False, u'no active patient')
+	def export_to_file(self, filename=None, patient=None):
+		"""
+		Export medical record into a file.
+
+		@type filename: None (creates filename by itself) or string
+		@type patient: None (use currently active patient) or <gmPerson.cIdentity> instance
+		"""
+		if patient is None:
+			patient = gmPerson.gmCurrentPatient()
+			if not patient.is_connected():
+				raise ValueError('[%s].export_to_file(): no active patient' % self.__class__.__name__)
+
 		if filename is None:
-			ident = self.__pat.get_identity()
-			path = os.path.expanduser(os.path.join('~', 'gnumed', 'export'))
 			filename = u'%s-%s-%s-%s.txt' % (
-				os.path.join(path, _('emr-journal')),
-				ident['lastnames'].replace(u' ', u'-'),
-				ident['firstnames'].replace(u' ', u'_'),
-				ident['dob'].strftime('%Y-%m-%d')
+				_('emr-journal'),
+				patient['lastnames'].replace(u' ', u'_'),
+				patient['firstnames'].replace(u' ', u'_'),
+				patient['dob'].strftime('%Y-%m-%d')
 			)
-		f = codecs.open(filename = filename, mode = 'w+b', encoding = 'utf8')
-		status = self.__export(target = f)
+			path = os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'EMR', patient['dirname'], filename))
+
+		f = codecs.open(filename = filename, mode = 'w+b', encoding = 'utf8', errors = 'replace')
+		self.export(target = f, patient = patient)
 		f.close()
-		return (status, filename)
+		return filename
 	#--------------------------------------------------------
-	def export(self, target):
-		return self.__export(target)
+	# internal API
 	#--------------------------------------------------------
-	# interal API
-	#--------------------------------------------------------
-	def __export(self, target = None):
-		if not self.__pat.is_connected():
-			return False
-		ident = self.__pat.get_identity()
+	def export(self, target=None, patient=None):
+		"""
+		Export medical record into a Python object.
+
+		@type target: a python object supporting the write() API
+		@type patient: None (use currently active patient) or <gmPerson.cIdentity> instance
+		"""
+		if patient is None:
+			patient = gmPerson.gmCurrentPatient()
+			if not patient.is_connected():
+				raise ValueError('[%s].export(): no active patient' % self.__class__.__name__)
+
 		# write header
 		txt = _('Chronological EMR Journal\n')
 		target.write(txt)
 		target.write(u'=' * (len(txt)-1))
 		target.write('\n')
-		target.write(_('Patient: %s (%s), No: %s\n') % (ident['description'], ident['gender'], self.__pat['ID']))
-		target.write(_('Born   : %s, age: %s\n\n') % (ident['dob'].strftime('%Y-%m-%d'), ident.get_medical_age()))
+		target.write(_('Patient: %s (%s), No: %s\n') % (patient['description'], patient['gender'], patient['pk_identity']))
+		target.write(_('Born   : %s, age: %s\n\n') % (patient['dob'].strftime('%Y-%m-%d'), patient.get_medical_age()))
 		target.write(u'.-%10.10s---%9.9s-------%72.72s\n' % (u'-' * 10, u'-' * 9, u'-' * self.__part_len))
 		target.write(u'| %10.10s | %9.9s |   | %s\n' % (_('Date'), _('Doc'), _('Narrative')))
 		target.write(u'|-%10.10s---%9.9s-------%72.72s\n' % (u'-' * 10, u'-' * 9, u'-' * self.__part_len))
@@ -1026,7 +1030,7 @@ select
 	(select rank from clin.soap_cat_ranks where soap_cat=vemrj.soap_cat) as scr
 from clin.v_emr_journal vemrj
 where pk_patient=%s order by date, pk_episode, scr"""
-		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.__pat['ID']]}], get_col_idx = True)
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [patient['pk_identity']]}], get_col_idx = True)
 		# write data
 		prev_date = u''
 		prev_doc = u''
@@ -1067,8 +1071,9 @@ where pk_patient=%s order by date, pk_episode, scr"""
 				target.write(line)
 		# write footer
 		target.write(u'`-%10.10s---%9.9s-------%72.72s\n\n' % (u'-' * 10, u'-' * 9, u'-' * self.__part_len))
-		target.write(_('Exported: %s\n') % time.asctime())
-		return True
+		target.write(_('Exported: %s\n') % pyDT.datetime.now().strftime('%c').decode(gmI18N.get_encoding()))
+
+		return
 #============================================================
 class cMedistarSOAPExporter:
 	"""Export SOAP data per encounter into Medistar import format."""
@@ -1076,8 +1081,8 @@ class cMedistarSOAPExporter:
 		if patient is None:
 			self.__pat = gmPerson.gmCurrentPatient()
 		else:
-			if not isinstance(patient, gmPerson.cPerson):
-				raise gmExceptions.ConstructorError, '<patient> argument must be instance of <cPerson>, but is: %s' % type(gmPerson.cPerson)
+			if not isinstance(patient, gmPerson.cIdentity):
+				raise gmExceptions.ConstructorError, '<patient> argument must be instance of <cIdentity>, but is: %s' % type(patient)
 			self.__pat = patient
 		self.__tx_soap = {
 			's': 'A',
@@ -1092,14 +1097,13 @@ class cMedistarSOAPExporter:
 		if not self.__pat.is_connected():
 			return (False, 'no active patient')
 		if filename is None:
-			ident = self.__pat.get_identity()
 			path = os.path.abspath(os.path.expanduser('~/gnumed/export'))
 			filename = '%s-%s-%s-%s-%s.txt' % (
 				os.path.join(path, 'Medistar-MD'),
 				time.strftime('%Y-%m-%d',time.localtime()),
-				ident['lastnames'].replace(' ', '-'),
-				ident['firstnames'].replace(' ', '_'),
-				ident['dob'].strftime('%Y-%m-%d')
+				self.__pat['lastnames'].replace(' ', '-'),
+				self.__pat['firstnames'].replace(' ', '_'),
+				self.__pat['dob'].strftime('%Y-%m-%d')
 			)
 		f = codecs.open(filename = filename, mode = 'w+b', encoding = 'utf8')
 		status = self.__export(target = f)
@@ -1120,7 +1124,7 @@ class cMedistarSOAPExporter:
 		# get data
 		cmd = u"select narrative from clin.v_emr_journal where pk_patient=%s and pk_encounter=%s and soap_cat=%s"
 		for soap_cat in 'soap':
-			rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': (self.__pat['ID'], encounter['pk_encounter'], soap_cat)}])
+			rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': (self.__pat['pk_identity'], encounter['pk_encounter'], soap_cat)}])
 			target.write('*MD%s*\n' % self.__tx_soap[soap_cat])
 			for row in rows:
 				text = row[0]
@@ -1197,9 +1201,9 @@ def run():
         if patient is None:
             break
         # FIXME: needed ?
-        gmPerson.set_active_patient(patient=patient)
+#        gmPerson.set_active_patient(patient=patient)
         exporter = cEMRJournalExporter()
-        exporter.export_to_file()
+        exporter.export_to_file(patient=patient)
 #        export_tool.set_patient(patient)
         # Dump patient EMR sections
 #        export_tool.dump_constraints()
@@ -1215,32 +1219,81 @@ def run():
             patient.cleanup()
         except:
             print "error cleaning up patient"
+#============================================================
+# main
 #------------------------------------------------------------
 if __name__ == "__main__":
-    gmI18N.activate_locale()
-    gmI18N.install_domain()
+	gmI18N.activate_locale()
+	gmI18N.install_domain()
 
-    gmLog.gmDefLog.SetAllLogLevels(gmLog.lData)
+	gmLog.gmDefLog.SetAllLogLevels(gmLog.lData)
 
-    print "\n\nGNUmed ASCII EMR Export"
-    print     "======================="
+	#--------------------------------------------------------
+	def export_journal():
 
-    if gmCLI.has_arg('--help'):
-        usage()
+		print "Exporting EMR journal(s) ..."
+		pat_searcher = gmPerson.cPatientSearcher_SQL()
+		while True:
+			patient = gmPerson.ask_for_patient()
+			if patient is None:
+				break
+
+			exporter = cEMRJournalExporter()
+			print "exported into file:", exporter.export_to_file(patient=patient)
+
+			if patient is not None:
+				try:
+					patient.cleanup()
+				except:
+					print "error cleaning up patient"
+		print "Done."
+	#--------------------------------------------------------
+	print "\n\nGNUmed ASCII EMR Export"
+	print     "======================="
+
+	if gmCLI.has_arg('--help'):
+		usage()
+
+	# run main loop
+	export_journal()
 
-    # run main loop
-    try:
-        run()
-    except StandardError:
-        traceback.print_exc(file=sys.stdout)
-        _log.LogException('unhandled exception caught', sys.exc_info(), verbose=1)
-    try:
-        pool.StopListeners()
-    except:
-        traceback.print_exc(file=sys.stdout)
-        _log.LogException('unhandled exception caught', sys.exc_info(), verbose=1)
 #============================================================
 # $Log: gmPatientExporter.py,v $
+# Revision 1.106  2007/05/21 14:46:44  ncq
+# - use patient['dirname']
+#
+# Revision 1.105  2007/05/14 13:09:04  ncq
+# - use bold on health issues with open episodes
+#
+# Revision 1.104  2007/04/01 15:25:55  ncq
+# - safely get encoding
+#
+# Revision 1.103  2007/03/02 15:30:00  ncq
+# - decode() strftime() output
+#
+# Revision 1.102  2007/02/22 17:30:48  ncq
+# - no more get_identity()
+# - patient now cIdentity() child
+#
+# Revision 1.101  2007/02/19 17:54:06  ncq
+# - need to return True when successful
+#
+# Revision 1.100  2007/02/19 16:56:05  ncq
+# - properly check for is_connected()
+#
+# Revision 1.99  2007/02/19 14:07:31  ncq
+# - fix format string parameters
+#
+# Revision 1.98  2007/02/17 14:10:03  ncq
+# - use improved gmTools.coalesce()
+#
+# Revision 1.97  2007/02/10 23:41:38  ncq
+# - fix loading of GNUmed python modules
+# - cleaned up journal exporter
+# - fixed bug in journal exporter where it expected is_connected()
+#   in non-gmCurrentPatient-using context, too
+# - when run standalone: export journal
+#
 # Revision 1.96  2007/01/18 22:03:58  ncq
 # - a bit of cleanup
 #
