@@ -1,10 +1,7 @@
 #!/bin/sh
 
 # $Source: /sources/gnumed/gnumed/gnumed/client/gm-from-cvs.sh,v $
-# $Revision: 1.7 $
-
-# start kvkd
-# FIXME: needs logic to prevent more than one kvkd from running
+# $Revision: 1.8 $
 
 # maybe force some locale setting here
 #export LANG=fr
@@ -16,17 +13,10 @@ cd ../
 ln -vfsn client Gnumed
 cd -
 export PYTHONPATH="${PYTHONPATH}:../"
+
 LOG="gm-from-cvs.log"
 rm -vf $LOG
 
-# prepare
-CONF="gm-from-cvs.conf"
-cp -vf $CONF tmp-$CONF
-
 # run
-python wxpython/gnumed.py --log-file=$LOG --conf-file=tmp-$CONF --debug --override-schema-check
+python wxpython/gnumed.py --log-file=$LOG --conf-file=gm-from-cvs.conf --debug --override-schema-check
 # --profile=gm-from-cvs.prof
-
-# clean up
-rm -vf tmp-$CONF
-rm -vf tmp-$CONF.gmCfg.bak
