@@ -96,14 +96,18 @@ http://archives.postgresql.org/pgsql-general/2004-10/msg01352.php
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmBusinessDBObject.py,v $
-# $Id: gmBusinessDBObject.py,v 1.34 2006/07/19 20:27:03 ncq Exp $
-__version__ = "$Revision: 1.34 $"
+# $Id: gmBusinessDBObject.py,v 1.42 2007/05/21 14:47:22 ncq Exp $
+__version__ = "$Revision: 1.42 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
 import sys, copy, types, inspect
 
-from Gnumed.pycommon import gmExceptions, gmLog, gmPG
+
+if __name__ == '__main__':
+	sys.path.insert(0, '../../')
+from Gnumed.pycommon import gmExceptions, gmLog, gmPG2
+
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
@@ -121,71 +125,45 @@ class cBusinessDBObject:
 	- does NOT create new entries in the database
 	- does NOT lazy-fetch fields on access
 
-	Class scope SQL commands:
+	Class scope SQL commands and variables:
+
 	<_cmd_fetch_payload>
 		- must return exactly one row
 		- where clause argument values are expected
-		  in self._pk_obj (taken from __init__(aPK_obj))
+		  in self.pk_obj (taken from __init__(aPK_obj))
 		- must return xmin of all rows that _cmds_store_payload
-		  will be updating
+		  will be updating, so views must support the xmin columns
+		  of their underlying tables
+
+	<_cmds_store_payload>
+		- one or multiple "update ... set ... where xmin_* = ..." statements
+		  which actually update the database from the data in self._payload,
+		- the last query must refetch the XMIN values needed to detect
+		  concurrent updates, their field names had better be the same as
+		  in _cmd_fetch_payload
+
+	<_updatable_fields>
+		- a list of fields available for update via object['field']
+
 	"""
-	_conn_pool = None
 	#--------------------------------------------------------
 	def __init__(self, aPK_obj=None, row=None):
 		"""Init business object.
 		"""
 		self._is_modified = False
 		# check descendants
-		#<DEBUG>
 		self.__class__._cmd_fetch_payload
-			# must fetch xmin ! (and the view must support that ...)
-		self.__class__._cmds_lock_rows_for_update
-			# must do "select for update" and use xmin in where clause,
-			# each query must return exactly 1 row
 		self.__class__._cmds_store_payload
-			# one or multiple "update ... set ..." statements which
-			# actually update the database from the data in self._payload,
-			# the last query must refetch the XMIN values needed to detect
-			# concurrent updates, their field names had better be the same as
-			# in _cmd_fetch_payload
 		self.__class__._updatable_fields
-			# a list of fields available to users via object['field']
-		self.__class__._service
-			# the service in which our source relation is found,
-			# this is used for establishing connections
-		# FIXME: if you want this check to be done please update all the child classes, too
-#		self.__class__._subtable_dml_templates
-			# a dictionary of subtables by name,
-			# values are dictionaries  of 3 queries keyed 'select', 'insert' and 'delete',
-			#
-			# The 'select' query accepts one parameter (this object's primary
-			# key) and returns some rows. One column in which must be 'pk'.
-			# These rows, as dictionaries, are avaiable as attributes of the
-			# business object, by the name of the key in _subtable_dml_templates.
-			#
-			# The 'insert' query is called by add_to_subtable(). It must have
-			# %(labelled)s parameters for the columns to insert into from
-			# the dictionary passed to add_to_subtable(). 'pk_master' is also
-			# available in this dictionary, being the primary key of the
-			# 'master' table.
-			#
-			# The 'delete' is called from del_from_subtable(). Two parameters
-			# in the order: pk for the master object and pk of the
-			# subtable row to be deleted.
-		#</DEBUG>
 		self._payload = []		# the cache for backend object values (mainly table fields)
 		self._ext_cache = {}	# the cache for extended method's results
 		self._idx = {}
-		self._subtable_cmd_queue = []		# must be suitable to be passed as <queries> argument to gmPG.run_commit2()
-		if cBusinessDBObject._conn_pool is None:
-			# once for ALL descendants :-)
-			cBusinessDBObject._conn_pool = gmPG.ConnectionPool()
+
 		if aPK_obj is not None:
 			self.__init_from_pk(aPK_obj=aPK_obj)
 		else:
 			self._init_from_row_data(row=row)
 		self._is_modified = False
-#		self._flagged = False
 	#--------------------------------------------------------
 	def __init_from_pk(self, aPK_obj=None):
 		"""Creates a new clinical item instance by its PK.
@@ -249,37 +227,14 @@ class cBusinessDBObject:
 	#--------------------------------------------------------
 	def __getitem__(self, attribute):
 		# use try: except: as it is faster and we want this as fast as possible
+
 		# 1) backend payload cache
 		try:
 			return self._payload[self._idx[attribute]]
 		except KeyError:
 			pass
-		# 2) cached extension method results ...
-		try:
-			return self._ext_cache[attribute] # FIXME: when do we evict this cache ?
-		except KeyError:
-			pass
-		# 3) subtable
-		try:
-			subtable = self._subtable_dml_templates[attribute]
-			try:
-				query = subtable['select']
-				rows, idx = gmPG.run_ro_query(self.__class__._service, query, True, self.pk_obj)
-				if rows is not None:
-					self._ext_cache[attribute] = [dict([(name, row[i]) for name, i in idx.items()]) for row in rows]
-					return self._ext_cache[attribute]
-				_log.Log(gmLog.lErr, '[%s:%s]: error getting subtable [%s] values' % (self.__class__.__name__, self.pk_obj, attribute))
-				# FIXME: should actually fail and return appropriate error
-			except KeyError:
-				_log.LogException('[%s:%s]: subtable support error, no "select" for subtable [%s]' % (self.__class__.__name__, self.pk_obj, attribute), sys.exc_info(), verbose=0)
-				# FIXME: should actually fail and return appropriate error
-				pass
-		except (KeyError, AttributeError):
-			# either
-			# - no subtable support (no attribute _subtable_dml_templates)
-			# - or no known subtable <attribute>
-			pass
-		# 4) getters providing extensions
+
+		# 2) extension method results ...
 		getter = getattr(self, 'get_%s' % attribute, None)
 		if not callable(getter):
 			_log.Log(gmLog.lWarn, '[%s]: no attribute [%s]' % (self.__class__.__name__, attribute))
@@ -288,10 +243,12 @@ class cBusinessDBObject:
 			methods = filter(lambda x: x[0].startswith('get_'), inspect.getmembers(self, inspect.ismethod))
 			_log.Log(gmLog.lWarn, '[%s]: valid getter methods: %s' % (self.__class__.__name__, str(methods)))
 			raise gmExceptions.NoSuchBusinessObjectAttributeError, '[%s]: cannot access [%s]' % (self.__class__.__name__, attribute)
+
 		self._ext_cache[attribute] = getter()
 		return self._ext_cache[attribute]
 	#--------------------------------------------------------
 	def __setitem__(self, attribute, value):
+
 		# 1) backend payload cache
 		if attribute in self.__class__._updatable_fields:
 			try:
@@ -303,6 +260,7 @@ class cBusinessDBObject:
 				_log.Log(gmLog.lWarn, '[%s]: cannot set attribute <%s> despite marked settable' % (self.__class__.__name__, attribute))
 				_log.Log(gmLog.lWarn, '[%s]: supposedly settable attributes: %s' % (self.__class__.__name__, str(self.__class__._updatable_fields)))
 				raise gmExceptions.NoSuchBusinessObjectAttributeError, '[%s]: cannot access [%s]' % (self.__class__.__name__, attribute)
+
 		# 2) setters providing extensions
 		if hasattr(self, 'set_%s' % attribute):
 			setter = getattr(self, "set_%s" % attribute)
@@ -320,6 +278,7 @@ class cBusinessDBObject:
 			if setter(value):
 				self._is_modified = True
 				return
+
 		# 3) don't know what to do with <attribute>
 		_log.Log(gmLog.lErr, '[%s]: cannot find attribute <%s> or setter method [set_%s]' % (self.__class__.__name__, attribute, attribute))
 		_log.Log(gmLog.lWarn, '[%s]: settable attributes: %s' % (self.__class__.__name__, str(self.__class__._updatable_fields)))
@@ -348,19 +307,18 @@ class cBusinessDBObject:
 		if self._is_modified:
 			_log.Log(gmLog.lPanic, '[%s:%s]: cannot reload, payload changed' % (self.__class__.__name__, self.pk_obj))
 			return False
-		data, self._idx = gmPG.run_ro_query (
-			self.__class__._service,
-			self.__class__._cmd_fetch_payload,
-			True,
-			self.pk_obj
+		if type(self.pk_obj) == types.DictType:
+			arg = self.pk_obj
+		else:
+			arg = [self.pk_obj]
+		rows, self._idx = gmPG2.run_ro_queries (
+			queries = [{'cmd': self.__class__._cmd_fetch_payload, 'args': arg}],
+			get_col_idx = True
 		)
-		if data is None:
-			_log.Log(gmLog.lErr, '[%s:%s]: error retrieving instance' % (self.__class__.__name__, self.pk_obj))
-			return False
-		if len(data) == 0:
+		if len(rows) == 0:
 			_log.Log(gmLog.lErr, '[%s:%s]: no such instance' % (self.__class__.__name__, self.pk_obj))
 			return False
-		self._payload = data[0]
+		self._payload = rows[0]
 		return True
 	#--------------------------------------------------------
 	def __noop(self):
@@ -374,80 +332,34 @@ class cBusinessDBObject:
 		- True: success
 		- False: an error occurred
 			* data is (error, message)
-			* for error meanings see gmPG.run_commit2()
+			* for error meanings see gmPG2.run_rw_queries()
 		"""
 		if not self._is_modified:
 			return (True, None)
-		params = {}
+
+		args = {}
 		for field in self._idx.keys():
-			params[field] = self._payload[self._idx[field]]
-		self.modified_payload = params
+			args[field] = self._payload[self._idx[field]]
+		self.modified_payload = args
+
 		close_conn = self.__noop
 		if conn is None:
-			conn = self.__class__._conn_pool.GetConnection(self.__class__._service, readonly=0)
+			conn = gmPG2.get_connection(readonly=False)
 			close_conn = conn.close
-		if conn is None:
-			_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance' % (self.__class__.__name__, self.pk_obj))
-			return (False, (1, _('Cannot connect to database.')))
 
-		# try to lock rows
-		for query in self.__class__._cmds_lock_rows_for_update:
-			successful, result = gmPG.run_commit2(link_obj = conn, queries = [(query, [params])], extra_verbose = False)
-			# error
-			if not successful:
-				conn.rollback()
-				close_conn()
-				_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance, error locking row' % (self.__class__.__name__, self.pk_obj))
-				return (False, result)
-			# query succeeded but failed to find the row to lock
-			# because another transaction committed an UPDATE or
-			# DELETE *before* we attempted to lock it ...
-			# FIXME: this can fail if savepoints are used since subtransactions change the xmin/xmax ...
-			data, idx = result
-			if len(data) == 0:
-				conn.rollback()
-				close_conn()
-				_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance, concurrency conflict (lock query succeeded but did not find row to lock)' % (self.__class__.__name__, self.pk_obj))
-				_log.Log(gmLog.lErr, query)
-				_log.Log(gmLog.lErr, params)
-				# store current content so user can still play with it ...
-				self.modified_payload = params
-				# update from backend
-				self._is_modified = False
-				if self.refetch_payload():
-					return (False, (2, 'c'))
-				else:
-					return (False, (2, 'd'))
-			# uh oh
-			if len(data) > 1:
-				conn.rollback()
-				close_conn()
-				_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance, deep sh*t' % (self.__class__.__name__, self.pk_obj))
-				_log.Log(gmLog.lPanic, '[%s:%s]: integrity violation, more than one matching row' % (self.__class__.__name__, self.pk_obj))
-				_log.Log(gmLog.lPanic, 'HINT: shut down application and backup database immediately')
-				_log.Log(gmLog.lErr, query)
-				_log.Log(gmLog.lErr, params)
-				return (False, (1, _('Database integrity violation detected. Immediate shutdown strongly advisable.')))
-		# successfully locked, now actually run update
+		# query succeeded but failed to find the row to lock
+		# because another transaction committed an UPDATE or
+		# DELETE *before* we attempted to lock it ...
+		# FIXME: this can fail if savepoints are used since subtransactions change the xmin/xmax ...
+
 		queries = []
 		for query in self.__class__._cmds_store_payload:
-			queries.append((query, [params]))
-		successful, result = gmPG.run_commit2(link_obj = conn, queries = queries, get_col_idx = True)
-		if not successful:
-			conn.rollback()
-			close_conn()
-			_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance' % (self.__class__.__name__, self.pk_obj))
-			_log.Log(gmLog.lErr, params)
-			return (False, result)
-		rows, idx = result
-		if rows is None:
-			conn.rollback()
-			close_conn()
-			_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance, last query did not return XMIN values' % (self.__class__.__name__, self.pk_obj))
-			return (False, result)
+			queries.append({'cmd': query, 'args': args})
+		rows, idx = gmPG2.run_rw_queries(link_obj = conn, queries=queries, return_data=True, get_col_idx=True)
+
 		# update cached XMIN values
 		row = rows[0]
-		for key in idx.keys():
+		for key in idx:
 			try:
 				self._payload[self._idx[key]] = row[idx[key]]
 			except KeyError:
@@ -456,101 +368,32 @@ class cBusinessDBObject:
 				_log.Log(gmLog.lErr, '[%s:%s]: cannot update instance, XMIN refetch key mismatch on [%s]' % (self.__class__.__name__, self.pk_obj, key))
 				_log.Log(gmLog.lErr, 'payload keys: %s' % str(self._idx))
 				_log.Log(gmLog.lErr, 'XMIN refetch keys: %s' % str(idx))
-				_log.Log(gmLog.lErr, params)
-				return (False, data)
-		# execute cached changes to subtables
-		if len(self._subtable_cmd_queue) > 0:
-			successful, result = gmPG.run_commit2(link_obj = conn, queries=self._subtable_cmd_queue)
-			if not successful:
-				conn.rollback()
-				close_conn()
-				_log.Log(gmLog.lErr, '[%s:%s]: cannot change subtables' % (self.__class__.__name__, self.pk_obj))
-				return (False, result)
-			self._subtable_cmd_queue = []
-		try:
-			conn.commit()
-			close_conn()
-		except:
-			typ, val, tb = sys.exc_info() 
-			return (False, (1, val))
+				_log.Log(gmLog.lErr, args)
+				# FIXME: turn into proper exception
+				return (False, None)
+
+		conn.commit()
+		close_conn()
+
 		self._is_modified = False
 		# update to new "original" payload
 		self.original_payload = {}
 		for field in self._idx.keys():
 			self.original_payload[field] = self._payload[self._idx[field]]
+
 		return (True, None)
-	#----------------------------------------------------
-	def del_from_subtable(self, table, row):
-		"""Delete a row from a subtable.
-
-		1) remove from subtable cache
-		2) queue backend subtable delete for save_payload()
-		"""
-		try:
-			row_count = len(self._ext_cache[table])
-		except KeyError:
-			_log.Log(gmLog.lErr, 'table [%s] not registered as subtable in class [%s]' % (table, self.__class__.__name__))
-			return False
-		for i in range(row_count):
-			if self._ext_cache[table][i]['pk'] == row['pk']:
-				del self._ext_cache[table][i]
-		self._subtable_cmd_queue.append((self._subtable_dml_templates[table]['delete'], [self.pk_obj, row['pk']]))
-		self._is_modified = True
-		return True
-	#-----------------------------------------------------
-	def add_to_subtable(self, table, row):
-		"""Add a row to a subtable.
-
-		1) add to subtable cache
-		2) queue backend subtable insert for save_payload()
-		"""
-		row['pk_master'] = self.pk_obj
-		try:
-			self._ext_cache[table].append(row)
-			self._subtable_cmd_queue.append((self._subtable_dml_templates[table]['insert'], [row]))
-		except KeyError:
-			_log.Log(gmLog.lErr, 'table [%s] not registered as subtable in class [%s]' % (table, self.__class__.__name__))
-			return False
-		self._is_modified = True
-		return True
-	#----------------------------------------------------
-	def sync_subtable(self, table, items):
-		"""FIXME: is this actually used anywhere ?
-
-		Ensures that a new version of the subtable matches whats in the
-		database, adding and deleting as appropriate.
-		"""
-		print "WARNING: %s.sync_subtable() is likely broken" % self.__class__.__name__
-		table_cache = self._ext_cache[table][:]
-		# FIXME: this ain't gonna work as t is undefined
-		# FIXME: leave it in for now so we find out whether this method is used anywhere
-		# FIXME: should be: for row_idx in range (len(table_cache)):
-		for row_idx in range (len(t)):
-			for j in range (items):
-				eqn = 1
-				for k in items[j].keys():
-					if items[j][k] != self._ext_cache[table][row_idx][k]:
-						eqn = 0
-				if eqn: # these dicts are considered equal
-					items[j]['__same'] = 1
-					table_cache[row_idx]['__same'] = 1
-		for i in items:
-			if not i.has_key('__same'):
-				self.add_to_subtable (table, i)
-		for i in table_cache:
-			if not i.has_key('__same'):
-				self.del_from_subtable (table, i)
-
 #============================================================
 if __name__ == '__main__':
+	from Gnumed.pycommon import gmI18N
+	gmI18N.activate_locale()
+	gmI18N.install_domain()
+
 	_log.SetAllLogLevels(gmLog.lData)
 	#--------------------------------------------------------
 	class cTestObj(cBusinessDBObject):
 		_cmd_fetch_payload = None
-		_cmds_lock_rows_for_update = None
 		_cmds_store_payload = None
 		_updatable_fields = []
-		_service = None
 		#----------------------------------------------------
 		def get_something(self):
 			pass
@@ -569,6 +412,37 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmBusinessDBObject.py,v $
+# Revision 1.42  2007/05/21 14:47:22  ncq
+# - no caching of get_*()ers anymore, but don't deprecate them eiter
+#
+# Revision 1.41  2007/05/19 23:12:28  ncq
+# - cleanup
+# - remove _subtable support
+#
+# Revision 1.40  2006/11/14 23:30:33  ncq
+# - fix var name
+#
+# Revision 1.39  2006/10/31 15:59:47  ncq
+# - we are dealing with gmPG2 now
+#
+# Revision 1.38  2006/10/23 13:22:07  ncq
+# - no conn pool no more
+#
+# Revision 1.37  2006/10/21 20:39:48  ncq
+# - a bunch of cleanup
+#
+# Revision 1.36  2006/10/09 11:42:16  ncq
+# - in refetch_payload() properly handle scalar vs complex self.pk_obj
+#
+# Revision 1.35  2006/10/08 14:26:16  ncq
+# - convert to use gmPG2
+# 	- subtable support may still be suffering fallout
+# - better docstrings
+# - drop _cmds_lock_rows_for_update
+# 	- must use xmin=... in UPDATE now
+# - drop self._service
+# - adjust test suite
+#
 # Revision 1.34  2006/07/19 20:27:03  ncq
 # - gmPyCompat.py is history
 #
