@@ -37,19 +37,24 @@ variables by the locale system.
 @copyright: authors
 """
 #===========================================================================
-# $Id: gmI18N.py,v 1.30.2.1 2006/08/28 10:20:39 ncq Exp $
+# $Id: gmI18N.py,v 1.32 2007/04/01 15:20:52 ncq Exp $
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmI18N.py,v $
-__version__ = "$Revision: 1.30.2.1 $"
+__version__ = "$Revision: 1.32 $"
 __author__ = "H. Herb <hherb@gnumed.net>, I. Haywood <i.haywood@ugrad.unimelb.edu.au>, K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
-import sys, os.path, os, re, locale, gettext
-import gmLog
+#stdlib
+import sys, os.path, os, re as regex, locale, gettext
+
+
+# GNUmed libs
+if __name__ == "__main__":
+	sys.path.insert(0, '../../')
+from Gnumed.pycommon import gmLog, gmTools
+
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
-if __name__ == "__main__":
-	_log.SetAllLogLevels(gmLog.lData)
 
 system_locale = ''
 system_locale_level = {}
@@ -79,7 +84,7 @@ def __split_locale_into_levels():
 	global system_locale_level
 	system_locale_level['full'] = system_locale
 	# trim '@<variant>' part
-	system_locale_level['country'] = re.split('@|:|\.', system_locale, 1)[0]
+	system_locale_level['country'] = regex.split('@|:|\.', system_locale, 1)[0]
 	# trim '_<COUNTRY>@<variant>' part
 	system_locale_level['language'] = system_locale.split('_', 1)[0]
 
@@ -227,7 +232,6 @@ def install_domain(text_domain=None, language=None):
 
 	# search for message catalog
 	candidates = []
-
 	# 1) try standard places first
 	if os.name == 'posix':
 		_log.Log(gmLog.lData, 'system is POSIX, looking in standard locations (see Python Manual)')
@@ -236,7 +240,6 @@ def install_domain(text_domain=None, language=None):
 		candidates.append(gettext.bindtextdomain(text_domain))
 	else:
 		_log.Log(gmLog.lData, 'No use looking in standard POSIX locations - not a POSIX system.')
-
 	# 2) $(<script-name>_DIR)/
 	env_key = "%s_DIR" % os.path.splitext(os.path.basename(sys.argv[0]))[0].upper()
 	_log.Log(gmLog.lData, 'looking at ${%s}' % env_key)
@@ -246,7 +249,6 @@ def install_domain(text_domain=None, language=None):
 		candidates.append(loc_dir)
 	else:
 		_log.Log(gmLog.lInfo, "${%s} not set" % env_key)
-
 	# 3) one level above path to binary
 	#    last resort for inferior operating systems such as DOS/Windows
 	#    strip one directory level
@@ -254,7 +256,6 @@ def install_domain(text_domain=None, language=None):
 	loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), '..', 'locale'))
 	_log.Log(gmLog.lData, 'looking above binary install directory [%s]' % loc_dir)
 	candidates.append(loc_dir)
-
 	# 4) in path to binary
 	loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), 'locale' ))
 	_log.Log(gmLog.lData, 'looking in binary install directory [%s]' % loc_dir)
@@ -285,9 +286,24 @@ def install_domain(text_domain=None, language=None):
 	dummy.install()
 	return True
 #===========================================================================
+def get_encoding():
+	"""Try to get a sane encoding.
+
+	On MaxOSX locale.setlocale(locale.LC_ALL, '') does not
+	have the desired effect. locale.getlocale()[1] still
+	returns None. So in that case try to fallback to
+	locale.getpreferredencoding().
+	"""
+	return gmTools.coalesce (
+		locale.getlocale()[1],
+		locale.getpreferredencoding()
+	)
+#===========================================================================
 # Main
 #---------------------------------------------------------------------------
 if __name__ == "__main__":
+	_log.SetAllLogLevels(gmLog.lData)
+
 	print "======================================================================"
 	print __doc__
 	print "======================================================================"
@@ -295,16 +311,19 @@ if __name__ == "__main__":
 	print "license:", __license__, "; version:", __version__
 	activate_locale()
 	print "system locale: ", system_locale, "; levels:", system_locale_level
-	install_domain(text_domain='gnumed', language='de_DE')
+	install_domain()
 	# == do not remove this line =============================
 	tmp = _('translate this or i18n will not work properly !')
 	# ========================================================
 
 #=====================================================================
 # $Log: gmI18N.py,v $
-# Revision 1.30.2.1  2006/08/28 10:20:39  ncq
-# - make tag unicode string
-# - no more unicode_flag in install_domain, rather *require* unicode gettext
+# Revision 1.32  2007/04/01 15:20:52  ncq
+# - add get_encoding()
+# - fix test suite
+#
+# Revision 1.31  2006/09/01 14:41:22  ncq
+# - always use UNICODE gettext
 #
 # Revision 1.30  2006/07/10 21:44:23  ncq
 # - slightly better logging
