@@ -12,7 +12,7 @@ def resultset_functional_batchgenerator(cursor, size=100):
 """
 # =======================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmPG2.py,v $
-__version__ = "$Revision: 1.31.2.2 $"
+__version__ = "$Revision: 1.46 $"
 __author__  = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
@@ -23,7 +23,8 @@ import time, locale, sys, re, os, codecs, types, datetime
 # GNUmed
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmLog, gmLoginInfo, gmExceptions, gmDateTime
+from Gnumed.pycommon import gmLog, gmLoginInfo, gmExceptions, gmDateTime, gmBorg
+
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
@@ -60,6 +61,7 @@ except ValueError:
 
 import psycopg2.extras
 import psycopg2.extensions
+import psycopg2.pool
 
 # =======================================================================
 #_default_client_encoding = 'UNICODE'
@@ -82,6 +84,8 @@ _default_login = None
 postgresql_version_string = None
 postgresql_version = None			# accuracy: major.minor
 
+__ro_conn_pool = None
+
 # =======================================================================
 # global data
 # =======================================================================
@@ -91,13 +95,16 @@ known_schema_hashes = {
 	'v2': 'b09d50d7ed3f91ddf4c4ddb8ea507720',
 	'v3': 'e73718eaf230d8f1d2d01afa8462e176',
 	'v4': '4428ccf2e54c289136819e701bb095ea',
-	'v5': 'v5 not released'
+	'v5': '7e7b093af57aea48c288e76632a382e5',	# old (v1)
+	'v6': '90e2026ac2efd236da9c8608b8685b2d'	# new (v2)
 }
 
 map_schema_hash2version = {
 	'b09d50d7ed3f91ddf4c4ddb8ea507720': 'v2',
 	'e73718eaf230d8f1d2d01afa8462e176': 'v3',
-	'4428ccf2e54c289136819e701bb095ea': 'v4'
+	'4428ccf2e54c289136819e701bb095ea': 'v4',
+	'7e7b093af57aea48c288e76632a382e5': 'v5',
+	'90e2026ac2efd236da9c8608b8685b2d': 'v6'
 }
 
 # get columns and data types for a given table
@@ -165,21 +172,20 @@ def __prompted_input(prompt, default=None):
 def __request_login_params_tui():
 	"""Text mode request of database login parameters"""
 	import getpass
-	login = gmLoginInfo.LoginInfo('', '', '')
+	login = gmLoginInfo.LoginInfo()
 
 	print "\nPlease enter the required login parameters:"
 	try:
-		host = __prompted_input("host ['' = non-TCP/IP]: ", '')
-		database = __prompted_input("database [gnumed_v3]: ", 'gnumed_v3')
-		user = __prompted_input("user name: ", '')
-		password = getpass.getpass("password (not shown): ")
-		port = __prompted_input("port [5432]: ", 5432)
+		login.host = __prompted_input("host ['' = non-TCP/IP]: ", '')
+		login.database = __prompted_input("database [gnumed_v6]: ", 'gnumed_v6')
+		login.user = __prompted_input("user name: ", '')
+		login.password = getpass.getpass("password (not shown): ")
+		login.port = __prompted_input("port [5432]: ", 5432)
 	except KeyboardInterrupt:
 		_log.Log(gmLog.lWarn, "user cancelled text mode login dialog")
 		print "user cancelled text mode login dialog"
 		raise gmExceptions.ConnectionError(_("Cannot connect to database without login information!"))
 
-	login.SetInfo(user, password, dbname=database, host=host, port=port)
 	return login
 #---------------------------------------------------
 def __request_login_params_gui_wx():
@@ -283,7 +289,18 @@ def set_default_login(login=None):
 # =======================================================================
 def database_schema_compatible(link_obj=None, version=None):
 	expected_hash = known_schema_hashes[version]
-	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': u'select md5(gm_concat_table_structure()) as md5'}])
+#	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': u'select md5(gm_concat_table_structure()) as md5'}])
+	if version == 'devel':
+		args = {'ver': '9999'}
+	else:
+		args = {'ver': version.strip('v')}
+	rows, idx = run_ro_queries (
+		link_obj = link_obj,
+		queries = [{
+			'cmd': u'select md5(gm.concat_table_structure(%(ver)s::integer)) as md5',
+			'args': args
+		}]
+	)
 	if rows[0]['md5'] != expected_hash:
 		_log.Log(gmLog.lErr, 'database schema version mismatch')
 		_log.Log(gmLog.lErr, 'expected: %s (%s)' % (version, expected_hash))
@@ -293,12 +310,16 @@ def database_schema_compatible(link_obj=None, version=None):
 	return True
 #------------------------------------------------------------------------
 def get_schema_version(link_obj=None):
-	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': u'select md5(gm_concat_table_structure()) as md5'}])
+	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': u'select md5(gm.concat_table_structure()) as md5'}])
 	try:
 		return map_schema_hash2version[rows[0]['md5']]
 	except KeyError:
 		return u'unknown database schema version, MD5 hash is [%s]' % rows[0]['md5']
 #------------------------------------------------------------------------
+def get_schema_structure(link_obj=None):
+	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': u'select gm.concat_table_structure()'}])
+	return rows[0][0]
+#------------------------------------------------------------------------
 def get_current_user():
 	rows, idx = run_ro_queries(queries = [{'cmd': u'select CURRENT_USER'}])
 	return rows[0][0]
@@ -390,15 +411,18 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 		curs = link_obj
 		curs_close = __noop
 		conn_close = __noop
+		tx_rollback = __noop
 	elif isinstance(link_obj, dbapi._psycopg.connection):
 		curs = link_obj.cursor()
 		curs_close = curs.close
 		conn_close = __noop
+		tx_rollback = link_obj.rollback
 	elif link_obj is None:
 		conn = get_connection(readonly=True, verbose=verbose)
-		conn_close = conn.close
 		curs = conn.cursor()
 		curs_close = curs.close
+		conn_close = conn.close
+		tx_rollback = conn.rollback
 	else:
 		raise ValueError('link_obj must be cursor, connection or None but not [%s]' % link_obj)
 
@@ -413,8 +437,6 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 			args = query['args']
 		except KeyError:
 			args = (None,)
-#		if verbose:		# mogrify does not support unicode queries, yet
-#			_log.Log(gmLog.lData, 'running: %s' % curs.mogrify(query['cmd'], args))
 		try:
 			curs.execute(query['cmd'], args)
 			if verbose:
@@ -422,10 +444,12 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 				_log.Log(gmLog.lData, 'PG status message: %s' % curs.statusmessage)
 				_log.Log(gmLog.lData, 'cursor description: %s' % curs.description)
 		except:
+			curs_close()
+			tx_rollback()		# need to rollback so ABORT state isn't preserved in pooled conns
+			conn_close()
 			_log.Log(gmLog.lErr, 'query failed: [%s]' % curs.query)
 			_log.Log(gmLog.lErr, 'PG status message: %s' % curs.statusmessage)
-			curs_close()
-			conn_close()
+			_log.flush()
 			raise
 
 	data = None
@@ -439,6 +463,7 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 			_log.Log(gmLog.lData, 'cursor description: %s' % curs.description)
 
 	curs_close()
+	tx_rollback()		# rollback just so that we don't stay IDLE IN TRANSACTION forever
 	conn_close()
 	return (data, col_idx)
 #------------------------------------------------------------------------
@@ -460,7 +485,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 	<end_tx>
 		- controls whether the transaction is finalized (eg.
 		  committed/rolled back) or not, this allows the
-		  call to run_commit2() to be part of a framing
+		  call to run_rw_queries() to be part of a framing
 		  transaction
 		- if link_obj is a connection then <end_tx> will
 		  default to False unless it is explicitely set to
@@ -548,6 +573,29 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 
 	return (data, col_idx)
 # =======================================================================
+# connection handling API
+# -----------------------------------------------------------------------
+class cConnectionPool(psycopg2.pool.PersistentConnectionPool):
+	"""
+	GNUmed database connection pool.
+
+	Extends psycopg2's PersistentConnectionPool with
+	a custom _connect() function. Supports one connection
+	per thread - which also ties it to one particular DSN.
+	"""
+	#--------------------------------------------------
+	def _connect(self, key=None):
+
+		conn = get_raw_connection(dsn = self._kwargs['dsn'], verbose = self._kwargs['verbose'])
+
+		if key is not None:
+			self._used[key] = conn
+			self._rused[id(conn)] = key
+		else:
+			self._pool.append(conn)
+
+		return conn
+# -----------------------------------------------------------------------
 def get_raw_connection(dsn=None, verbose=False):
 	"""Get a raw, unadorned connection.
 
@@ -557,7 +605,6 @@ def get_raw_connection(dsn=None, verbose=False):
 	  for verifying encodings etc
 	"""
 	# FIXME: support verbose
-
 	if dsn is None:
 		dsn = get_default_dsn()
 
@@ -583,9 +630,13 @@ def get_raw_connection(dsn=None, verbose=False):
 			where name='server_version'"""
 		)
 		postgresql_version = curs.fetchone()['version']
+		_log.Log(gmLog.lInfo, 'PostgreSQL version (numeric): %s' % postgresql_version)
+		if verbose:
+			__log_PG_settings(curs=curs)
 		curs.close()
 		conn.commit()
-		_log.Log(gmLog.lInfo, 'PostgreSQL version (numeric): %s' % postgresql_version)
+		
+	conn.is_decorated = False
 
 	return conn
 # =======================================================================
@@ -595,14 +646,29 @@ def get_connection(dsn=None, readonly=True, encoding=None, verbose=False, pooled
 	This assumes the locale system has been initialzied
 	unless an encoding is specified.
 	"""
-	# FIXME: support pooled, verbose
+	# FIXME: support pooled on RW, too
+	# FIXME: for now, support the default DSN only
+	if pooled and readonly and (dsn is None):
+		global __ro_conn_pool
+		if __ro_conn_pool is None:
+			__ro_conn_pool = cConnectionPool (
+				minconn = 1,
+				maxconn = 2,
+				dsn = dsn,
+				verbose = verbose
+			)
+		conn = __ro_conn_pool.getconn()
+		conn.close = __noop					# do not close pooled ro connections
+	else:
+		conn = get_raw_connection(dsn=dsn, verbose=verbose)
 
-	conn = get_raw_connection(dsn=dsn, verbose=verbose)
+	if conn.is_decorated:
+		return conn
 
 	if encoding is None:
 		encoding = _default_client_encoding
 	if encoding is None:
-		encoding = locale.getlocale()[1]
+		encoding = gmI18N.get_encoding()
 		_log.Log(gmLog.lWarn, 'client encoding not specified')
 		_log.Log(gmLog.lWarn, 'the string encoding currently set in the active locale is used: [%s]' % encoding)
 		_log.Log(gmLog.lWarn, 'for this to work the application MUST have called locale.setlocale() before')
@@ -658,6 +724,9 @@ def get_connection(dsn=None, readonly=True, encoding=None, verbose=False, pooled
 
 	curs.close()
 	conn.commit()
+
+	conn.is_decorated = True
+
 	return conn
 # =======================================================================
 # internal helpers
@@ -762,7 +831,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v3'
+		dsn = 'dbname=gnumed_v6'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -771,7 +840,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v3 user=abc'
+		dsn = 'dbname=gnumed_v6 user=abc'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -780,7 +849,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v3 user=any-doc'
+		dsn = 'dbname=gnumed_v6 user=any-doc'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -789,7 +858,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v3 user=any-doc password=abc'
+		dsn = 'dbname=gnumed_v6 user=any-doc password=abc'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -798,13 +867,13 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v3 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
 		conn = get_connection(dsn=dsn, readonly=True)
 
-		dsn = 'dbname=gnumed_v3 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
 		conn = get_connection(dsn=dsn, readonly=False)
 
-		dsn = 'dbname=gnumed_v3 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
 		encoding = 'foo'
 		try:
 			conn = get_connection(dsn=dsn, encoding=encoding)
@@ -836,7 +905,7 @@ if __name__ == "__main__":
 	def test_ro_queries():
 		print "testing run_ro_queries()"
 
-		dsn = 'dbname=gnumed_v3 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
 		conn = get_connection(dsn, readonly=True)
 
 		data, idx = run_ro_queries(link_obj=conn, queries=[{'cmd': u'select version()'}], return_data=True, get_col_idx=True, verbose=True)
@@ -936,21 +1005,75 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 	#--------------------------------------------------------------------
+	def test_connection_pool():
+		dsn = get_default_dsn()
+		pool = cConnectionPool(minconn=1, maxconn=2, dsn=None, verbose=False)
+		print pool
+		print pool.getconn()
+		print pool.getconn()
+		print pool.getconn()
+		print type(pool.getconn())
+	#--------------------------------------------------------------------
 	# run tests
-	test_get_connection()
-	test_exceptions()
-	test_ro_queries()
-	test_request_dsn()
-	test_set_encoding()
+#	test_get_connection()
+#	test_exceptions()
+#	test_ro_queries()
+#	test_request_dsn()
+#	test_set_encoding()
+	test_connection_pool()
 	print "tests ran successfully"
 
 # =======================================================================
 # $Log: gmPG2.py,v $
-# Revision 1.31.2.2  2007/01/23 22:22:18  ncq
-# - set sslmode to "prefer"
+# Revision 1.46  2007/05/07 16:45:12  ncq
+# - add v6 schema hash
 #
-# Revision 1.31.2.1  2007/01/23 13:59:22  ncq
-# - add v4 schema hash as known
+# Revision 1.45  2007/05/07 16:28:34  ncq
+# - use database maintenance functions in schema "gm"
+#
+# Revision 1.44  2007/04/27 13:19:58  ncq
+# - get_schema_structure()
+#
+# Revision 1.43  2007/04/02 18:36:17  ncq
+# - fix comment
+#
+# Revision 1.42  2007/04/02 14:31:17  ncq
+# - v5 -> v6
+#
+# Revision 1.41  2007/04/01 15:27:09  ncq
+# - safely get_encoding()
+#
+# Revision 1.40  2007/03/26 16:08:06  ncq
+# - added v5 hash
+#
+# Revision 1.39  2007/03/08 11:37:24  ncq
+# - simplified gmLogin
+# - log PG settings on first connection if verbose
+#
+# Revision 1.38  2007/03/01 14:05:53  ncq
+# - rollback in run_ro_queries() even if no error occurred such that
+#   we don't stay IDLE IN TRANSACTION
+#
+# Revision 1.37  2007/03/01 14:03:53  ncq
+# - in run_ro_queries() we now need to rollback failed transactions due to
+#   the connections being pooled - or else abort state could carry over into
+#   the next use of that connection - since transactions aren't really
+#   in need of ending
+#
+# Revision 1.36  2007/02/19 15:00:53  ncq
+# - restrict pooling to the default DSN, too
+#
+# Revision 1.35  2007/02/18 16:56:21  ncq
+# - add connection pool for read-only connections ...
+#
+# Revision 1.34  2007/02/06 12:11:25  ncq
+# - gnumed_v5
+#
+# Revision 1.33  2007/01/24 11:03:55  ncq
+# - add sslmode=prefer to DSN
+#
+# Revision 1.32  2007/01/23 14:03:14  ncq
+# - add known v4 schema hash - backport from 0.2.4
 #
 # Revision 1.31  2007/01/17 13:26:02  ncq
 # - note on MDY/DMY handling
