@@ -2,20 +2,22 @@
 # GNUmed SANE/TWAIN scanner classes
 #==================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmScanBackend.py,v $
-# $Id: gmScanBackend.py,v 1.34 2007/01/19 14:06:17 ncq Exp $
-__version__ = "$Revision: 1.34 $"
+# $Id: gmScanBackend.py,v 1.39 2007/05/08 11:14:34 ncq Exp $
+__version__ = "$Revision: 1.39 $"
 __license__ = "GPL"
 __author__ = """Sebastian Hilbert <Sebastian.Hilbert@gmx.net>, Karsten Hilbert <Karsten.Hilbert@gmx.net>"""
 
 #==================================================
 # stdlib
-import sys, os.path, os, Image, string, time, shutil, tempfile, codecs, glob, locale
+import sys, os.path, os, string, time, shutil, tempfile, codecs, glob, locale
 
+# 3rd party
+import Image
 
 # GNUmed
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmLog, gmExceptions, gmShellAPI
+from Gnumed.pycommon import gmLog, gmExceptions, gmShellAPI, gmTools, gmI18N
 
 
 _log = gmLog.gmDefLog
@@ -155,7 +157,7 @@ class cTwainScanner:
 	#---------------------------------------------------
 	def _twain_handle_transfer_in_memory(self):
 
-		# FIXME: handle more images
+		# FIXME: handle several images
 
 		_log.Log(gmLog.lData, 'receiving image from TWAIN source')
 		_log.Log(gmLog.lData, 'image info: %s' % self.__scanner.GetImageInfo())
@@ -300,6 +302,9 @@ class cXSaneScanner:
 		# this will tell us fairly safely whether XSane is properly installed
 		if not os.access(cXSaneScanner._xsanerc, os.W_OK):
 			raise IOError('XSane not properly installed for this user, no write access for [%s]' % cXSaneScanner._xsanerc)
+
+		self.device_settings_file = None
+		self.default_device = None
 	#----------------------------------------------
 	def close(self):
 		pass
@@ -307,7 +312,7 @@ class cXSaneScanner:
 	def acquire_pages_into_files(self, delay=None, filename=None, tmpdir=None):
 		"""Call XSane.
 
-		<filename name part must have format name-xxx.ext>
+		<filename name part must have format name-###.ext>
 		"""
 		if filename is None:
 			if tmpdir is None:
@@ -316,8 +321,7 @@ class cXSaneScanner:
 				(handle, filename) = tempfile.mkstemp(suffix=cXSaneScanner._filetype, prefix='gmScannedObj-', dir=tmpdir)
 		else:
 			tmp, ext = os.path.splitext(filename)
-			if ext != cXSaneScanner._filetype:
-				filename = filename + cXSaneScanner._filetype
+			filename = '%s-###.%s' % (tmp, cXSaneScanner._filetype)
 
 		filename = os.path.abspath(os.path.expanduser(filename))
 		path, name = os.path.split(filename)
@@ -325,7 +329,11 @@ class cXSaneScanner:
 		self.__prepare_xsanerc(tmpdir=path)
 
 		gmShellAPI.run_command_in_shell (
-			command = 'xsane --no-mode-selection --save --force-filename "%s"' % filename, 
+			command = 'xsane --no-mode-selection --save --force-filename "%s" %s %s' % (
+				filename,
+				gmTools.coalesce(self.device_settings_file, '', '--device-settings %s'),
+				gmTools.coalesce(self.default_device, '')
+			),
 			blocking = True
 		)
 
@@ -343,14 +351,16 @@ class cXSaneScanner:
 		shutil.copy2(cXSaneScanner._xsanerc, cXSaneScanner._xsanerc_backup)
 
 		# our closest bet, might contain umalauts
-		enc = locale.getlocale()[1]
+		enc = gmI18N.get_encoding()
 		fread = codecs.open(cXSaneScanner._xsanerc_backup, mode = "rU", encoding = enc)
 		fwrite = codecs.open(cXSaneScanner._xsanerc, mode = "w", encoding = enc)
 
 		val_dict = {
 			'filetype': cXSaneScanner._filetype,
 			'tmp-path': tmpdir,
-			'working-directory': tmpdir
+			'working-directory': tmpdir,
+			'filename-counter-step': '1',
+			'filename-counter-len': '3'
 		}
 
 		for idx, line in enumerate(fread):
@@ -415,7 +425,7 @@ def get_devices():
 		return _sane_module.get_devices()
 	return False
 #-----------------------------------------------------
-def acquire_pages_into_files(device=None, delay=None, filename=None, tmpdir=None, calling_window=None):
+def acquire_pages_into_files(device=None, delay=None, filename=None, tmpdir=None, calling_window=None, xsane_device_settings=None):
 	try:
 		scanner = cTwainScanner(calling_window=calling_window)
 	except gmExceptions.ConstructorError:
@@ -423,6 +433,8 @@ def acquire_pages_into_files(device=None, delay=None, filename=None, tmpdir=None
 			_log.Log(gmLog.lData, 'using XSane')
 			try:
 				scanner = cXSaneScanner()
+				scanner.device_settings_file = xsane_device_settings
+				scanner.default_device = device
 			except IOError:
 				_log.LogException('Cannot load any scanner driver (XSANE or TWAIN).', verbose=False)
 				return None
@@ -470,6 +482,21 @@ if __name__ == '__main__':
 
 #==================================================
 # $Log: gmScanBackend.py,v $
+# Revision 1.39  2007/05/08 11:14:34  ncq
+# - cleanup
+#
+# Revision 1.38  2007/04/01 15:27:09  ncq
+# - safely get_encoding()
+#
+# Revision 1.37  2007/02/17 18:18:09  ncq
+# - support pre-setting device and device-settings-file with XSane
+#
+# Revision 1.36  2007/02/15 12:03:27  ncq
+# - really support numbered multi-file scans with XSane
+#
+# Revision 1.35  2007/01/29 11:59:34  ncq
+# - improve comment
+#
 # Revision 1.34  2007/01/19 14:06:17  ncq
 # - do not attempt to handle several scans at once
 #
