@@ -1,8 +1,8 @@
 """Widgets dealing with patient demographics."""
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmDemographicsWidgets.py,v $
-# $Id: gmDemographicsWidgets.py,v 1.111 2006/11/28 20:43:26 ncq Exp $
-__version__ = "$Revision: 1.111 $"
+# $Id: gmDemographicsWidgets.py,v 1.120 2007/05/21 22:30:12 ncq Exp $
+__version__ = "$Revision: 1.120 $"
 __author__ = "R.Terry, SJ Tan, I Haywood, Carlos Moro <cfmoro1976@yahoo.es>"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
@@ -16,7 +16,7 @@ import wx.wizard
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
 from Gnumed.wxpython import gmPlugin, gmPhraseWheel, gmGuiHelpers, gmDateTimeInput, gmRegetMixin
-from Gnumed.pycommon import gmGuiBroker, gmLog, gmDispatcher, gmSignals, gmCfg, gmI18N, gmMatchProvider, gmPG2, gmFuzzyTimestamp, gmTools
+from Gnumed.pycommon import gmGuiBroker, gmLog, gmDispatcher, gmSignals, gmCfg, gmI18N, gmMatchProvider, gmPG2, gmTools, gmDateTime
 from Gnumed.business import gmDemographicRecord, gmPerson
 
 # constant defs
@@ -138,7 +138,6 @@ select code, name from (
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query, context=context)
 		mp.setThresholds(2, 5, 6)
 		mp.setWordSeparators(separators=u'[ \t]+')
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
@@ -147,7 +146,10 @@ select code, name from (
 		self.unset_context(context = u'zip')
 		self.unset_context(context = u'country_name')
 
+		self.matcher = mp
 		self.SetToolTipString(_("Select a state/region/province/territory."))
+		self.capitalisation_mode = gmTools.CAPS_FIRST
+		self.selection_only = True
 #============================================================
 class cZipcodePhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -159,13 +161,13 @@ class cZipcodePhraseWheel(gmPhraseWheel.cPhraseWheel):
 			(select distinct postcode, postcode from dem.urb where postcode %(fragment_condition)s limit 20)"""
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(2, 3, 15)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
 			**kwargs
 		)
 		self.SetToolTipString(_("Type or select a zip code (postcode)."))
+		self.matcher = mp
 #============================================================
 class cStreetPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -198,7 +200,6 @@ select s1, s2 from (
 ) as q1 order by rank, s2 limit 50"""
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query, context=context)
 		mp.setThresholds(3, 5, 8)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
@@ -207,6 +208,8 @@ select s1, s2 from (
 		self.unset_context(context = u'zip')
 
 		self.SetToolTipString(_('Type or select a street.'))
+		self.capitalisation_mode = gmTools.CAPS_FIRST
+		self.matcher = mp
 #============================================================
 class cUrbPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -239,7 +242,6 @@ select u1, u2 from (
 ) as q1 order by rank, u2 limit 50"""
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query, context=context)
 		mp.setThresholds(3, 5, 7)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
@@ -248,6 +250,8 @@ select u1, u2 from (
 		self.unset_context(context = u'zip')
 
 		self.SetToolTipString(_('Type or select a city/town/village/dwelling.'))
+		self.capitalisation_mode = gmTools.CAPS_FIRST
+		self.matcher = mp
 #============================================================
 class cCountryPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -304,7 +308,6 @@ select code, name from (
 ) as q1 order by rank, name limit 25"""
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query, context=context)
 		mp.setThresholds(2, 5, 9)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
@@ -313,6 +316,9 @@ select code, name from (
 		self.unset_context(context = u'zip')
 
 		self.SetToolTipString(_('Type or select a country.'))
+		self.capitalisation_mode = gmTools.CAPS_FIRST
+		self.selection_only = True
+		self.matcher = mp
 #============================================================
 # identity phrasewheels
 #============================================================
@@ -322,13 +328,14 @@ class cLastnamePhraseWheel(gmPhraseWheel.cPhraseWheel):
 		query = u"select distinct lastnames, lastnames from dem.names where lastnames %(fragment_condition)s order by lastnames limit 25"
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(3, 5, 9)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
 			**kwargs
 		)
 		self.SetToolTipString(_("Type or select a lastname (family name)."))
+		self.capitalisation_mode = gmTools.CAPS_NAMES
+		self.matcher = mp
 #============================================================
 class cFirstnamePhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -339,13 +346,14 @@ class cFirstnamePhraseWheel(gmPhraseWheel.cPhraseWheel):
 			(select distinct name, name from dem.name_gender_map where name %(fragment_condition)s order by name limit 20)"""
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(3, 5, 9)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
 			**kwargs
 		)
 		self.SetToolTipString(_("Type or select a firstname (surname/given name)."))
+		self.capitalisation_mode = gmTools.CAPS_NAMES
+		self.matcher = mp
 #============================================================
 class cNicknamePhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -358,13 +366,14 @@ class cNicknamePhraseWheel(gmPhraseWheel.cPhraseWheel):
 			(select distinct name, name from dem.name_gender_map where name %(fragment_condition)s order by name limit 20)"""
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(3, 5, 9)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
 			**kwargs
 		)
 		self.SetToolTipString(_("Type or select an alias (nick name, preferred name, call name, warrior name, artist name)."))
+		self.capitalisation_mode = gmTools.CAPS_NAMES
+		self.matcher = mp
 #============================================================
 class cTitlePhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -372,13 +381,13 @@ class cTitlePhraseWheel(gmPhraseWheel.cPhraseWheel):
 		query = u"select distinct title, title from dem.identity where title %(fragment_condition)s"
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(1, 3, 9)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
 			**kwargs
 		)
 		self.SetToolTipString(_("Type or select a title."))
+		self.matcher = mp
 #============================================================
 class cGenderSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""Let user select a gender."""
@@ -404,14 +413,10 @@ class cGenderSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 		mp = gmMatchProvider.cMatchProvider_FixedList(aSeq = cGenderSelectionPhraseWheel._gender_map.values())
 		mp.setThresholds(1, 1, 3)
 
-		kwargs['aMatchProvider'] = mp
-		kwargs['aDelay'] = 50
-		kwargs['selection_only'] = True
-		gmPhraseWheel.cPhraseWheel.__init__ (
-			self,
-			*args,
-			**kwargs
-		)
+		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
+		self.selection_only = True
+		self.matcher = mp
+		self.picklist_delay = 50
 #============================================================
 class cOccupationPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -419,13 +424,14 @@ class cOccupationPhraseWheel(gmPhraseWheel.cPhraseWheel):
 		query = u"select distinct name, _(name) from dem.occupation where _(name) %(fragment_condition)s"
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(1, 3, 5)
-		kwargs['aMatchProvider'] = mp
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
 			**kwargs
 		)
 		self.SetToolTipString(_("Type or select an occupation."))
+		self.capitalisation_mode = gmTools.CAPS_FIRST
+		self.matcher = mp
 #============================================================
 # new patient wizard classes
 #============================================================
@@ -509,12 +515,12 @@ class cBasicPatDetailsPage(wx.wizard.WizardPageSimple):
 
 		# state
 		STT_state = wx.StaticText(PNL_form, -1, _('State'))
-		self.PRW_state = cStateSelectionPhraseWheel(parent=PNL_form, id=-1, selection_only = True)
+		self.PRW_state = cStateSelectionPhraseWheel(parent=PNL_form, id=-1)
 		self.PRW_state.SetToolTipString(_("primary/home address: state"))
 
 		# country
 		STT_country = wx.StaticText(PNL_form, -1, _('Country'))
-		self.PRW_country = cCountryPhraseWheel(parent = PNL_form, id = -1, selection_only = True)
+		self.PRW_country = cCountryPhraseWheel(parent = PNL_form, id = -1)
 		self.PRW_country.SetToolTipString(_("primary/home address: country"))
 
 		# phone
@@ -525,16 +531,6 @@ class cBasicPatDetailsPage(wx.wizard.WizardPageSimple):
 		# occupation
 		STT_occupation = wx.StaticText(PNL_form, -1, _('Occupation'))
 		self.PRW_occupation = cOccupationPhraseWheel(parent = PNL_form,	id = -1)
-#		queries = []
-#		queries.append("select distinct name, name from dem.occupation where name %(fragment_condition)s")
-#		mp = gmMatchProvider.cMatchProvider_SQL2(queries)
-#		mp.setThresholds(3, 5, 15)		
-#		self.PRW_occupation = gmPhraseWheel.cPhraseWheel (
-#			parent = PNL_form,
-#			id = -1,
-#			aMatchProvider = mp
-#		)
-#		self.PRW_occupation.SetToolTipString(_("primary occupation of the patient"))
 
 		# form main validator
 		self.form_DTD = cFormDTD(fields = self.__class__.form_fields)
@@ -653,12 +649,10 @@ class cNewPatientWizard(wx.wizard.Wizard):
 		ident = create_identity_from_dtd(dtd = self.basic_pat_details.form_DTD)
 		update_identity_from_dtd(identity = ident, dtd = self.basic_pat_details.form_DTD)
 		link_contacts_from_dtd(identity = ident, dtd = self.basic_pat_details.form_DTD)
-		#ident.link_occupation(occupation = self.PRW_occupation.GetValue().strip())
 		link_occupation_from_dtd(identity = ident, dtd = self.basic_pat_details.form_DTD)
 
 		if activate:
-			pat = gmPerson.cPatient(identity = ident)
-			gmPerson.gmCurrentPatient(patient = pat)
+			gmPerson.set_active_patient(patient = ident)
 
 		return ident
 	#--------------------------------------------------------
@@ -780,16 +774,16 @@ class cBasicPatDetailsPageValidator(wx.PyValidator):
 		_pnl_form = self.GetWindow().GetParent()
 		# fill in controls with values from self.form_DTD
 		_pnl_form.PRW_gender.SetData(self.form_DTD['gender'])
-		_pnl_form.PRW_dob.SetValue(self.form_DTD['dob'])
-		_pnl_form.PRW_lastname.SetValue(self.form_DTD['lastnames'])
-		_pnl_form.PRW_firstname.SetValue(self.form_DTD['firstnames'])
-		_pnl_form.PRW_title.SetValue(self.form_DTD['title'])
-		_pnl_form.PRW_nick.SetValue(self.form_DTD['nick'])
-		_pnl_form.PRW_occupation.SetValue(self.form_DTD['occupation'])
+		_pnl_form.PRW_dob.SetText(self.form_DTD['dob'])
+		_pnl_form.PRW_lastname.SetText(self.form_DTD['lastnames'])
+		_pnl_form.PRW_firstname.SetText(self.form_DTD['firstnames'])
+		_pnl_form.PRW_title.SetText(self.form_DTD['title'])
+		_pnl_form.PRW_nick.SetText(self.form_DTD['nick'])
+		_pnl_form.PRW_occupation.SetText(self.form_DTD['occupation'])
 		_pnl_form.TTC_address_number.SetValue(self.form_DTD['address_number'])
-		_pnl_form.PRW_street.SetValue(self.form_DTD['street'])
-		_pnl_form.PRW_zip_code.SetValue(self.form_DTD['zip_code'])
-		_pnl_form.PRW_town.SetValue(self.form_DTD['town'])
+		_pnl_form.PRW_street.SetText(self.form_DTD['street'])
+		_pnl_form.PRW_zip_code.SetText(self.form_DTD['zip_code'])
+		_pnl_form.PRW_town.SetText(self.form_DTD['town'])
 		_pnl_form.PRW_state.SetData(self.form_DTD['state'])
 		_pnl_form.PRW_country.SetData(self.form_DTD['country'])
 		_pnl_form.TTC_phone.SetValue(self.form_DTD['phone'])
@@ -894,9 +888,10 @@ class cPatEditionNotebook(wx.Notebook):
 			id = id,
 			pos = pos,
 			size = size,
-			style = wx.NB_TOP | wx.NB_MULTILINE | wx.NO_BORDER | wx.VSCROLL | wx.HSCROLL,
+			style = wx.NB_TOP | wx.NB_MULTILINE | wx.NO_BORDER,
 			name = self.__class__.__name__
 		)
+# | wx.VSCROLL | wx.HSCROLL
 #		self.SetExtraStyle(wx.WS_EX_VALIDATE_RECURSIVELY)
 
 		self.__pat = gmPerson.gmCurrentPatient()
@@ -912,12 +907,10 @@ class cPatEditionNotebook(wx.Notebook):
 	def refresh(self):
 		"""Populate fields in pages with data from model.
 		"""
-		identity = self.__pat.get_identity()
-
 		# refresh identity reference in pages
 		for page_idx in range(self.GetPageCount()):
 			page = self.GetPage(page_idx)
-			page.set_identity(identity)
+			page.set_identity(self.__pat)
 
 		return True
 	#--------------------------------------------------------
@@ -927,12 +920,11 @@ class cPatEditionNotebook(wx.Notebook):
 		"""
 		Build patient edition notebook pages.
 		"""
-		ident = self.__pat.get_identity()
 		# identity page
 		new_page = cPatIdentityPanel (
 			parent = self,
 			id = -1,
-			ident = ident
+			ident = self.__pat
 		)
 		self.AddPage (
 			page = new_page,
@@ -944,7 +936,7 @@ class cPatEditionNotebook(wx.Notebook):
 		new_page = cPatContactsPanel (
 			parent = self,
 			id = -1,
-			ident = ident
+			ident = self.__pat
 		)
 		self.AddPage (
 			page = new_page,
@@ -956,7 +948,7 @@ class cPatEditionNotebook(wx.Notebook):
 		new_page = cPatOccupationsPanel (
 			parent = self,
 			id = -1,
-			ident = ident
+			ident = self.__pat
 		)
 		self.AddPage (
 			page = new_page,
@@ -1107,15 +1099,15 @@ class cPatIdentityPanel(wx.Panel):
 		if identity is not None:
 			self.__ident = identity
 
-		dob = gmFuzzyTimestamp.cFuzzyTimestamp(timestamp = self.__ident['dob'])
+		dob = gmDateTime.cFuzzyTimestamp(timestamp = self.__ident['dob'])
 		active_name = self.__ident.get_active_name()
 
 		self.PRW_gender.SetData(self.__ident['gender'])
-		self.PRW_dob.SetValue(val = dob.strftime('%Y-%m-%d %H:%M'), data = dob)
-		self.PRW_lastname.SetValue(active_name['last'])
-		self.PRW_firstname.SetValue(active_name['first'])
-		self.PRW_title.SetValue(gmTools.coalesce(self.__ident['title'], ''))
-		self.PRW_nick.SetValue(gmTools.coalesce(active_name['preferred'], ''))
+		self.PRW_dob.SetText(value = dob.strftime('%Y-%m-%d %H:%M'), data = dob)
+		self.PRW_lastname.SetText(active_name['last'])
+		self.PRW_firstname.SetText(active_name['first'])
+		self.PRW_title.SetText(gmTools.coalesce(self.__ident['title'], ''))
+		self.PRW_nick.SetText(gmTools.coalesce(active_name['preferred'], ''))
 		return True
 	#--------------------------------------------------------
 	def save(self):
@@ -1296,9 +1288,9 @@ class cPatContactsPanel(wx.Panel):
 		"""
 		zip, state_id, state, country_id, country = gmDemographicRecord.get_town_data (self.PRW_town.GetValue ())
 		if zip:
-			self.PRW_state.SetValue (state, state_id)
-			self.PRW_zip_code.SetValue (zip)
-			self.PRW_country.SetValue (country, country_id)
+			self.PRW_state.SetText (state, state_id)
+			self.PRW_zip_code.SetText (zip)
+			self.PRW_country.SetText (country, country_id)
 			self.TTC_phone.SetFocus ()
 	#--------------------------------------------------------
 	# internal helpers
@@ -1347,9 +1339,9 @@ class cPatContactsPanel(wx.Panel):
 		if len(adrs) != 0:
 			home = adrs[0]
 			self.TTC_address_number.SetValue(home['number'])
-			self.PRW_street.SetValue(home['street'])
-			self.PRW_zip_code.SetValue(home['postcode'])
-			self.PRW_town.SetValue(home['urb'])
+			self.PRW_street.SetText(home['street'])
+			self.PRW_zip_code.SetText(home['postcode'])
+			self.PRW_town.SetText(home['urb'])
 			self.PRW_country.SetData(data = home['code_country'])
 			self.PRW_state.SetData(data = home['code_state'])
 
@@ -1373,7 +1365,7 @@ class cPatContactsPanel(wx.Panel):
 			country = self.PRW_country.GetData()
 		)
 		if not success:
-			gmGuiHelpers.gm_statustext(_('Cannot update patient address.'))
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot update patient address.'))
 			return False
 
 		phone = self.TTC_phone.GetValue().strip()
@@ -1384,7 +1376,7 @@ class cPatContactsPanel(wx.Panel):
 				is_confidential = False
 			)
 		if not success:
-			gmGuiHelpers.gm_statustext(_('Cannot update patient phone number.'))
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot update patient phone number.'))
 			return False
 
 		return True
@@ -1439,7 +1431,7 @@ class cPatOccupationsPanel(wx.Panel):
 			self.__ident = identity
 		jobs = self.__ident.get_occupations()
 		if len(jobs) > 0:
-			self.PRW_occupation.SetValue(jobs[0]['l10n_occupation'])
+			self.PRW_occupation.SetText(jobs[0]['l10n_occupation'])
 			self.TTC_occupation_updated.SetValue(jobs[0]['modified_when'].strftime('%m/%Y'))
 		return True
 	#--------------------------------------------------------
@@ -1621,30 +1613,36 @@ def link_contacts_from_dtd(identity, dtd=None):
 	supplied data.
 	@type basic_details_DTD A cFormDTD instance.
 	"""
-	# FIXME: support address type
-
-	success = identity.link_address (
-		number = dtd['address_number'].strip(),
-		street = dtd['street'].strip(),
-		postcode = dtd['zip_code'].strip(),
-		urb = dtd['town'].strip(),
-		state = dtd['state'].strip(),
-		country = dtd['country'].strip()
+	lng = len (
+		dtd['address_number'].strip() +
+		dtd['street'].strip() +
+		dtd['zip_code'].strip() +
+		dtd['town'].strip() +
+		dtd['state'].strip() +
+		dtd['country'].strip()
 	)
-	if not success:
-		gmGuiHelpers.gm_statustext(_('Cannot update patient address.'))
-		return False
+	if lng > 0:
+		# FIXME: support address type
+		success = identity.link_address (
+			number = dtd['address_number'].strip(),
+			street = dtd['street'].strip(),
+			postcode = dtd['zip_code'].strip(),
+			urb = dtd['town'].strip(),
+			state = dtd['state'].strip(),
+			country = dtd['country'].strip()
+		)
+		if not success:
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Cannot update patient address.'))
 
-	input_phone = dtd['phone']
-	if len(input_phone) > 0:
+	if len(dtd['phone']) > 0:
 		identity.link_communication (
 			comm_medium = 'homephone',
-			url = input_phone,
+			url = dtd['phone'],
 			is_confidential = False
 		)
 
 	# FIXME: error checking
-	identity.save_payload()
+#	identity.save_payload()
 	return True
 #============================================================				
 def link_occupation_from_dtd(identity, dtd=None):
@@ -1656,7 +1654,7 @@ def link_occupation_from_dtd(identity, dtd=None):
 	supplied data.
 	@type basic_details_DTD A cFormDTD instance.
 	"""
-
+	identity.link_occupation(occupation = dtd['occupation'])
 
 	return True
 #============================================================
@@ -1731,6 +1729,36 @@ if __name__ == "__main__":
 
 #============================================================
 # $Log: gmDemographicsWidgets.py,v $
+# Revision 1.120  2007/05/21 22:30:12  ncq
+# - cleanup
+# - don't try to store empty address in link_contacts_from_dtd()
+#
+# Revision 1.119  2007/05/14 13:11:24  ncq
+# - use statustext() signal
+#
+# Revision 1.118  2007/04/02 18:39:52  ncq
+# - gmFuzzyTimestamp -> gmDateTime
+#
+# Revision 1.117  2007/03/31 21:34:11  ncq
+# - use gmPerson.set_active_patient()
+#
+# Revision 1.116  2007/02/22 17:41:13  ncq
+# - adjust to gmPerson changes
+#
+# Revision 1.115  2007/02/17 13:59:20  ncq
+# - honor entered occupation in new patient wizard
+#
+# Revision 1.114  2007/02/06 13:43:40  ncq
+# - no more aDelay in __init__()
+#
+# Revision 1.113  2007/02/05 12:15:23  ncq
+# - no more aMatchProvider/selection_only in cPhraseWheel.__init__()
+#
+# Revision 1.112  2007/02/04 15:52:10  ncq
+# - set proper CAPS modes on phrasewheels
+# - use SetText()
+# - remove HSCROLL/VSCROLL so we run on Mac
+#
 # Revision 1.111  2006/11/28 20:43:26  ncq
 # - remove lots of debugging prints
 #
