@@ -2,30 +2,27 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmEMRBrowser.py,v $
-# $Id: gmEMRBrowser.py,v 1.66 2007/01/16 18:00:59 ncq Exp $
-__version__ = "$Revision: 1.66 $"
+# $Id: gmEMRBrowser.py,v 1.75 2007/05/21 14:48:20 ncq Exp $
+__version__ = "$Revision: 1.75 $"
 __author__ = "cfmoro1976@yahoo.es, sjtan@swiftdsl.com.au, Karsten.Hilbert@gmx.net"
 __license__ = "GPL"
 
 # std lib
-import sys, types, os.path, StringIO
+import sys, types, os.path, StringIO, codecs
 
 # 3rd party
 import wx
 
 # GNUmed libs
-from Gnumed.pycommon import gmLog, gmI18N, gmDispatcher, gmSignals
+from Gnumed.pycommon import gmLog, gmI18N, gmDispatcher, gmSignals, gmExceptions, gmTools
 from Gnumed.exporters import gmPatientExporter
 from Gnumed.business import gmEMRStructItems, gmPerson, gmSOAPimporter
-from Gnumed.wxpython import gmRegetMixin, gmGuiHelpers, gmEMRStructWidgets, gmSOAPWidgets, gmEditArea
+from Gnumed.wxpython import gmGuiHelpers, gmEMRStructWidgets, gmSOAPWidgets, gmAllergyWidgets
 from Gnumed.wxGladeWidgets import wxgScrolledEMRTreePnl, wxgSplittedEMRTreeBrowserPnl
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
 
-# module level constants
-dialog_OK = -2
-
 #============================================================
 def export_emr_to_ascii(parent=None):
 	"""
@@ -34,41 +31,47 @@ def export_emr_to_ascii(parent=None):
 	@type parent - A wx.Window instance
 	"""
 	# sanity checks
+	if parent is None:
+		raise TypeError('[export_emr_to_ascii]: expected wx.Window instance as parent, got <None>')
+
 	pat = gmPerson.gmCurrentPatient()
 	if not pat.is_connected():
-		gmGuiHelpers.gm_statustext(_('Cannot export EMR. No active patient.'), gmLog.lErr)
-		return False
-	if parent is None:
-		_log.Log(gmLog.lErr, 'cannot dump emr in gui mode without parent widget')
+		gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot export EMR. No active patient.'))
 		return False
+
 	# get file name
-	aWildcard = "%s (*.txt)|*.txt|%s (*.*)|*.*" % (_("text files"), _("all files"))
-	aDefDir = os.path.abspath(os.path.expanduser(os.path.join('~', 'gnumed')))
-	ident = pat.get_identity()
-	fname = '%s-%s_%s.txt' % (_('emr-export'), ident['lastnames'], ident['firstnames'])
+	wc = "%s (*.txt)|*.txt|%s (*)|*" % (_("text files"), _("all files"))
+	defdir = os.path.abspath(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'EMR', pat['dirname'])))
+	gmTools.mkdir(defdir)
+	fname = '%s-%s_%s.txt' % (_('emr-export'), pat['lastnames'], pat['firstnames'])
 	dlg = wx.FileDialog (
 		parent = parent,
 		message = _("Save patient's EMR as..."),
-		defaultDir = aDefDir,
+		defaultDir = defdir,
 		defaultFile = fname,
-		wildcard = aWildcard,
+		wildcard = wc,
 		style = wx.SAVE
 	)
 	choice = dlg.ShowModal()
 	fname = dlg.GetPath()
 	dlg.Destroy()
-	if choice == wx.ID_OK:
-		_log.Log(gmLog.lData, 'exporting EMR to [%s]' % fname)
-		output_file = open(fname, 'wb')
-		# instantiate exporter
-		exporter = gmPatientExporter.cEmrExport(patient = pat)
-		exporter.set_output_file(output_file)
-		exporter.dump_constraints()
-		exporter.dump_demographic_record(True)
-		exporter.dump_clinical_record()
-		exporter.dump_med_docs()
-		output_file.close()
-		gmGuiHelpers.gm_show_info('EMR successfully exported to file: %s' % fname, _('emr_dump'), gmLog.lInfo)
+	if choice != wx.ID_OK:
+		return None
+
+	_log.Log(gmLog.lData, 'exporting EMR to [%s]' % fname)
+
+#	output_file = open(fname, 'wb')
+	output_file = codecs.open(fname, 'wb', encoding='utf8', errors='replace')
+	exporter = gmPatientExporter.cEmrExport(patient = pat)
+	exporter.set_output_file(output_file)
+	exporter.dump_constraints()
+	exporter.dump_demographic_record(True)
+	exporter.dump_clinical_record()
+	exporter.dump_med_docs()
+	output_file.close()
+
+	gmDispatcher.send(gmSignals.statustext(), msg = _('EMR successfully exported to file: %s') % fname, beep = False)
+	return fname
 #============================================================
 class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	"""This wx.TreeCtrl derivative displays a tree view of the medical record."""
@@ -97,10 +100,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	#--------------------------------------------------------
 	def refresh(self):
 		if not self.__pat.is_connected():
-			gmGuiHelpers.gm_statustext (
-				_('Cannot load clinical narrative. No active patient.'),
-				gmLog.lWarn
-			)
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot load clinical narrative. No active patient.'),)
 			return False
 
 		if not self.__populate_tree():
@@ -129,8 +129,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		self.DeleteAllItems()
 
 		# init new tree
-		ident = self.__pat.get_identity()
-		root_item = self.AddRoot(_('%s EMR') % ident['description'])
+		root_item = self.AddRoot(_('%s EMR') % self.__pat['description'])
 		self.SetPyData(root_item, None)
 		self.SetItemHasChildren(root_item, True)
 
@@ -155,7 +154,6 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		return True
 	#--------------------------------------------------------
 	def __make_popup_menus(self):
-		# make popup menus for later use
 
 		# - episodes
 		self.__epi_context_popup = wx.Menu()
@@ -163,20 +161,22 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		menu_id = wx.NewId()
 		self.__epi_context_popup.AppendItem(wx.MenuItem(self.__epi_context_popup, menu_id, _('Edit episode details')))
 		wx.EVT_MENU(self.__epi_context_popup, menu_id, self.__edit_episode)
-		# delete episode
+
+		menu_id = wx.NewId()
+		self.__epi_context_popup.AppendItem(wx.MenuItem(self.__epi_context_popup, menu_id, _('Delete episode')))
+		wx.EVT_MENU(self.__epi_context_popup, menu_id, self.__delete_episode)
 		# attach all encounters to another episode
 
 		# - encounters
 		self.__enc_context_popup = wx.Menu()
-		menu_id = wx.NewId()
 		# - move data
+		menu_id = wx.NewId()
 		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('move encounter data to another episode')))
 		wx.EVT_MENU(self.__enc_context_popup, menu_id, self.__relink_encounter_data2episode)
 		# - edit encounter details
+		menu_id = wx.NewId()
 		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('edit consultation details')))
 		wx.EVT_MENU(self.__enc_context_popup, menu_id, self.__edit_consultation_details)
-		# delete encounter
-		# attach all progress notes to another encounter
 
 		# - health issues
 		self.__issue_context_popup = wx.Menu()
@@ -186,9 +186,14 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		
 		# - root node
 		self.__root_context_popup = wx.Menu()
+		# add health issue
 		menu_id = wx.NewId()
 		self.__root_context_popup.AppendItem(wx.MenuItem(self.__root_context_popup, menu_id, _('create health issue')))
 		wx.EVT_MENU(self.__root_context_popup, menu_id, self.__create_issue)
+		# add allergy
+		menu_id = wx.NewId()
+		self.__root_context_popup.AppendItem(wx.MenuItem(self.__root_context_popup, menu_id, _('manage allergies')))
+		wx.EVT_MENU(self.__root_context_popup, menu_id, self.__document_allergy)
 		# print " attach issue to another patient"
 		# print " move all episodes to another issue"
 	#--------------------------------------------------------
@@ -198,19 +203,37 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		self.PopupMenu(self.__epi_context_popup, pos)
 	#--------------------------------------------------------
 	def __edit_episode(self, event):
-		node_data = self.GetPyData(self.__curr_node)
-		dlg = gmEMRStructWidgets.cEpisodeEditAreaDlg(parent=self, episode=node_data)
+		dlg = gmEMRStructWidgets.cEpisodeEditAreaDlg(parent=self, episode=self.__curr_node_data)
 		result = dlg.ShowModal()
 		if result == wx.ID_OK:
 			self.__populate_tree()
 	#--------------------------------------------------------
 	def __delete_episode(self, event):
-		print "deleting episode"
-		print self.__curr_node_data
-	#--------------------------------------------------------
-	def __relink_episode_encounters(self, event):
-		print "relinking encounters of episode"
-		print self.__curr_node_data
+		dlg = gmGuiHelpers.c2ButtonQuestionDlg (
+			parent = self,
+			id = -1,
+			caption = _('Deleting episode'),
+			button_defs = [
+				{'label': _('Yes, delete'), 'tooltip': _('Delete the episode if possible (it must be completely empty).')},
+				{'label': _('No, cancel'), 'tooltip': _('Cancel and do NOT delete the episode.')}
+			],
+			question = _(
+				'Are you sure you want to delete this episode ?\n'
+				'\n'
+				' "%s"\n'
+			) % self.__curr_node_data['description']
+		)
+		result = dlg.ShowModal()
+		if result != wx.ID_YES:
+			return
+
+		try:
+			gmEMRStructItems.delete_episode(episode = self.__curr_node_data)
+		except gmExceptions.DatabaseObjectInUseError:
+			gmDispatcher.send(signal = gmSignals.statustext(), msg = _('Cannot delete episode. There is still clinical data recorded for it.'))
+			return
+
+		self.__populate_tree()
 	#--------------------------------------------------------
 	# encounters
 	def __handle_encounter_context(self, pos=wx.DefaultPosition):
@@ -227,68 +250,50 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		node_parent = self.GetItemParent(self.__curr_node)
 		owning_episode = self.GetPyData(node_parent)
 
-		episode_selector = gmEMRStructWidgets.cEpisodeSelectorDlg (
-			None,
+		episode_selector = gmEMRStructWidgets.cMoveNarrativeDlg (
+			self,
 			-1,
-			caption = _('Reordering EMR ...'),
-			msg = _(
-				'The EMR entries in this encounter were attached to episode:\n "%s"\n'
-				"Please select the episode you want to move them to:"
-			) % owning_episode['description'],
-			action_txt = _('move entries'),
-			pk_health_issue = owning_episode['pk_health_issue']
+			episode = owning_episode,
+			encounter = self.__curr_node_data
 		)
-		retval = episode_selector.ShowModal()
-		target = episode_selector.get_selected_episode()
+
+		result = episode_selector.ShowModal()
 		episode_selector.Destroy()
-		
-		if retval == dialog_OK:
-			target_episode_node = self.__find_node(self.GetRootItem(), target)
-			if target_episode_node and target_episode_node.IsOk():
-				print "DEBUG trying to move node ", node, " to ", target_episode_node
-				self.__move_node(node, target_episode_node)
-				self.EnsureVisible(target_episode_node)
-			else:
-				print "No target episode node found"
-			self.__curr_node_data.transfer_clinical_data (
-				source_episode = owning_episode,
-				target_episode = target_episode_node
-			)
-		
-		# FIXME: GNUmed internal signal
-		#self._on_episodes_modified()
+
+		if result == wx.ID_YES:
+			self.__populate_tree()
 	#--------------------------------------------------------
-	def __find_node(self, root, data_object):
-		nodes = []
-		id , cookie = self.GetFirstChild(root)
+#	def __find_node(self, root, data_object):
+#		nodes = []
+#		id , cookie = self.GetFirstChild(root)
 
 		#print "DEBUG id , cookie", id, cookie
 		#print "DEBUG id dict is ", id.__dict__.keys()
-		while id.IsOk():
-			nodes.append(id)
-			id, cookie = self.GetNextChild( root, cookie)
+#		while id.IsOk():
+#			nodes.append(id)
+#			id, cookie = self.GetNextChild( root, cookie)
 
-		l = [x for x in nodes if self.GetPyData(x) == data_object]
-		if l == []:
-			print "DEBUG looking further in ", nodes
-			if nodes == []:
-				return None
-			else:
-				for x in nodes:
-					val = self.__find_node(x, data_object)
-					if val:
-						return val
-		else:
-			return l[0]
+#		l = [x for x in nodes if self.GetPyData(x) == data_object]
+#		if l == []:
+#			print "DEBUG looking further in ", nodes
+#			if nodes == []:
+#				return None
+#			else:
+#				for x in nodes:
+#					val = self.__find_node(x, data_object)
+#					if val:
+#						return val
+#		else:
+#			return l[0]
 	#--------------------------------------------------------
-	def __move_node(self, node, target_node):
-		new_node = self.AppendItem(target_node, self.GetItemText(node))
-		self.SetPyData(new_node, self.GetPyData(node))
-		id, cookie = self.GetFirstChild(node)
-		while id.IsOk():
-			self.__move_node(id, new_node)
-			id, cookie = self.GetNextChild(node)
-		self.Delete(node)
+#	def __move_node(self, node, target_node):
+#		new_node = self.AppendItem(target_node, self.GetItemText(node))
+#		self.SetPyData(new_node, self.GetPyData(node))
+#		id, cookie = self.GetFirstChild(node)
+#		while id.IsOk():
+#			self.__move_node(id, new_node)
+#			id, cookie = self.GetNextChild(node)
+#		self.Delete(node)
 	#--------------------------------------------------------
 	# health issues
 	def __handle_issue_context(self, pos=wx.DefaultPosition):
@@ -297,46 +302,25 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	#--------------------------------------------------------
 	def __edit_issue(self, event):
 		ea = gmEMRStructWidgets.cHealthIssueEditAreaDlg(parent=self, id=-1, issue=self.__curr_node_data)
-		ea.ShowModal()
-		self.SetItemText(self.__curr_node, self.__curr_node_data['description'])
-		self.Refresh()
-		#self.Update()
+		if ea.ShowModal() == wx.ID_OK:
+			self.__populate_tree()
 		return
 	#--------------------------------------------------------
 	# root
 	def __handle_root_context(self, pos=wx.DefaultPosition):
-		self.PopupMenu(self.__root_context_popup, pos)		
+		self.PopupMenu(self.__root_context_popup, pos)
 	#--------------------------------------------------------
 	def __create_issue(self, event):
-
-		return True
-
-		# FIXME: refactor this code, present in three places
-		pat = gmPerson.gmCurrentPatient()
-		if not pat.is_connected():
-			gmGuiHelpers.gm_statustext(_('Cannot add health issue. No active patient.'), gmLog.lErr)
-			return False
-		ea = gmEMRStructWidgets.cHealthIssueEditArea (
-			self,
-			-1,
-			wx.DefaultPosition,
-			wx.DefaultSize,
-			wx.NO_BORDER | wx.TAB_TRAVERSAL
-		)
-			
-		popup = gmEditArea.cEditAreaPopup (
-			parent = None,
-			id = -1,
-			title = _('Add health issue (pHx item)'),
-			size = (200,200),
-			pos = wx.DefaultPosition,
-			style = wx.CENTRE | wx.STAY_ON_TOP | wx.CAPTION | wx.SUNKEN_BORDER,
-			name ='',
-			edit_area = ea
-		)
-		result = popup.ShowModal()
-		if ea._health_issue :
-			self.__exporter._add_health_issue_branch (self, ea._health_issue)
+		ea = gmEMRStructWidgets.cHealthIssueEditAreaDlg(parent=self, id=-1)
+		if ea.ShowModal() == wx.ID_OK:
+			self.__populate_tree()
+		return
+	#--------------------------------------------------------
+	def __document_allergy(self, event):
+		dlg = gmAllergyWidgets.cAllergyManagerDlg(parent=self, id=-1)
+		if dlg.ShowModal() == wx.ID_OK:
+			self.__populate_tree()
+		return
 	#--------------------------------------------------------
 	# event handlers
 	#--------------------------------------------------------
@@ -394,6 +378,8 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		 0: 1 = 2
 		 1: 1 > 2
 		"""
+		# FIXME: implement sort modes, chron, reverse cron, by regex, etc
+
 		item1 = self.GetPyData(node1)
 		item2 = self.GetPyData(node2)
 
@@ -415,29 +401,22 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 
 		return 0
 #================================================================
-class cScrolledEMRTreePnl(wxgScrolledEMRTreePnl.wxgScrolledEMRTreePnl, gmRegetMixin.cRegetOnPaintMixin):
+class cScrolledEMRTreePnl(wxgScrolledEMRTreePnl.wxgScrolledEMRTreePnl):
 	"""A scrollable panel holding an EMR tree.
 
 	Lacks a widget to display details for selected items. The
-	tree data will be refetched - if necessary - when the widget
-	is repainted. Refetching can also be initiated (given it is
-	necessary) by calling repopulate_ui().
+	tree data will be refetched - if necessary - whenever
+	repopulate_ui() is called, e.g., when then patient is changed.
 	"""
 	def __init__(self, *args, **kwds):
 		wxgScrolledEMRTreePnl.wxgScrolledEMRTreePnl.__init__(self, *args, **kwds)
-		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
-		self.__register_interests()
+#		self.__register_interests()
 	#--------------------------------------------------------
-	# reget mixin API
+#	def __register_interests(self):
+#		gmDispatcher.connect(signal=gmSignals.post_patient_selection(), receiver=self.repopulate_ui)
 	#--------------------------------------------------------
-	def __register_interests(self):
-		gmDispatcher.connect(signal=gmSignals.post_patient_selection(), receiver=self._schedule_data_reget)
-	#--------------------------------------------------------
-	def _populate_with_data(self):
-		"""Fills UI with data."""
-		if not self._emr_tree.refresh():
-			_log.Log(gmLog.lErr, "cannot update EMR tree")
-			return False
+	def repopulate_ui(self):
+		self._emr_tree.refresh()
 		return True
 #============================================================
 class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTreeBrowserPnl):
@@ -445,24 +424,32 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 
 	The left hand side displays a scrollable EMR tree while
 	on the right details for selected items are displayed.
+
+	Expects to be put into a Notebook.
 	"""
 	def __init__(self, *args, **kwds):
 		wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTreeBrowserPnl.__init__(self, *args, **kwds)
 		self._pnl_emr_tree._emr_tree.set_narrative_display(narrative_display = self._TCTRL_item_details)
+		self.__register_events()
+	#--------------------------------------------------------
+	def __register_events(self):
+		gmDispatcher.connect(signal = gmSignals.post_patient_selection(), receiver = self._on_post_patient_selection)
+		return True
+	#--------------------------------------------------------
+	def _on_post_patient_selection(self):
+		if self.GetParent().GetCurrentPage() == self:
+			self.repopulate_ui()
+		return True
 	#--------------------------------------------------------
 	def repopulate_ui(self):
 		"""Fills UI with data."""
-		if not self._pnl_emr_tree._populate_with_data():
-			_log.Log(gmLog.lErr, "cannot update EMR tree")
-			return False
+		self._pnl_emr_tree.repopulate_ui()
 		self._splitter_browser.SetSashPosition(self._splitter_browser.GetSizeTuple()[0]/3, True)
 		return True
 #================================================================
-#class cEMRJournalPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixin):
 class cEMRJournalPanel(wx.Panel):
 	def __init__(self, *args, **kwargs):
 		wx.Panel.__init__(self, *args, **kwargs)
-#		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
 
 		self.__do_layout()
 
@@ -488,43 +475,34 @@ class cEMRJournalPanel(wx.Panel):
 		self.Layout()
 	#--------------------------------------------------------
 	def __register_events(self):
-		# client internal signals
 		gmDispatcher.connect(signal = gmSignals.post_patient_selection(), receiver = self._on_post_patient_selection)
-		return 1
+		return True
 	#--------------------------------------------------------
 	def _on_post_patient_selection(self):
-		# FIXME: check for visibility
-		self.__journal.SetValue(u'')
+		"""Expects to be in a Notebook."""
+		if self.GetParent().GetCurrentPage() == self:
+			self.repopulate_ui()
 		return True
 	#--------------------------------------------------------
 	# notebook plugin API
 	#--------------------------------------------------------
 	def repopulate_ui(self):
-		# get data from backend
 		txt = StringIO.StringIO()
 		exporter = gmPatientExporter.cEMRJournalExporter()
 		# FIXME: if journal is large this will error out, use generator/yield etc
-		successful = exporter.export(txt)
-		if not successful:
-			_log.Log(gmLog.lErr, 'cannot get EMR journal')
+		# FIXME: turn into proper list
+		try:
+			exporter.export(txt)
+			self.__journal.SetValue(txt.getvalue())
+			txt.close()
+		except ValueError:
+			_log.LogException('cannot get EMR journal')
 			self.__journal.SetValue (_(
 				'An error occurred while retrieving the EMR\n'
 				'in journal form for the active patient.\n\n'
 				'Please check the log file for details.'
 			))
-			return False
-		self.__journal.SetValue(txt.getvalue())
-		txt.close()
 		return True
-	#--------------------------------------------------------
-	# reget mixin API
-	#--------------------------------------------------------
-#	def _populate_with_data(self):
-#		"""Fills UI with data.
-#		"""
-#		if self.refresh_journal():
-#			return True
-#		return False
 #================================================================
 # MAIN
 #----------------------------------------------------------------
@@ -571,6 +549,36 @@ if __name__ == '__main__':
 
 #================================================================
 # $Log: gmEMRBrowser.py,v $
+# Revision 1.75  2007/05/21 14:48:20  ncq
+# - cleanup
+# - use pat['dirname'], use export/EMR/
+# - unicode output files
+#
+# Revision 1.74  2007/05/21 13:05:25  ncq
+# - catch-all wildcard on UNIX must be *, not *.*
+#
+# Revision 1.73  2007/05/18 13:29:25  ncq
+# - some cleanup
+# - properly support moving narrative between episodes
+#
+# Revision 1.72  2007/05/14 13:11:24  ncq
+# - use statustext() signal
+#
+# Revision 1.71  2007/05/14 10:33:33  ncq
+# - allow deleting episode
+#
+# Revision 1.70  2007/03/18 14:04:00  ncq
+# - add allergy handling to menu and root node of tree
+#
+# Revision 1.69  2007/03/02 15:31:45  ncq
+# - properly repopulation EMR tree and problem list :-)
+#
+# Revision 1.68  2007/02/22 17:41:13  ncq
+# - adjust to gmPerson changes
+#
+# Revision 1.67  2007/02/16 12:51:46  ncq
+# - fix add issue popup on root node as requested by user :-)
+#
 # Revision 1.66  2007/01/16 18:00:59  ncq
 # - cleanup
 # - explicitely sort episodes and encounters by when they were started
