@@ -11,25 +11,143 @@ to anybody else.
 """
 # ========================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmGuiHelpers.py,v $
-# $Id: gmGuiHelpers.py,v 1.48 2007/01/20 22:52:27 ncq Exp $
-__version__ = "$Revision: 1.48 $"
+# $Id: gmGuiHelpers.py,v 1.61.2.1 2007/06/06 08:21:39 ncq Exp $
+__version__ = "$Revision: 1.61.2.1 $"
 __author__  = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
-import sys, string, os
+import sys, os, shutil, datetime as pyDT, traceback
 
 if __name__ == '__main__':
 	sys.exit("This is not intended to be run standalone !")
 
 import wx
 
-from Gnumed.pycommon import gmLog, gmGuiBroker, gmPG2, gmLoginInfo
-from Gnumed.wxGladeWidgets import wxg3ButtonQuestionDlg
+from Gnumed.business import gmSurgery
+from Gnumed.pycommon import gmLog, gmGuiBroker, gmPG2, gmLoginInfo, gmDispatcher, gmSignals
+from Gnumed.wxGladeWidgets import wxg3ButtonQuestionDlg, wxg2ButtonQuestionDlg, wxgUnhandledExceptionDlg
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lData, __version__)
 
-_set_status_text = None
+_prev_excepthook = None
+
+# ========================================================================
+def handle_uncaught_exception_wx(t, v, tb):
+
+	_log.LogException('unhandled exception caught', (t,v,tb), verbose=True)
+
+	for target in _log.get_targets():
+		if not isinstance(target, gmLog.cLogTargetFile):
+			continue
+		name = os.path.basename(target.ID)
+		name, ext = os.path.splitext(name)
+		new_name = os.path.expanduser(os.path.join (
+			'~',
+			'gnumed',
+			'logs',
+			'%s_%s%s' % (name, pyDT.datetime.now().strftime('%Y-%m-%d_%H-%M-%S'), ext)
+		))
+		_log.Log(gmLog.lWarn, 'syncing log file for backup to [%s]' % new_name)
+		_log.flush()
+		shutil.copy2(target.ID, new_name)
+
+	try: wx.EndBusyCursor()
+	except: pass
+
+	dlg = cUnhandledExceptionDlg(parent = None, id = -1, exception = (t, v, tb), logfile = new_name)
+	dlg.ShowModal()
+	dlg.Destroy()
+# ------------------------------------------------------------------------
+def install_wx_exception_handler():
+	global _prev_excepthook
+	_prev_excepthook = sys.excepthook
+	sys.excepthook = handle_uncaught_exception_wx
+	return True
+# ------------------------------------------------------------------------
+def uninstall_wx_exception_handler():
+	if _prev_excepthook is None:
+		sys.excepthook = sys.__excepthook__
+		return True
+	sys.excepthook = _prev_excepthook
+	return True
+# ========================================================================
+class cUnhandledExceptionDlg(wxgUnhandledExceptionDlg.wxgUnhandledExceptionDlg):
+
+	def __init__(self, *args, **kwargs):
+
+		exception = kwargs['exception']
+		del kwargs['exception']
+		logfile = kwargs['logfile']
+		del kwargs['logfile']
+
+		wxgUnhandledExceptionDlg.wxgUnhandledExceptionDlg.__init__(self, *args, **kwargs)
+
+		office = gmSurgery.gmCurrentPractice()
+		self._TCTRL_helpdesk.SetValue(office.helpdesk)
+		self._TCTRL_logfile.SetValue(logfile)
+		t, v, tb = exception
+		self._TCTRL_exc_type.SetValue(str(t))
+		self._TCTRL_exc_value.SetValue(str(v))
+		self._TCTRL_traceback.SetValue(''.join(traceback.format_tb(tb)))
+
+		self.Fit()
+	#------------------------------------------
+	def _on_close_gnumed_button_pressed(self, evt):
+		top_win = wx.GetApp().GetTopWindow()
+		wx.CallAfter(top_win.Close)
+		evt.Skip()
+# ========================================================================
+class c2ButtonQuestionDlg(wxg2ButtonQuestionDlg.wxg2ButtonQuestionDlg):
+
+	def __init__(self, *args, **kwargs):
+
+		caption = kwargs['caption']
+		question = kwargs['question']
+		button_defs = kwargs['button_defs'][:2]
+		try:
+			show_checkbox = kwargs['show_checkbox']
+			del kwargs['show_checkbox']
+		except KeyError:
+			show_checkbox = False
+
+		del kwargs['caption']
+		del kwargs['question']
+		del kwargs['button_defs']
+
+		wxg2ButtonQuestionDlg.wxg2ButtonQuestionDlg.__init__(self, *args, **kwargs)
+
+		self.SetTitle(title = caption)
+		self._LBL_question.SetLabel(label = question)
+
+		if not show_checkbox:
+			self._CHBOX_dont_ask_again.Hide()
+
+		buttons = [self._BTN_1, self._BTN_2]
+		for idx in range(len(button_defs)):
+			buttons[idx].SetLabel(label = button_defs[idx]['label'])
+			buttons[idx].SetToolTipString(button_defs[idx]['tooltip'])
+			try:
+				if button_defs[idx]['default']:
+					buttons[idx].SetDefault()
+			except KeyError:
+				pass
+
+		self.Fit()
+	#--------------------------------------------------------
+	# event handlers
+	#--------------------------------------------------------
+	def _on_BTN_1_pressed(self, evt):
+		if self.IsModal():
+			self.EndModal(wx.ID_YES)
+		else:
+			self.Close()
+	#--------------------------------------------------------
+	def _on_BTN_2_pressed(self, evt):
+		if self.IsModal():
+			self.EndModal(wx.ID_NO)
+		else:
+			self.Close()
 # ========================================================================
 class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 
@@ -165,7 +283,7 @@ class cFileDropTarget(wx.FileDropTarget):
 		Widgets being declared file drop targets
 		must provide the method:
 
-			add_filename(filenames)
+			add_filenames(filenames)
 	"""
 	#-----------------------------------------------
 	def __init__(self, target):
@@ -180,8 +298,7 @@ def gm_SingleChoiceDialog(aMessage = None, aTitle = None, aLogLevel = None, choi
         aMessage = _('programmer forgot to specify info message')
 
     if aLogLevel is not None:
-        log_msg = string.replace(aMessage, '\015', ' ')
-        log_msg = string.replace(log_msg, '\012', ' ')
+        log_msg = aMessage.replace('\015', ' ').replace('\012', ' ')
         _log.Log(aLogLevel, log_msg)
 
     if aTitle is None:
@@ -207,8 +324,7 @@ def gm_show_error(aMessage = None, aTitle = None, aLogLevel = None):
 		aMessage = _('programmer forgot to specify error message')
 
 	if aLogLevel is not None:
-		log_msg = string.replace(aMessage, '\015', ' ')
-		log_msg = string.replace(log_msg, '\012', ' ')
+		log_msg = aMessage.replace('\015', ' ').replace('\012', ' ')
 		_log.Log(aLogLevel, log_msg)
 
 	aMessage += _("\n\nPlease consult the error log for all the gory details !")
@@ -236,8 +352,7 @@ def gm_show_info(aMessage = None, aTitle = None, aLogLevel = None):
 		aMessage = _('programmer forgot to specify info message')
 
 	if aLogLevel is not None:
-		log_msg = string.replace(aMessage, '\015', ' ')
-		log_msg = string.replace(log_msg, '\012', ' ')
+		log_msg = aMessage.replace('\015', ' ').replace('\012', ' ')
 		_log.Log(aLogLevel, log_msg)
 
 	if aTitle is None:
@@ -258,8 +373,7 @@ def gm_show_warning(aMessage = None, aTitle = None, aLogLevel = None):
 		aMessage = _('programmer forgot to specify warning')
 
 	if aLogLevel is not None:
-		log_msg = string.replace(aMessage, '\015', ' ')
-		log_msg = string.replace(log_msg, '\012', ' ')
+		log_msg = aMessage.replace('\015', ' ').replace('\012', ' ')
 		_log.Log(aLogLevel, log_msg)
 
 	if aTitle is None:
@@ -297,59 +411,35 @@ def gm_show_question(aMessage = 'programmer forgot to specify question', aTitle
 	else:
 		return None
 #-------------------------------------------------------------------------
-# FIXME: actually make this use a signal !
-def gm_statustext(aMessage=None, aLogLevel=None, beep=True):
-	if aMessage is None:
-		aMessage = _('programmer forgot to specify alert message')
-
-	if aLogLevel is not None:
-		log_msg = aMessage.replace('\015', ' ')
-		log_msg = log_msg.replace('\012', ' ')
-		_log.Log(aLogLevel, log_msg)
-
-	if beep:
-		wx.Bell()
-
-	# only now and here can we assume that wxWindows
-	# is sufficiently initialized
-	global _set_status_text
-	if _set_status_text is None:
-		try:
-			_set_status_text = gmGuiBroker.GuiBroker()['main.statustext']
-		except KeyError:
-			_log.LogException('called too early, cannot set status text', sys.exc_info(), verbose=0)
-			print "Status message:", aMessage
-			return 1
-
-	_set_status_text(aMessage)
-	return 1
-#-------------------------------------------------------------------------
-def get_dbowner_connection(procedure=None):
+def get_dbowner_connection(procedure=None, dbo_password=None):
 	if procedure is None:
 		procedure = _('<restricted procedure>')
 
 	# 1) get password for gm-dbo
-	pwd_gm_dbo = wx.GetPasswordFromUser (
-		message = _("""
+	if dbo_password is None:
+		pwd_gm_dbo = wx.GetPasswordFromUser (
+			message = _("""
  [%s]
 
 This is a restricted procedure. We need the
 password for the GNUmed database owner.
 
 Please enter the password for <gm-dbo>:""") % procedure,
-		caption = procedure
-	)
-	if pwd_gm_dbo == '':
-		return None
+			caption = procedure
+		)
+		if pwd_gm_dbo == '':
+			return None
+	else:
+		pwd_gm_dbo = dbo_password
 
 	# 2) connect as gm-dbo
 	login = gmPG2.get_default_login()
 	dsn = gmPG2.make_psycopg2_dsn(database=login.database, host=login.host, port=login.port, user='gm-dbo', password=pwd_gm_dbo)
 	try:
-		conn = gmPG2.get_connection(dsn=dsn, readonly=False, verbose=True)
+		conn = gmPG2.get_connection(dsn=dsn, readonly=False, verbose=True, pooled=False)
 	except:
 		_log.LogException('cannot connect')
-		gmGuiHelpers.gm_show_error (
+		gm_show_error (
 			aMessage = _('Cannot connect as the GNUmed database owner <gm-dbo>.'),
 			aTitle = procedure,
 			aLogLevel = gmLog.lErr
@@ -357,15 +447,6 @@ Please enter the password for <gm-dbo>:""") % procedure,
 		return None
 
 	return conn
-#------------------------------------------------------------------------
-def gm_icon (name):
-	"""
-	Returns a icon based on the name
-	Hint: run names through gettext ()
-	"""
-	fname = os.path.join(gmGuiBroker.GuiBroker ()['gnumed_dir'], 'bitmaps', '%s.png' % name)
-	img = wx.Image(fname, wx.BITMAP_TYPE_ANY)
-	return wx.BitmapFromImage(img)
 #----------------------------------------------------------------------
 def makePageTitle(wizPg, title):
 	"""
@@ -384,6 +465,8 @@ def makePageTitle(wizPg, title):
 	sizer.Add(wx.StaticLine(wizPg, -1), 0, wx.EXPAND|wx.ALL, 2)
 	return sizer	
 #============================================================
+import string			# remove !
+
 class cTextWidgetValidator(wx.PyValidator):
 	"""
 	This validator is used to ensure that the user has entered any value
@@ -430,7 +513,6 @@ class cTextWidgetValidator(wx.PyValidator):
 
 		if self.__non_empty and val.strip() == '':
 			print self.__msg
-#			gm_statustext(self.__msg)
 			ctrl.SetBackgroundColour('pink')
 			ctrl.SetFocus()
 			ctrl.Refresh()
@@ -439,7 +521,6 @@ class cTextWidgetValidator(wx.PyValidator):
 			for char in val:
 				if not char in string.digits:
 					print self.__msg
-#					gm_statustext(self.__msg)
 					ctrl.SetBackgroundColour('pink')
 					ctrl.SetFocus()
 					ctrl.Refresh()					
@@ -491,6 +572,50 @@ class cTextWidgetValidator(wx.PyValidator):
 
 # ========================================================================
 # $Log: gmGuiHelpers.py,v $
+# Revision 1.61.2.1  2007/06/06 08:21:39  ncq
+# - MSW does ref counting on Begin/EndBusyCursor :-( so deal with that
+#
+# Revision 1.61  2007/05/14 10:34:07  ncq
+# - no more gm_statustext()
+#
+# Revision 1.60  2007/05/14 10:05:33  ncq
+# - make "default" button definition optional
+#
+# Revision 1.59  2007/05/14 08:36:13  ncq
+# - in c2ButtonQuestionDlg make keyword show_checkbox option defaulting to False
+#
+# Revision 1.58  2007/05/11 14:15:59  ncq
+# - display help desk in exception handler
+# - properly handle keep running/close client buttons
+#
+# Revision 1.57  2007/05/08 16:04:40  ncq
+# - add wxPython based exception display handler
+#
+# Revision 1.56  2007/04/27 13:28:48  ncq
+# - implement c2ButtonQuestionDlg
+#
+# Revision 1.55  2007/04/23 01:06:42  ncq
+# - add password argument to get_dbowner_connection()
+#
+# Revision 1.54  2007/04/11 20:41:58  ncq
+# - remove gm_icon()
+#
+# Revision 1.53  2007/04/09 22:02:40  ncq
+# - fix docstring
+#
+# Revision 1.52  2007/03/18 14:07:14  ncq
+# - factor out hook script running
+#
+# Revision 1.51  2007/03/02 15:32:56  ncq
+# - turn gm_statustext() into signal sender with depreciation
+#   warning (should used gmDispatcher.send() now)
+#
+# Revision 1.50  2007/02/19 16:13:36  ncq
+# - add run_hook_script()
+#
+# Revision 1.49  2007/02/18 16:57:38  ncq
+# - make sure gm-dbo connections aren't returned from the pool
+#
 # Revision 1.48  2007/01/20 22:52:27  ncq
 # - .KeyCode -> GetKeyCode()
 #
