@@ -12,8 +12,8 @@ copyright: authors
 """
 #==============================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmHorstSpace.py,v $
-# $Id: gmHorstSpace.py,v 1.35 2006/12/17 20:44:52 ncq Exp $
-__version__ = "$Revision: 1.35 $"
+# $Id: gmHorstSpace.py,v 1.37 2007/02/17 14:13:11 ncq Exp $
+__version__ = "$Revision: 1.37 $"
 __author__  = "H. Herb <hherb@gnumed.net>,\
 			   K. Hilbert <Karsten.Hilbert@gmx.net>,\
 			   I. Haywood <i.haywood@ugrad.unimelb.edu.au>"
@@ -29,8 +29,9 @@ from Gnumed.business import gmPerson
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
-		  
+
 #==============================================================================
+# finding the visible page from a notebook page: self.GetParent.GetCurrentPage == self
 class cHorstSpaceLayoutMgr(wx.Panel):
 	"""GnuMed inner-frame layout manager.
 
@@ -146,7 +147,7 @@ class cHorstSpaceLayoutMgr(wx.Panel):
 		me = gmPerson.gmCurrentProvider()
 		default_plugin = db_cfg.get2 (
 			option = u'patient_search.plugin_to_raise_after_search',
-			workplace = me.get_workplace(),
+			workplace = me.workplace,
 			bias = u'user',
 			default = u'gmEMRBrowserPlugin'
 		)
@@ -310,6 +311,12 @@ if __name__ == '__main__':
 
 #==============================================================================
 # $Log: gmHorstSpace.py,v $
+# Revision 1.37  2007/02/17 14:13:11  ncq
+# - gmPerson.gmCurrentProvider().workplace now property
+#
+# Revision 1.36  2007/02/15 14:57:49  ncq
+# - cleanup
+#
 # Revision 1.35  2006/12/17 20:44:52  ncq
 # - cleanup
 #
