@@ -6,8 +6,8 @@
 # @license: GPL (details at http://www.gnu.org)
 ############################################################################
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmLogin.py,v $
-# $Id: gmLogin.py,v 1.30 2006/12/15 15:27:01 ncq Exp $
-__version__ = "$Revision: 1.30 $"
+# $Id: gmLogin.py,v 1.33 2007/04/27 13:29:31 ncq Exp $
+__version__ = "$Revision: 1.33 $"
 __author__ = "H.Herb"
 
 import wx
@@ -86,13 +86,22 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 			user = login.user,
 			password = login.password
 		)
-		try:
-			gmPG2.get_connection(dsn=dsn, verbose=True)
-			gmPG2.set_default_login(login=login)
 
-			if gmPG2.database_schema_compatible(version = expected_version):
-				dlg.panel.save_settings()
-			else:
+		try:
+			# try getting a connection to verify the DSN works
+			gmPG2.get_raw_connection(dsn = dsn, verbose = True)
+			gmPG2.set_default_login(login = login)
+			gmPG2.set_default_client_encoding(encoding = dlg.panel.backend_profile.encoding)
+
+			compatible = gmPG2.database_schema_compatible(version = expected_version)
+
+			if compatible or not require_version:
+				dlg.panel.save_state()
+
+			if not compatible:
+				_log.Log(gmLog.lData, 'normalized schema dump follows:')
+				for line in gmPG2.get_schema_structure().split():
+					_log.Log(gmLog.lData, line)
 				connected_db_version = gmPG2.get_schema_version()
 				msg = msg_generic % (connected_db_version, expected_version, login.host, login.database, login.user)
 				if require_version:
@@ -132,6 +141,16 @@ if __name__ == "__main__":
 	print "This module needs a test function!  please write it"
 #==============================================================
 # $Log: gmLogin.py,v $
+# Revision 1.33  2007/04/27 13:29:31  ncq
+# - log schema dump on version conflict
+#
+# Revision 1.32  2007/03/18 14:10:07  ncq
+# - do show schema mismatch warning even if --override-schema-check
+#
+# Revision 1.31  2007/03/08 11:41:55  ncq
+# - set default client encoding from here
+# - save state when --override-schema-check == True, too
+#
 # Revision 1.30  2006/12/15 15:27:01  ncq
 # - move database schema version check here
 #
