@@ -2,15 +2,15 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmMedDocWidgets.py,v $
-# $Id: gmMedDocWidgets.py,v 1.110 2007/01/18 22:13:37 ncq Exp $
-__version__ = "$Revision: 1.110 $"
+# $Id: gmMedDocWidgets.py,v 1.127 2007/05/21 14:49:20 ncq Exp $
+__version__ = "$Revision: 1.127 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
 import os.path, sys, re as regex
 
 import wx
 
-from Gnumed.pycommon import gmLog, gmI18N, gmCfg, gmPG2, gmMimeLib, gmExceptions, gmMatchProvider, gmDispatcher, gmSignals, gmFuzzyTimestamp
+from Gnumed.pycommon import gmLog, gmI18N, gmCfg, gmPG2, gmMimeLib, gmExceptions, gmMatchProvider, gmDispatcher, gmSignals, gmDateTime, gmTools
 from Gnumed.business import gmPerson, gmMedDoc
 from Gnumed.wxpython import gmGuiHelpers, gmRegetMixin, gmPhraseWheel, gmPlugin
 from Gnumed.wxGladeWidgets import wxgScanIdxPnl, wxgReviewDocPartDlg, wxgSelectablySortedDocTreePnl, wxgEditDocumentTypesPnl, wxgEditDocumentTypesDlg
@@ -23,6 +23,8 @@ class cDocumentCommentPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""Let user select a document comment from all existing comments."""
 	def __init__(self, *args, **kwargs):
 
+		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
+
 		context = {
 			u'ctxt_doc_type': {
 				u'where_part': u'and fk_type = %(pk_doc_type)s',
@@ -57,14 +59,8 @@ limit 25"""],
 		mp.setThresholds(3, 5, 7)
 		mp.unset_context(u'pk_doc_type')
 
-		kwargs['aMatchProvider'] = mp
-		kwargs['aDelay'] = 50
-		kwargs['selection_only'] = False
-		gmPhraseWheel.cPhraseWheel.__init__ (
-			self,
-			*args,
-			**kwargs
-		)
+		self.matcher = mp
+		self.picklist_delay = 50
 #============================================================
 class cEditDocumentTypesDlg(wxgEditDocumentTypesDlg.wxgEditDocumentTypesDlg):
 	"""A dialog showing a cEditDocumentTypesPnl."""
@@ -162,8 +158,8 @@ class cEditDocumentTypesPnl(wxgEditDocumentTypesPnl.wxgEditDocumentTypesPnl):
 			l10n_desc = self._TCTRL_l10n_type.GetValue().strip()
 			if (l10n_desc != '') and (l10n_desc != doc_type['l10n_type']):
 				doc_type.set_translation(translation = l10n_desc)
+			self.repopulate_ui()
 
-		self.repopulate_ui()
 		return
 	#--------------------------------------------------------
 	def _on_type_modified(self, event):
@@ -177,6 +173,8 @@ class cDocumentTypeSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""Let user select a document type."""
 	def __init__(self, *args, **kwargs):
 
+		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
+
 		mp = gmMatchProvider.cMatchProvider_SQL2 (
 			queries = [
 u"""select * from ((
@@ -192,14 +190,8 @@ u"""select * from ((
 			)
 		mp.setThresholds(2, 4, 6)
 
-		kwargs['aMatchProvider'] = mp
-		kwargs['aDelay'] = 50
-		kwargs['selection_only'] = False
-		gmPhraseWheel.cPhraseWheel.__init__ (
-			self,
-			*args,
-			**kwargs
-		)
+		self.matcher = mp
+		self.picklist_delay = 50
 	#--------------------------------------------------------
 	def GetData(self, can_create=False):
 		if self.data is None:
@@ -207,28 +199,49 @@ u"""select * from ((
 				self.data = gmMedDoc.create_document_type(self.GetValue().strip())['pk_doc_type']	# FIXME: error handling
 		return self.data
 #============================================================
+# slightly misnamed due to 
 class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 	def __init__(self, *args, **kwds):
-		self.__part = kwds['part']
+		"""Support parts and docs now.
+		"""
+		part = kwds['part']
 		del kwds['part']
 		wxgReviewDocPartDlg.wxgReviewDocPartDlg.__init__(self, *args, **kwds)
+
+		if isinstance(part, gmMedDoc.cMedDocPart):
+			self.__part = part
+			self.__doc = self.__part.get_containing_document()
+			self.__reviewing_doc = False
+		elif isinstance(part, gmMedDoc.cMedDoc):
+			self.__doc = part
+			self.__part = self.__doc.get_parts()[0]
+			self.__reviewing_doc = True
+		else:
+			raise ValueError('<part> must be gmMedDoc.cMedDoc or gmMedDoc.cMedDocPart instance, got <%s>' % type(part))
+
 		self.__init_ui_data()
 	#--------------------------------------------------------
 	# internal API
 	#--------------------------------------------------------
 	def __init_ui_data(self):
+		# FIXME: fix this
 		# associated episode (add " " to avoid popping up pick list)
-		self._PhWheel_episode.SetValue('%s ' % self.__part['episode'], self.__part['pk_episode'])
-		self._PhWheel_doc_type.SetValue(value = self.__part['l10n_type'], data = self.__part['pk_type'])
+		self._PhWheel_episode.SetText('%s ' % self.__part['episode'], self.__part['pk_episode'])
+		self._PhWheel_doc_type.SetText(value = self.__part['l10n_type'], data = self.__part['pk_type'])
 		self._PhWheel_doc_type.add_callback_on_lose_focus(self._on_doc_type_loses_focus)
 
-		self._PRW_doc_comment.SetValue(self.__part['doc_comment'])
+		self._PRW_doc_comment.SetText(gmTools.coalesce(self.__part['doc_comment'], ''))
 		self._PRW_doc_comment.set_context(context = 'pk_doc_type', val = self.__part['pk_type'])
 
-		fts = gmFuzzyTimestamp.cFuzzyTimestamp(timestamp = self.__part['date_generated'])
-		self._PhWheel_doc_date.SetValue(fts.strftime('%Y-%m-%d'), fts)
-		if self.__part['ext_ref'] is not None:
-			self._TCTRL_reference.SetValue(self.__part['ext_ref'])
+		fts = gmDateTime.cFuzzyTimestamp(timestamp = self.__part['date_generated'])
+		self._PhWheel_doc_date.SetText(fts.strftime('%Y-%m-%d'), fts)
+		self._TCTRL_reference.SetValue(gmTools.coalesce(self.__part['ext_ref'], ''))
+		if self.__reviewing_doc:
+			self._TCTRL_filename.Enable(False)
+			self._SPINCTRL_seq_idx.Enable(False)
+		else:
+			self._TCTRL_filename.SetValue(gmTools.coalesce(self.__part['filename'], ''))
+			self._SPINCTRL_seq_idx.SetValue(gmTools.coalesce(self.__part['seq_idx'], 0))
 
 		self._LCTRL_existing_reviews.InsertColumn(0, _('who'))
 		self._LCTRL_existing_reviews.InsertColumn(1, _('when'))
@@ -261,6 +274,8 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 					self._ChBOX_relevant.SetValue(bool(rev[3]))
 					break
 
+		self._ChBOX_sign_all_pages.SetValue(self.__reviewing_doc)
+
 		return True
 	#--------------------------------------------------------
 	def __reload_existing_reviews(self):
@@ -306,12 +321,9 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 
 		evt.Skip()
 
-		doc = self.__part.get_containing_document()
-
 		# 1) handle associated episode
 		pk_episode = self._PhWheel_episode.GetData(can_create=True, is_open=True)
 		if pk_episode is None:
-			# FIXME: allow attaching to health issue
 			gmGuiHelpers.gm_show_error (
 				_('Cannot create episode\n [%s]'),
 				_('editing document properties')
@@ -320,19 +332,19 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 
 		doc_type = self._PhWheel_doc_type.GetData(can_create = True)
 		if doc_type is None:
-			gmGuiHelpers.gm_statustext(_('Cannot change document type to [%s].') % self._PhWheel_doc_type.GetValue().strip(), beep=True)
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot change document type to [%s].') % self._PhWheel_doc_type.GetValue().strip())
 			return False
 
 		# since the phrasewheel operates on the active
 		# patient all episodes really should belong
 		# to it so we don't check patient change
-		doc['pk_episode'] = pk_episode
-		doc['pk_type'] = doc_type
-		doc['comment'] = self._PRW_doc_comment.GetValue().strip()
-		doc['date'] = self._PhWheel_doc_date.GetData().get_pydt()
-		doc['ext_ref'] = self._TCTRL_reference.GetValue().strip()
+		self.__doc['pk_episode'] = pk_episode
+		self.__doc['pk_type'] = doc_type
+		self.__doc['comment'] = self._PRW_doc_comment.GetValue().strip()
+		self.__doc['date'] = self._PhWheel_doc_date.GetData().get_pydt()
+		self.__doc['ext_ref'] = self._TCTRL_reference.GetValue().strip()
 
-		success, data = doc.save_payload()
+		success, data = self.__doc.save_payload()
 		if not success:
 			gmGuiHelpers.gm_show_error (
 				_('Cannot link the document to episode\n\n [%s]') % epi_name,
@@ -346,29 +358,32 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 			abnormal = self._ChBOX_abnormal.GetValue()
 			relevant = self._ChBOX_relevant.GetValue()
 			msg = None
-			# - on all pages
-			if self._ChBOX_sign_all_pages.GetValue():
-				if not doc.set_reviewed(technically_abnormal = abnormal, clinically_relevant = relevant):
+			if self.__reviewing_doc:		# - on all pages
+				if not self.__doc.set_reviewed(technically_abnormal = abnormal, clinically_relevant = relevant):
 					msg = _('Error setting "reviewed" status of this document.')
 				if self._ChBOX_responsible.GetValue():
-					if not doc.set_primary_reviewer(reviewer = provider['pk_staff']):
+					if not self.__doc.set_primary_reviewer(reviewer = provider['pk_staff']):
 						msg = _('Error setting responsible clinician for this document.')
-			# - just on this page
-			else:
+			else:								# - just on this page
 				if not self.__part.set_reviewed(technically_abnormal = abnormal, clinically_relevant = relevant):
 					msg = _('Error setting "reviewed" status of this page.')
 				if self._ChBOX_responsible.GetValue():
 					self.__part['pk_intended_reviewer'] = provider['pk_staff']
+			if msg is not None:
+				gmGuiHelpers.gm_show_error(msg, _('editing document properties'))
+				return False
 
-			# FIXME: if msg is not None
-
-		success, data = self.__part.save_payload()
-		if not success:
-			gmGuiHelpers.gm_show_error (
-				_('Error saving document review.'),
-				_('editing document properties')
-			)
-			return False
+		# 3) handle page specific parts
+		if not self.__reviewing_doc:
+			self.__part['filename'] = gmTools.none_if(self._TCTRL_filename.GetValue().strip(), u'')
+			self.__part['seq_idx'] = gmTools.none_if(self._SPINCTRL_seq_idx.GetValue(), 0)
+			success, data = self.__part.save_payload()
+			if not success:
+				gmGuiHelpers.gm_show_error (
+					_('Error saving page properties.'),
+					_('editing document properties')
+				)
+				return False
 
 		return True
 	#--------------------------------------------------------
@@ -377,9 +392,6 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 		self._ChBOX_abnormal.Enable(enable = state)
 		self._ChBOX_relevant.Enable(enable = state)
 		self._ChBOX_responsible.Enable(enable = state)
-		# NOTE: for now *always* apply to all pages so we can
-		# NOTE: offer review from document level as well
-		#self._ChBOX_sign_all_pages.Enable(enable = state)
 	#--------------------------------------------------------
 	def _on_doc_type_loses_focus(self):
 		pk_doc_type = self._PhWheel_doc_type.GetData()
@@ -395,7 +407,7 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 		wxgScanIdxPnl.wxgScanIdxPnl.__init__(self, *args, **kwds)
 		gmPlugin.cPatientChange_PluginMixin.__init__(self)
 
-		self._PhWheel_reviewer.setMatchProvider(mp = gmPerson.cMatchProvider_Provider())
+		self._PhWheel_reviewer.matcher = gmPerson.cMatchProvider_Provider()
 
 		self.__init_ui_data()
 		self._PhWheel_doc_type.add_callback_on_lose_focus(self._on_doc_type_loses_focus)
@@ -414,7 +426,7 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 	def add_filenames(self, filenames):
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.is_connected():
-			gmGuiHelpers.gm_statustext(_('Cannot accept new documents. No active patient.'))
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot accept new documents. No active patient.'))
 			return
 
 		# dive into folders dropped onto us and extract files (one level deep only)
@@ -422,7 +434,7 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 		for pathname in filenames:
 			try:
 				files = os.listdir(pathname)
-				gmGuiHelpers.gm_statustext(_('Extracting files from folder [%s] ...') % pathname)
+				gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Extracting files from folder [%s] ...') % pathname)
 				for file in files:
 					fullname = os.path.join(pathname, file)
 					if not os.path.isfile(fullname):
@@ -450,17 +462,17 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 	#--------------------------------------------------------
 	def __init_ui_data(self):
 		# -----------------------------
-		self._PhWheel_episode.SetValue('')
-		self._PhWheel_doc_type.SetValue('')
+		self._PhWheel_episode.SetText('')
+		self._PhWheel_doc_type.SetText('')
 		# -----------------------------
 		# FIXME: make this configurable: either now() or last_date()
-		fts = gmFuzzyTimestamp.cFuzzyTimestamp()
-		self._PhWheel_doc_date.SetValue(fts.strftime('%Y-%m-%d'), fts)
-		self._PRW_doc_comment.SetValue('')
+		fts = gmDateTime.cFuzzyTimestamp()
+		self._PhWheel_doc_date.SetText(fts.strftime('%Y-%m-%d'), fts)
+		self._PRW_doc_comment.SetText('')
 		# FIXME: should be set to patient's primary doc
 		self._PhWheel_reviewer.selection_only = True
 		me = gmPerson.gmCurrentProvider()
-		self._PhWheel_reviewer.SetValue (
+		self._PhWheel_reviewer.SetText (
 			value = u'%s (%s%s %s)' % (me['short_alias'], me['title'], me['firstnames'], me['lastnames']),
 			data = me['pk_staff']
 		)
@@ -526,11 +538,19 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 
 		return True
 	#--------------------------------------------------------
-	# event handling API
-	#--------------------------------------------------------
-	def _scan_btn_pressed(self, evt):
-		devices = self.scan_module.get_devices()
+	def get_device_to_use(self, reconfigure=False):
 
+		if not reconfigure:
+			dbcfg = gmCfg.cCfgSQL()
+			device = dbcfg.get2 (
+				option =  'external.xsane.default_device',
+				workplace = gmPerson.gmCurrentProvider().workplace,
+				bias = 'workplace'
+			)
+			if device is not None:
+				return device
+
+		devices = self.scan_module.get_devices()
 		if devices is False:
 			gmGuiHelpers.gm_statustext (
 				_('There is no scanner support installed on this machine.'),
@@ -538,53 +558,67 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 			)
 			return None
 
-		# TWAIN doesn't have get_devices() :-(
 		if devices is None:
-			chosen_device = None
-		else:
-			if len(devices) == 0:
-				gmGuiHelpers.gm_statustext (
-					_('Cannot find an active scanner.'),
-					gmLog.lWarn
-				)
-				return None
-			device_names = []
-			for device in devices:
-				device_names.append('%s (%s)' % (device[2], device[0]))
-			# wxpython does not support client data in wxSingleChoiceDialog
-			device_idx = gmGuiHelpers.gm_SingleChoiceDialog (
-				aMessage = _('Select an image capture device'),
-				aTitle = _('device selection'),
-				choices = device_names
+			# get_devices() not implemented for TWAIN yet
+			# XSane has its own chooser (so does TWAIN)
+			return None
+
+		if len(devices) == 0:
+			gmGuiHelpers.gm_statustext (
+				_('Cannot find an active scanner.'),
+				gmLog.lWarn
 			)
-			if device_idx is False:
-				return None
-			chosen_device = devices[device_idx][0]
+			return None
+
+		device_names = []
+		for device in devices:
+			device_names.append('%s (%s)' % (device[2], device[0]))
+		# wxPython does not support client data in wxSingleChoiceDialog
+		device_idx = gmGuiHelpers.gm_SingleChoiceDialog (
+			aMessage = _('Select an image capture device'),
+			aTitle = _('device selection'),
+			choices = device_names
+		)
+		if device_idx is False:
+			return None
+
+		# FIXME: add support for actually reconfiguring
+		return devices[device_idx][0]
+	#--------------------------------------------------------
+	# event handling API
+	#--------------------------------------------------------
+	def _scan_btn_pressed(self, evt):
+
+		chosen_device = self.get_device_to_use()
 
 		tmpdir = os.path.expanduser(os.path.join('~', 'gnumed', 'tmp'))
-		if not os.path.isdir(tmpdir):
-			try:
-				os.makedirs(tmpdir)
-			except:
-				tmpdir = None
+		try:
+			gmTools.mkdir(tmpdir)
+		except:
+			tmpdir = None
+
+		# FIXME: configure whether to use XSane or sane directly
+		# FIXME: add support for xsane_device_settings argument
 		fnames = self.scan_module.acquire_pages_into_files (
 			device = chosen_device,
 			delay = 5,
 			tmpdir = tmpdir,
 			calling_window = self
 		)
+
 		if fnames is False:
 			gmGuiHelpers.gm_show_error (
 				aMessage = _('Page could not be acquired from source.'),
 				aTitle = _('acquiring page')
 			)
 			return None
+
 		if len(fnames) == 0:		# no pages scanned
 			return True
-		# FIXME: configure whether to use XSane or sane directly
+
 		self.acquired_pages.extend(fnames)
-		# update list of pages in GUI
 		self.__reload_LBOX_doc_pages()
+
 		return True
 	#--------------------------------------------------------
 	def _load_btn_pressed(self, evt):
@@ -594,7 +628,7 @@ class cScanIdxDocsPnl(wxgScanIdxPnl.wxgScanIdxPnl, gmPlugin.cPatientChange_Plugi
 			message = _('Choose a file'),
 			defaultDir = os.path.expanduser(os.path.join('~', 'gnumed')),
 			defaultFile = '',
-			wildcard = "all (*.*)|*.*|TIFFs (*.tif)|*.tif|JPEGs (*.jpg)|*.jpg",
+			wildcard = "%s (*)|*|TIFFs (*.tif)|*.tif|JPEGs (*.jpg)|*.jpg|%s (*.*)|*.*" % (_('all files'), _('all files (Win)')),
 			style = wx.OPEN | wx.HIDE_READONLY | wx.FILE_MUST_EXIST | wx.MULTIPLE
 		)
 		result = dlg.ShowModal()
@@ -760,7 +794,7 @@ from your computer.""") % page_fname,
 		show_id = bool (
 			cfg.get2 (
 				option = 'horstspace.scan_index.show_doc_id',
-				workplace = gmPerson.gmCurrentProvider().get_workplace(),
+				workplace = gmPerson.gmCurrentProvider().workplace,
 				bias = 'user'
 			)
 		)
@@ -783,7 +817,7 @@ off this message in the GNUmed configuration.""") % ref
 
 		# prepare for next document
 		self.__init_ui_data()
-		gmGuiHelpers.gm_statustext(_('Successfully saved new document.'))
+		gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Successfully saved new document.'))
 		return True
 	#--------------------------------------------------------
 	def _startover_btn_pressed(self, evt):
@@ -903,12 +937,6 @@ class cDocTree(wx.TreeCtrl):
 		wx.EVT_TREE_ITEM_ACTIVATED (self, self.GetId(), self._on_activate)
 		wx.EVT_TREE_ITEM_RIGHT_CLICK (self, self.GetId(), self.__on_right_click)
 
-#		 wx.EVT_TREE_ITEM_EXPANDED	 (self, tID, self.OnItemExpanded)
-#		 wx.EVT_TREE_ITEM_COLLAPSED (self, tID, self.OnItemCollapsed)
-#		 wx.EVT_TREE_SEL_CHANGED	 (self, tID, self.OnSelChanged)
-#		 wx.EVT_TREE_BEGIN_LABEL_EDIT(self, tID, self.OnBeginEdit)
-#		 wx.EVT_TREE_END_LABEL_EDIT (self, tID, self.OnEndEdit)
-
 #		 wx.EVT_LEFT_DCLICK(self.tree, self.OnLeftDClick)
 	#--------------------------------------------------------
 	def __populate_tree(self):
@@ -927,7 +955,7 @@ class cDocTree(wx.TreeCtrl):
 		docs_folder = self.__pat.get_document_folder()
 		docs = docs_folder.get_documents()
 		if docs is None:
-			name = self.__pat.get_identity().get_names()
+			name = self.__pat.get_names()
 			gmGuiHelpers.gm_show_error (
 				aMessage = _('Error searching documents for patient\n[%s %s].') % (name['first'], name['last']),
 				aTitle = _('loading document list')
@@ -998,10 +1026,7 @@ class cDocTree(wx.TreeCtrl):
 
 				pg = _('page %2s') % part['seq_idx']
 
-				if part['obj_comment'] is None:
-					cmt = _("no comment available")
-				else:
-					cmt = part['obj_comment']
+				cmt = gmTools.coalesce(part['obj_comment'], _("no comment available"))
 
 				if part['size'] == 0:
 					sz = _('0 bytes - data missing ?')
@@ -1163,6 +1188,18 @@ class cDocTree(wx.TreeCtrl):
 		del self.__curr_node_data
 		evt.Skip()
 	#--------------------------------------------------------
+	def __activate_as_current_photo(self, evt):
+		self.__curr_node_data.set_as_active_photograph()
+	#--------------------------------------------------------
+	def __display_curr_part(self, evt):
+		self.__display_part(part=self.__curr_node_data)
+	#--------------------------------------------------------
+	def __review_curr_part(self, evt):
+		self.__review_part(part=self.__curr_node_data)
+	#--------------------------------------------------------
+	def __show_description(self, evt):
+		print "showing description"
+	#--------------------------------------------------------
 	# internal API
 	#--------------------------------------------------------
 	def __handle_doc_context(self):
@@ -1179,8 +1216,6 @@ class cDocTree(wx.TreeCtrl):
 		menu.AppendItem(wx.MenuItem(menu, ID, _('Export to disk')))
 		wx.EVT_MENU(menu, ID, self.__export_doc_to_disk)
 
-		# FIXME: add item "reorder pages"
-
 		# show descriptions
 		descriptions = self.__curr_node_data.get_descriptions()
 		desc_menu = wx.Menu()
@@ -1212,13 +1247,15 @@ class cDocTree(wx.TreeCtrl):
 		ID = wx.NewId()
 		menu.AppendItem(wx.MenuItem(menu, ID, _('Review/Edit properties')))
 		wx.EVT_MENU(menu, ID, self.__review_curr_part)
+		# make active patient photograph
+		if self.__curr_node_data['type'] == 'patient photograph':
+			ID = wx.NewId()
+			menu.AppendItem(wx.MenuItem(menu, ID, _('Activate as current photo')))
+			wx.EVT_MENU(menu, ID, self.__activate_as_current_photo)
 		# show menu
 		self.PopupMenu(menu, wx.DefaultPosition)
 		menu.Destroy()
 	#--------------------------------------------------------
-	def __display_curr_part(self, evt):
-		self.__display_part(part=self.__curr_node_data)
-	#--------------------------------------------------------
 	def __display_part(self, part):
 		"""Display document part."""
 
@@ -1241,7 +1278,7 @@ class cDocTree(wx.TreeCtrl):
 		cfg = gmCfg.cCfgSQL()
 		tmp_dir = cfg.get2 (
 			option = "horstspace.tmp_dir",
-			workplace = gmPerson.gmCurrentProvider().get_workplace(),
+			workplace = gmPerson.gmCurrentProvider().workplace,
 			bias = 'workplace',
 			default = def_tmp_dir
 		)
@@ -1255,7 +1292,7 @@ class cDocTree(wx.TreeCtrl):
 		# determine database export chunk size
 		chunksize = int(cfg.get2 (
 			option = "horstspace.blob_export_chunk_size",
-			workplace = gmPerson.gmCurrentProvider().get_workplace(),
+			workplace = gmPerson.gmCurrentProvider().workplace,
 			bias = 'workplace',
 			default = 1 * 1024 * 1024		# 1 MB
 		))
@@ -1273,7 +1310,7 @@ class cDocTree(wx.TreeCtrl):
 		# display it
 		block_during_view = bool( cfg.get2 (
 			option = 'horstspace.document_viewer.block_during_view',
-			workplace = gmPerson.gmCurrentProvider().get_workplace(),
+			workplace = gmPerson.gmCurrentProvider().workplace,
 			bias = 'user',
 			default = None
 		))
@@ -1288,7 +1325,7 @@ class cDocTree(wx.TreeCtrl):
 		# handle review after display
 		review_after_display = cfg.get2 (
 			option = 'horstspace.document_viewer.review_after_display',
-			workplace = gmPerson.gmCurrentProvider().get_workplace(),
+			workplace = gmPerson.gmCurrentProvider().workplace,
 			bias = 'user',
 			default = 2
 		)
@@ -1303,13 +1340,6 @@ class cDocTree(wx.TreeCtrl):
 
 		return 1
 	#--------------------------------------------------------
-	def __review_curr_part(self, evt):
-		if isinstance(self.__curr_node_data, gmMedDoc.cMedDocPart):
-			self.__review_part(part=self.__curr_node_data)
-		else:
-			parts = self.__curr_node_data.get_parts()
-			self.__review_part(part=parts[0])
-	#--------------------------------------------------------
 	def __review_part(self, part=None):
 		dlg = cReviewDocPartDlg (
 			parent = self,
@@ -1319,9 +1349,6 @@ class cDocTree(wx.TreeCtrl):
 		if dlg.ShowModal() == wx.ID_OK:
 			self.__populate_tree()
 	#--------------------------------------------------------
-	def __show_description(self, evt):
-		print "showing description"
-	#--------------------------------------------------------
 	# document level context menu handlers
 	#--------------------------------------------------------
 	def __export_doc_to_disk(self, evt):
@@ -1331,13 +1358,13 @@ class cDocTree(wx.TreeCtrl):
 		- into subdirectory named after patient
 		"""
 		pat = gmPerson.gmCurrentPatient()
-		ident = pat.get_identity()
-		# FIXME: make configurable
-		dname = '%s_%s-%s' % (ident['lastnames'], ident['firstnames'], ident['dob'].strftime('%Y-%m-%d'))
-		# FIXME: make configurable
-		def_dir = os.path.abspath(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'docs', dname)))
-		if not os.access(def_dir, os.F_OK):
-			os.makedirs(def_dir)
+		dname = '%s-%s%s' % (
+			self.__curr_node_data['l10n_type'],
+			self.__curr_node_data['date'].strftime('%Y-%m-%d'),
+			gmTools.coalesce(self.__curr_node_data['ext_ref'], '', '-%s').replace(' ', '_')
+		)
+		def_dir = os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'docs', pat['dirname'], dname))
+		gmTools.mkdir(def_dir)
 		
 		dlg = wx.DirDialog (
 			parent = self,
@@ -1345,17 +1372,18 @@ class cDocTree(wx.TreeCtrl):
 			defaultPath = def_dir,
 			style = wx.DD_DEFAULT_STYLE
 		)
-		if dlg.ShowModal() != wx.ID_OK:
-			dlg.Destroy()
-			return True
+		result = dlg.ShowModal()
 		dirname = dlg.GetPath()
 		dlg.Destroy()
 
+		if result != wx.ID_OK:
+			return True
+
 		wx.BeginBusyCursor()
 		fnames = self.__curr_node_data.export_parts_to_files(export_dir=dirname)
 		wx.EndBusyCursor()
 
-		gmGuiHelpers.gm_statustext(_('Successfully exported %s pages into the directory [%s].') % (len(fnames), dirname), beep=False)
+		gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Successfully exported %s pages into the directory [%s].') % (len(fnames), dirname))
 
 		return True
 #============================================================
@@ -1369,6 +1397,59 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmMedDocWidgets.py,v $
+# Revision 1.127  2007/05/21 14:49:20  ncq
+# - use pat['dirname'] for export
+#
+# Revision 1.126  2007/05/21 13:05:25  ncq
+# - catch-all wildcard on UNIX must be *, not *.*
+#
+# Revision 1.125  2007/05/20 01:28:09  ncq
+# - only repopulate if we actually saved a new doc type
+#
+# Revision 1.124  2007/05/18 22:02:30  ncq
+# - create export/docs/<patient>/<doc>/ *subdir* for document export
+#
+# Revision 1.123  2007/05/14 13:11:24  ncq
+# - use statustext() signal
+#
+# Revision 1.122  2007/04/23 16:59:35  ncq
+# - make cReviewDocPartDlg accept documents as well as document
+#   parts and dynamically adjust UI appropriately
+#
+# Revision 1.121  2007/04/23 01:08:04  ncq
+# - add "activate as current photo" to popup menu
+#
+# Revision 1.120  2007/04/21 19:40:06  ncq
+# - handle seq_idx spin ctrl in review doc (part)
+#
+# Revision 1.119  2007/04/02 18:39:52  ncq
+# - gmFuzzyTimestamp -> gmDateTime
+#
+# Revision 1.118  2007/03/31 21:51:05  ncq
+# - add xsane default device option
+#
+# Revision 1.117  2007/03/08 16:21:11  ncq
+# - support blobs.doc_obj.filename
+#
+# Revision 1.116  2007/02/22 17:41:13  ncq
+# - adjust to gmPerson changes
+#
+# Revision 1.115  2007/02/17 18:28:33  ncq
+# - factor out get_device_to_use() and use it in _scan_btn_pressed()
+# - support pre-setting device, only directly supported by XSane so far
+#
+# Revision 1.114  2007/02/17 14:13:11  ncq
+# - gmPerson.gmCurrentProvider().workplace now property
+#
+# Revision 1.113  2007/02/06 13:43:40  ncq
+# - no more aDelay in __init__()
+#
+# Revision 1.112  2007/02/05 12:15:23  ncq
+# - no more aMatchProvider/selection_only in cPhraseWheel.__init__()
+#
+# Revision 1.111  2007/02/04 15:55:14  ncq
+# - use SetText()
+#
 # Revision 1.110  2007/01/18 22:13:37  ncq
 # - tell user when we expand a folder to extract files
 #
