@@ -1,5 +1,5 @@
 #  coding: latin-1
-"""GnuMed quick patient search widget.
+"""GNUmed quick patient search widget.
 
 This widget allows to search for patients based on the
 critera name, date of birth and patient ID. It goes to
@@ -10,19 +10,19 @@ generator.
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPatSearchWidgets.py,v $
-# $Id: gmPatSearchWidgets.py,v 1.59 2007/01/20 22:52:27 ncq Exp $
-__version__ = "$Revision: 1.59 $"
+# $Id: gmPatSearchWidgets.py,v 1.80.2.1 2007/06/01 15:15:47 ncq Exp $
+__version__ = "$Revision: 1.80.2.1 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = 'GPL (for details see http://www.gnu.org/)'
 
-import sys, os.path, time, string, re, glob
+import sys, os.path, time, glob, locale, datetime as pyDT, webbrowser, fileinput
 
 import wx
 
-from Gnumed.pycommon import gmLog, gmDispatcher, gmSignals, gmPG2, gmI18N, gmCfg, gmTools
-from Gnumed.business import gmPerson, gmKVK
+from Gnumed.pycommon import gmLog, gmDispatcher, gmSignals, gmPG2, gmI18N, gmCfg, gmTools, gmDateTime, gmMatchProvider, gmMimeLib
+from Gnumed.business import gmPerson, gmKVK, gmDataMining
 from Gnumed.wxpython import gmGuiHelpers, gmDemographicsWidgets
-from Gnumed.wxGladeWidgets import wxgSelectPersonFromListDlg, wxgSelectPersonDTOFromListDlg
+from Gnumed.wxGladeWidgets import wxgSelectPersonFromListDlg, wxgSelectPersonDTOFromListDlg, wxgDataMiningPnl
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
@@ -32,6 +32,184 @@ _cfg = gmCfg.gmDefCfgFile
 ID_PatPickList = wx.NewId()
 ID_BTN_AddNew = wx.NewId()
 
+#============================================================
+# FIXME: this class is perhaps a bit oddly placed here
+class cDataMiningPnl(wxgDataMiningPnl.wxgDataMiningPnl):
+
+	def __init__(self, *args, **kwargs):
+		wxgDataMiningPnl.wxgDataMiningPnl.__init__(self, *args, **kwargs)
+
+		self.__init_ui()
+
+		# make me a file drop target
+		dt = gmGuiHelpers.cFileDropTarget(self)
+		self.SetDropTarget(dt)
+	#--------------------------------------------------------
+	def __init_ui(self):
+		mp = gmMatchProvider.cMatchProvider_SQL2 (
+			queries = [u'select distinct on (label) cmd, label from cfg.report_query where label %(fragment_condition)s or cmd %(fragment_condition)s']
+		)
+		mp.setThresholds(2,3,5)
+		self._PRW_report_name.matcher = mp
+		self._PRW_report_name.add_callback_on_selection(callback = self._on_report_selected)
+	#--------------------------------------------------------
+	def _on_report_selected(self, *args, **kwargs):
+		self._TCTRL_query.SetValue(self._PRW_report_name.GetData())
+		self._BTN_run.SetFocus()
+	#--------------------------------------------------------
+	# file drop target API
+	#--------------------------------------------------------
+	def add_filenames(self, filenames):
+		# act on first file only
+		fname = filenames[0]
+		# act on text files only
+		mime_type = gmMimeLib.guess_mimetye(fname)
+		if not mime_type.startswith('text/'):
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Cannot read SQL from [%s]. Not a text file.') % fname, beep = True)
+			return False
+		# act on "small" files only
+		stat_val = os.stat(fname)
+		if stat_val.st_size > 2000:
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Cannot read SQL from [%s]. File too big (> 2000 bytes).') % fname, beep = True)
+			return False
+		# all checks passed
+		for line in fileinput.input(fname):
+			self._TCTRL_query.AppendText(line)
+	#--------------------------------------------------------
+	# notebook plugin API
+	#--------------------------------------------------------
+	def repopulate_ui(self):
+		pass
+	#--------------------------------------------------------
+	# event handlers
+	#--------------------------------------------------------
+	def _on_list_item_activated(self, evt):
+		data = self._LCTRL_result.get_selected_item_data()
+		try:
+			pk_pat = data['pk_patient']
+		except KeyError:
+			gmGuiHelpers.gm_show_warning (
+				_(
+				'Cannot activate patient.\n\n'
+				'The report result list does not contain\n'
+				'a column named "pk_patient".\n\n'
+				'You may want to use the SQL "AS" column alias\n'
+				'syntax to make your query return such a column.\n'
+				),
+				_('activating patient from report result')
+			)
+			return
+		pat = gmPerson.cPatient(aPK_obj = pk_pat)
+		gmPerson.set_active_patient(patient = pat)
+	#--------------------------------------------------------
+	def _on_contribute_button_pressed(self, evt):
+		report = self._PRW_report_name.GetValue().strip()
+		if report == u'':
+			return
+		query = self._TCTRL_query.GetValue().strip()
+		if query == u'':
+			return
+
+		auth = {'user': gmTools.default_mail_sender, 'password': u'gm/bugs/gmx'}
+		msg = u"""
+To: gnumed-devel@gnu.org
+From: GNUmed Report Generator <gnumed@gmx.net>
+Subject: user contributed report
+
+This is a report definition contributed
+by a GNUmed user:
+
+#--------------------------------------
+
+%s
+
+%s
+
+#--------------------------------------
+
+The GNUmed client.
+""" % (report, query)
+
+		if not gmTools.send_mail(message = msg, auth = auth):
+			gmDispatcher.send(signal = gmSignals.statustext(), msg = _('Unable to send mail. Cannot contribute report [%s] to GNUmed community.') % report, beep = True)
+			return False
+
+		gmDispatcher.send(signal = gmSignals.statustext(), msg = _('Thank you for your contribution to the GNUmed community !'), beep = False)
+		return True
+	#--------------------------------------------------------
+	def _on_schema_button_pressed(self, evt):
+		webbrowser.open(u'http://wiki.gnumed.de/bin/view/Gnumed/DatabaseSchema', new=0, autoraise=1)
+	#--------------------------------------------------------
+	def _on_delete_button_pressed(self, evt):
+		report = self._PRW_report_name.GetValue().strip()
+		if report == u'':
+			return True
+		if gmDataMining.delete_report_definition(name=report):
+			self._PRW_report_name.SetText()
+			self._TCTRL_query.SetValue(u'')
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Deleted report definition [%s].') % report, beep=False)
+			return True
+		gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Error deleting report definition [%s].') % report, beep=True)
+		return False
+	#--------------------------------------------------------
+	def _on_clear_button_pressed(self, evt):
+		self._PRW_report_name.SetText()
+		self._TCTRL_query.SetValue(u'')
+	#--------------------------------------------------------
+	def _on_save_button_pressed(self, evt):
+		report = self._PRW_report_name.GetValue().strip()
+		if report == u'':
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Cannot save report definition without name.'), beep=True)
+			return False
+		query = self._TCTRL_query.GetValue().strip()
+		if query == u'':
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Cannot save report definition without query.'), beep=True)
+			return False
+		# FIXME: check for exists and ask for permission
+		if gmDataMining.save_report_definition(name=report, query=query, overwrite=True):
+			gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Saved report definition [%s].') % report, beep=False)
+			return True
+		gmDispatcher.send(signal=gmSignals.statustext(), msg = _('Error saving report definition [%s].') % report, beep=True)
+		return False
+	#--------------------------------------------------------
+	def _on_run_button_pressed(self, evt):
+		query = self._TCTRL_query.GetValue().strip().strip(';')
+		if query == u'':
+			return True
+
+		self._LCTRL_result.set_columns()
+
+		# FIXME: make configurable
+		query = u'select * from (' + query + u') as real_query limit 1024'
+		try:
+			# read-only only for safety reasons
+			rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': query}], get_col_idx = True)
+		except:
+			self._LCTRL_result.set_columns([_('Error')])
+			self._LCTRL_result.InsertStringItem(sys.maxint, label = _('The query failed.'))
+			gmDispatcher.send(gmSignals.statustext(), msg = _('The query failed.'), beep = True)
+			_log.LogException('report query failed')
+			return False
+
+		if len(rows) == 0:
+			self._LCTRL_result.set_columns([_('Results')])
+			self._LCTRL_result.InsertStringItem(sys.maxint, label = _('Report returned no data.'))
+			gmDispatcher.send(gmSignals.statustext(), msg = _('No data returned for this report.'), beep = True)
+			return True
+
+		cols = [(value, key) for key, value in idx.items()]
+		cols.sort()
+		cols = [pair[1] for pair in cols]
+
+		self._LCTRL_result.set_columns(cols)
+		for row in rows:
+			label = unicode(gmTools.coalesce(row[0], u''))
+			row_num = self._LCTRL_result.InsertStringItem(sys.maxint, label = label)
+			for col_idx in range(1, len(row)):
+				self._LCTRL_result.SetStringItem(index = row_num, col = col_idx, label = unicode(gmTools.coalesce(row[col_idx], u'')))
+
+		self._LCTRL_result.set_column_widths()
+		self._LCTRL_result.set_data(data = rows)
 #============================================================
 class cSelectPersonFromListDlg(wxgSelectPersonFromListDlg.wxgSelectPersonFromListDlg):
 
@@ -62,20 +240,17 @@ class cSelectPersonFromListDlg(wxgSelectPersonFromListDlg.wxgSelectPersonFromLis
 			return False
 
 		for person in persons:
-			ident = person.get_identity()
-
-			row_num = self._LCTRL_persons.InsertStringItem(pos, label = gmTools.coalesce(ident['title'], ''))
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 1, label = ident['lastnames'])
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 2, label = ident['firstnames'])
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 3, label = gmTools.coalesce(ident['preferred'], ''))
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 4, label = ident['dob'].strftime('%x'))
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 5, label = gmTools.coalesce(ident['l10n_gender'], '?'))
-			pat = gmPerson.cPatient(identity=ident)
-			enc = pat.get_last_encounter()
+			row_num = self._LCTRL_persons.InsertStringItem(pos, label = gmTools.coalesce(person['title'], ''))
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 1, label = person['lastnames'])
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 2, label = person['firstnames'])
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 3, label = gmTools.coalesce(person['preferred'], ''))
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 4, label = person['dob'].strftime('%x').decode(gmI18N.get_encoding()))
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 5, label = gmTools.coalesce(person['l10n_gender'], '?'))
+			enc = person.get_last_encounter()
 			if enc is None:
 				label = u''
 			else:
-				label = u'%s (%s)' % (enc['started'].strftime('%x'), enc['l10n_type'])
+				label = u'%s (%s)' % (enc['started'].strftime('%x').decode(gmI18N.get_encoding()), enc['l10n_type'])
 			self._LCTRL_persons.SetStringItem(index = row_num, col = 6, label = label)
 			try: self._LCTRL_persons.SetStringItem(index = row_num, col = 7, label = ident['match_type'])
 			except: pass
@@ -85,6 +260,7 @@ class cSelectPersonFromListDlg(wxgSelectPersonFromListDlg.wxgSelectPersonFromLis
 
 		self._BTN_select.Enable(False)
 		self._LCTRL_persons.SetFocus()
+		self._LCTRL_persons.Select(0)
 
 		self._LCTRL_persons.set_data(data=persons)
 	#--------------------------------------------------------
@@ -134,7 +310,7 @@ class cSelectPersonDTOFromListDlg(wxgSelectPersonDTOFromListDlg.wxgSelectPersonD
 			dto = rec['dto']
 			self._LCTRL_persons.SetStringItem(index = row_num, col = 1, label = dto.lastnames)
 			self._LCTRL_persons.SetStringItem(index = row_num, col = 2, label = dto.firstnames)
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 3, label = dto.dob.strftime('%x'))
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 3, label = dto.dob.strftime('%x').decode(gmI18N.get_encoding()))
 			self._LCTRL_persons.SetStringItem(index = row_num, col = 4, label = gmTools.coalesce(dto.gender, ''))
 
 		for col in range(len(self.__cols)):
@@ -142,6 +318,7 @@ class cSelectPersonDTOFromListDlg(wxgSelectPersonDTOFromListDlg.wxgSelectPersonD
 
 		self._BTN_select.Enable(False)
 		self._LCTRL_persons.SetFocus()
+		self._LCTRL_persons.Select(0)
 
 		self._LCTRL_persons.set_data(data=dtos)
 	#--------------------------------------------------------
@@ -249,39 +426,96 @@ def load_persons_from_xdt():
 
 	return dtos
 #============================================================
+def load_persons_from_pracsoft_au():
+
+	pracsoft_files = []
+
+	# try detecting PATIENTS.IN files
+	candidates = []
+	drives = 'cdefghijklmnopqrstuvwxyz'
+	for drive in drives:
+		candidate = drive + ':\MDW2\PATIENTS.IN'
+		candidates.extend(glob.glob(candidate))
+	for candidate in candidates:
+		drive, filename = os.path.splitdrive(candidate)
+		pracsoft_files.append({'file': candidate, 'source': 'PracSoft (AU): drive %s' % drive})
+
+	# add configured one
+	fname = _cfg.get('AU PracSoft PATIENTS.IN', 'filename')
+	source = _cfg.get('AU PracSoft PATIENTS.IN', 'source')
+	if fname is not None and source is not None:
+		pracsoft_files.append({'file': os.path.expanduser(fname), 'source': source})
+
+	# and parse them
+	dtos = []
+	for pracsoft_file in pracsoft_files:
+		try:
+			tmp = gmPerson.get_persons_from_pracsoft_file(filename = pracsoft_file['file'])
+		except:
+			_log.LogException('cannot parse PracSoft file [%s]' % pracsoft_file['file'])
+			continue
+		for dto in tmp:
+			dtos.append({'dto': dto, 'source': pracsoft_file['source']})
+
+	return dtos
+#============================================================
+def load_persons_from_kvks():
+
+	db_cfg = gmCfg.cCfgSQL()
+	kvk_dir = os.path.abspath(os.path.expanduser(db_cfg.get2 (
+		option = 'DE.KVK.spool_dir',
+		workplace = gmPerson.gmCurrentProvider().workplace,
+		bias = 'workplace',
+		default = u'/var/spool/kvkd/'
+	)))
+	dtos = []
+	for dto in gmKVK.get_available_kvks_as_dtos(spool_dir = kvk_dir):
+		dtos.append({'dto': dto, 'source': 'KVK'})
+
+	return dtos
+#============================================================
 def load_patient_from_external_sources(parent=None):
 
+	# get DTOs from interfaces
 	dtos = []
-
-	# xDT
 	dtos.extend(load_persons_from_xdt())
-
-	# more types: KVK files, other interfaces, ...
+	dtos.extend(load_persons_from_pracsoft_au())
+	dtos.extend(load_persons_from_kvks())
 
 	if len(dtos) == 0:
-		gmGuiHelpers.gm_statustext(_('No patients found in external sources.'))
+		gmDispatcher.send(signal=gmSignals.statustext(), msg=_('No patients found in external sources.'))
 		return True
-	if len(dtos) == 1:
-		gmGuiHelpers.gm_statustext(_('Only one patient found in external sources. Using that patient.'))
-		dto = dtos[0]['dto']
-	if len(dtos) > 1:
-		if parent is None:
-			parent = wx.GetApp().GetTopWindow()
-		dlg = cSelectPersonDTOFromListDlg(parent=parent, id=-1)
-		dlg.set_dtos(dtos=dtos)
-		result = dlg.ShowModal()
-		if result == wx.ID_CANCEL:
-			return True
-		dto = dlg.get_selected_dto()['dto']
-		dlg.Destroy()
+	elif len(dtos) == 1:
+		curr_pat = gmPerson.gmCurrentPatient()
+		if curr_pat.is_connected():
+			dto = dtos[0]
+			key_dto = dto.firstnames + dto.lastnames + dto.dob.strftime('%Y-%m-%d') + dto.gender
+			names = curr_pat.get_active_name()
+			key_pat = names['first'] + names['last'] + curr_pat['dob'].strftime('%Y-%m-%d') + curr_pat['gender']
+			_log.Log(gmLog.lData, 'current patient: %s' % key_pat)
+			_log.Log(gmLog.lData, 'dto patient    : %s' % key_dto)
+			if key_dto == key_pat:
+				gmDispatcher.send(signal=gmSignals.statustext(), msg=_('The only external patient is already active in GNUmed.'), beep=False)
+				return True
+
+	if parent is None:
+		parent = wx.GetApp().GetTopWindow()
+	dlg = cSelectPersonDTOFromListDlg(parent=parent, id=-1)
+	dlg.set_dtos(dtos=dtos)
+	result = dlg.ShowModal()
+	if result == wx.ID_CANCEL:
+		return True
+	dto = dlg.get_selected_dto()['dto']
+	dlg.Destroy()
 
 	# FIXME: config: delete DTO source after selection, eg KVK
 
 	# search
 	searcher = gmPerson.cPatientSearcher_SQL()
-	persons = searcher.get_persons (dto = dto)
+	idents = searcher.get_identities(dto = dto)
 
-	if len(persons) == 0:
+	ident = None
+	if len(idents) == 0:
 		ident = gmPerson.create_identity (
 			firstnames = dto.firstnames,
 			lastnames = dto.lastnames,
@@ -293,16 +527,15 @@ def load_patient_from_external_sources(parent=None):
 				_(
 				'Cannot create new patient:\n\n'
 				' [%s %s (%s), %s]'
-				) % (dto.firstnames, dto.lastnames, dto.gender, dto.dob.strftime('%x')),
+				) % (dto.firstnames, dto.lastnames, dto.gender, dto.dob.strftime('%x').decode(gmI18N.get_encoding())),
 				_('Activating xDT patient')
 			)
 			return False
-		person = gmPerson.cPerson(identity=ident)
 
-	if len(persons) == 1:
-		person = persons[0]
+	if len(idents) == 1:
+		ident = idents[0]
 
-	if len(persons) > 1:
+	if len(idents) > 1:
 		if parent is None:
 			parent = wx.GetApp().GetTopWindow()
 		dlg = cSelectPersonFromListDlg(parent=parent, id=-1)
@@ -310,16 +543,16 @@ def load_patient_from_external_sources(parent=None):
 		result = dlg.ShowModal()
 		if result == wx.ID_CANCEL:
 			return True
-		person = dlg.get_selected_person()
+		ident = dlg.get_selected_person()
 		dlg.Destroy()
 
-	if not gmPerson.set_active_patient(patient = person.get_identity()):
+	if not gmPerson.set_active_patient(patient = ident):
 		gmGuiHelpers.gm_show_info (
 			_(
 			'Cannot activate patient:\n\n'
 			'%s %s (%s)\n'
 			'%s'
-			) % (dto.firstnames, dto.lastnames, dto.gender, dto.dob.strftime('%x')),
+			) % (dto.firstnames, dto.lastnames, dto.gender, dto.dob.strftime('%x').decode(gmI18N.get_encoding())),
 			_('Activating xDT patient')
 		)
 		return False
@@ -368,8 +601,6 @@ class cPatientSelector(wx.TextCtrl):
 
 		self.__prev_search_term = None
 		self.__prev_idents = []
-		self.__pat_picklist_col_defs = []
-
 		self._lclick_count = 0
 
 		# get configuration
@@ -378,7 +609,7 @@ class cPatientSelector(wx.TextCtrl):
 		self.__always_dismiss_after_search = bool ( 
 			cfg.get2 (
 				option = 'patient_search.always_dismiss_previous_patient',
-				workplace = gmPerson.gmCurrentProvider().get_workplace(),
+				workplace = gmPerson.gmCurrentProvider().workplace,
 				bias = 'user',
 				default = 0
 			)
@@ -387,7 +618,7 @@ class cPatientSelector(wx.TextCtrl):
 		self.__always_reload_after_search = bool (
 			cfg.get2 (
 				option = 'patient_search.always_reload_new_patient',
-				workplace = gmPerson.gmCurrentProvider().get_workplace(),
+				workplace = gmPerson.gmCurrentProvider().workplace,
 				bias = 'user',
 				default = 0
 			)
@@ -400,7 +631,30 @@ class cPatientSelector(wx.TextCtrl):
 			_log.Log (gmLog.lErr, 'cannot change active patient')
 			return None
 
-		self.__remember_ident(self.curr_pat.get_identity())
+		self.__remember_ident(pat)
+
+		dbcfg = gmCfg.cCfgSQL()
+		dob_distance = dbcfg.get2 (
+			option = u'patient_search.dob_warn_interval',
+			workplace = gmPerson.gmCurrentProvider().workplace,
+			bias = u'user',
+			default = u'1 week'
+		)
+
+		if pat.dob_in_range(dob_distance, dob_distance):
+			now = pyDT.datetime.now(tz = gmDateTime.gmCurrentLocalTimezone)
+			enc = gmI18N.get_encoding()
+			gmGuiHelpers.gm_statustext (
+				_('%(pat)s was born on %(dow)s, %(month)s %(day)s ! (today is %(dow_now)s, %(month_now)s %(day_now)s)') % {
+					'pat': pat.get_description(),
+					'dow': pat['dob'].strftime('%A').decode(enc),
+					'month': pat['dob'].strftime('%B').decode(enc),
+					'day': pat['dob'].strftime('%d'),
+					'dow_now': now.strftime('%A').decode(enc),
+					'month_now': now.strftime('%B').decode(enc),
+					'day_now': now.strftime('%d')
+				}
+			)
 
 		return True
 	#--------------------------------------------------------
@@ -408,10 +662,9 @@ class cPatientSelector(wx.TextCtrl):
 	#--------------------------------------------------------
 	def _display_name(self):
 		if self.curr_pat.is_connected():
-			ident = self.curr_pat.get_identity()
-			self.SetValue(ident['description'])
+			self.SetValue(self.curr_pat['description'])
 		else:
-			self.SetValue('')
+			self.SetValue(u'')
 	#--------------------------------------------------------
 	def __remember_ident(self, ident=None):
 
@@ -513,12 +766,9 @@ class cPatientSelector(wx.TextCtrl):
 			evt.Skip()
 			if len(self.__prev_idents) == 0:
 				return True
-			persons = []
-			for ident in self.__prev_idents:
-				persons.append(gmPerson.cPerson(identity=ident))
 
 			dlg = cSelectPersonFromListDlg(parent=wx.GetTopLevelParent(self), id=-1)
-			dlg.set_persons(persons=persons)
+			dlg.set_persons(persons=self.__prev_idents)
 			result = dlg.ShowModal()
 			if result == wx.ID_OK:
 				wx.BeginBusyCursor()
@@ -546,29 +796,6 @@ class cPatientSelector(wx.TextCtrl):
 		# FIXME: invoke add new patient
 		# FIXME: add popup menu apart from system one
 
-		if evt.AltDown():
-
-			# ALT-K - access chipcards
-#			if keycode in [ord('k'), ord('c')]:
-				# FIXME: make configurable !!
-#				kvks = gmKVK.get_available_kvks('~/gnumed/kvk/incoming/')
-#				if kvks is None:
-#					print "No KVKs available !"
-					# show some message here ...
-#					return True
-#				picklist, col_order = gmKVK.kvks_extract_picklist(kvks)
-				# show list
-#				dlg = cPatientPickList(parent = self, title = _("please select a KVK"))
-#				dlg.SetItems(picklist, col_order)
-#				result = dlg.ShowModal()
-#				item = dlg.selected_item
-#				dlg.Destroy()
-				# and process selection
-#				if result > 0:
-#					print "user selected kvkd file %s" % picklist[result][10]
-#					print picklist[result]
-				return True
-		
 		evt.Skip()
 	#--------------------------------------------------------
 	def _on_enter(self, evt):
@@ -578,8 +805,7 @@ class cPatientSelector(wx.TextCtrl):
 			return None
 
 		if self.curr_pat.is_connected():
-			ident = self.curr_pat.get_identity()
-			if curr_search_term == ident['description']:
+			if curr_search_term == self.curr_pat['description']:
 				return None
 
 		wx.BeginBusyCursor()
@@ -594,10 +820,10 @@ class cPatientSelector(wx.TextCtrl):
 
 		# get list of matching ids
 		start = time.time()
-		persons = self.__pat_searcher.get_persons(curr_search_term)
+		idents = self.__pat_searcher.get_identities(curr_search_term)
 		duration = time.time() - start
 
-		if persons is None:
+		if idents is None:
 			wx.EndBusyCursor()
 			gmGuiHelpers.gm_show_info (
 				_('Error searching for matching patients.\n\n'
@@ -607,9 +833,9 @@ class cPatientSelector(wx.TextCtrl):
 			)
 			return None
 
-		_log.Log (gmLog.lInfo, "%s person objects(s) fetched in %3.3f seconds" % (len(persons), duration))
+		_log.Log (gmLog.lInfo, "%s person objects(s) fetched in %3.3f seconds" % (len(idents), duration))
 
-		if len(persons) == 0:
+		if len(idents) == 0:
 			wx.EndBusyCursor()
 			gmGuiHelpers.gm_show_info (
 				_('Cannot find any matching patients.\n'
@@ -624,14 +850,15 @@ class cPatientSelector(wx.TextCtrl):
 			return None
 
 		# only one matching identity
-		if len(persons) == 1:
-			self.SetActivePatient(persons[0])
+		if len(idents) == 1:
+			self.SetActivePatient(idents[0])
+			self._display_name()		# needed when the found patient is the same as the active one
 			wx.EndBusyCursor()
 			return None
 
 		# more than one matching identity: let user select from pick list
 		dlg = cSelectPersonFromListDlg(parent=wx.GetTopLevelParent(self), id=-1)
-		dlg.set_persons(persons=persons)
+		dlg.set_persons(persons=idents)
 		wx.EndBusyCursor()
 		result = dlg.ShowModal()
 		if result == wx.ID_CANCEL:
@@ -639,9 +866,10 @@ class cPatientSelector(wx.TextCtrl):
 			return None
 
 		wx.BeginBusyCursor()
-		person = dlg.get_selected_person()
+		ident = dlg.get_selected_person()
 		dlg.Destroy()
-		self.SetActivePatient(person)
+		self.SetActivePatient(ident)
+		self._display_name()		# needed when the found patient is the same as the active one
 		wx.EndBusyCursor()
 
 		return None
@@ -689,13 +917,6 @@ if __name__ == "__main__":
 #   - ESC cancels selection
 #   - number selects patient
 #
-# - hitting cursor-up (alt-K = KVK, alt-C = Chipkarte ?)
-#   - signal chipcard demon to read card
-#   - AND display list of available cards read
-#   - scrolling in list
-#   - ENTER selects patient and imports card data
-#   - ESC cancels selection
-#
 # - hitting ALT-N
 #   - immediately goes to entry of new patient
 #
@@ -771,6 +992,79 @@ if __name__ == "__main__":
 
 #============================================================
 # $Log: gmPatSearchWidgets.py,v $
+# Revision 1.80.2.1  2007/06/01 15:15:47  ncq
+# - every option needs a name, so use "patient_search.dob_warn_interval"
+#
+# Revision 1.80  2007/05/18 15:55:58  ncq
+# - auto-select first item in person/dto selector
+#
+# Revision 1.79  2007/05/14 14:56:41  ncq
+# - fix typo
+#
+# Revision 1.78  2007/05/14 13:52:24  ncq
+# - add display_name() in two places to fix visual glitch with search
+#
+# Revision 1.77  2007/05/14 13:37:42  ncq
+# - don't do anything if the only external patient is
+#   already the active patient in GNUmed
+#
+# Revision 1.76  2007/05/14 13:11:24  ncq
+# - use statustext() signal
+#
+# Revision 1.75  2007/05/07 08:04:36  ncq
+# - a bit of cleanup
+#
+# Revision 1.74  2007/04/19 13:13:47  ncq
+# - cleanup
+#
+# Revision 1.73  2007/04/11 14:53:33  ncq
+# - do some safeguarding against binary/large files being dropped onto
+#   the data mining plugin - check mimetype and size
+#
+# Revision 1.72  2007/04/09 22:03:57  ncq
+# - make data mining panel a file drop target
+#
+# Revision 1.71  2007/04/09 21:12:49  ncq
+# - better wording in contribute email
+# - properly unicode() SQL results
+#
+# Revision 1.70  2007/04/09 18:52:47  ncq
+# - magic patient activation from report result list
+#
+# Revision 1.69  2007/04/09 16:31:06  ncq
+# - add _on_contribute
+#
+# Revision 1.68  2007/04/08 21:17:14  ncq
+# - add more event handlers to data mining panel
+#
+# Revision 1.67  2007/04/07 22:45:28  ncq
+# - add save handler to data mining panel
+#
+# Revision 1.66  2007/04/06 23:15:21  ncq
+# - add data mining panel
+#
+# Revision 1.65  2007/04/01 15:29:51  ncq
+# - safely get_encoding()
+#
+# Revision 1.64  2007/03/02 15:38:47  ncq
+# - decode() strftime() to u''
+#
+# Revision 1.63  2007/02/22 17:41:13  ncq
+# - adjust to gmPerson changes
+#
+# Revision 1.62  2007/02/17 14:01:26  ncq
+# - gmCurrentProvider.workplace now property
+# - notify about birthday after activating patient
+# - remove crufty code/docs
+#
+# Revision 1.61  2007/02/15 14:58:08  ncq
+# - tie KVKs intoi external patient sources framework
+#
+# Revision 1.60  2007/02/13 17:07:38  ncq
+# - tie PracSoft PATIENTS.IN file into external patients framework
+# - *always* let user decide on whether to activate an external patient
+#   even if only a single source provides a patient
+#
 # Revision 1.59  2007/01/20 22:52:27  ncq
 # - .KeyCode -> GetKeyCode()
 #
