@@ -4,8 +4,8 @@
 """
 #==================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPlugin.py,v $
-# $Id: gmPlugin.py,v 1.65 2006/11/07 00:34:52 ncq Exp $
-__version__ = "$Revision: 1.65 $"
+# $Id: gmPlugin.py,v 1.70 2007/05/08 11:16:32 ncq Exp $
+__version__ = "$Revision: 1.70 $"
 __author__ = "H.Herb, I.Haywood, K.Hilbert"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
@@ -13,7 +13,7 @@ import os, sys, re
 
 import wx
 
-from Gnumed.pycommon import gmExceptions, gmGuiBroker, gmLog, gmCfg, gmDispatcher, gmSignals
+from Gnumed.pycommon import gmExceptions, gmGuiBroker, gmLog, gmCfg, gmDispatcher, gmSignals, gmTools
 from Gnumed.business import gmPerson
 
 _log = gmLog.gmDefLog
@@ -24,15 +24,15 @@ class cLoadProgressBar (wx.ProgressDialog):
 	def __init__(self, nr_plugins):
 		wx.ProgressDialog.__init__(
 			self,
-			title = _("GNUmed: configuring [%s] (%s plugins)") % (gmPerson.gmCurrentProvider().get_workplace(), nr_plugins),
+			title = _("GNUmed: configuring [%s] (%s plugins)") % (gmPerson.gmCurrentProvider().workplace, nr_plugins),
 			message = _("loading list of plugins                               "),
 			maximum = nr_plugins,
 			parent = None,
 			style = wx.PD_ELAPSED_TIME
 			)
 		# set window icon
-		gb = gmGuiBroker.GuiBroker()
-		png_fname = os.path.join(gb['gnumed_dir'], 'bitmaps', 'serpent.png')
+		paths = gmTools.cPaths(app_name = u'gnumed', wx = wx)
+		png_fname = os.path.join(paths.system_app_data_dir, 'bitmaps', 'serpent.png')
 		icon = wx.EmptyIcon()
 		try:
 			icon.LoadFile(png_fname, wx.BITMAP_TYPE_PNG)
@@ -42,7 +42,7 @@ class cLoadProgressBar (wx.ProgressDialog):
 		self.idx = 0
 		self.nr_plugins = nr_plugins
 		self.prev_plugin = ""
-
+	#----------------------------------------------------------
 	def Update (self, result, plugin):
 		if result == -1:
 			result = ""
@@ -184,16 +184,10 @@ class cNotebookPlugin:
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.is_connected():
 			# FIXME: people want an optional red backgound here
-			self._set_status_txt(_('Cannot switch to [%s]: no patient selected') % self.name())
-			wx.Bell()
+			gmDispatcher.send(gmSignals.statustext(), msg = _('Cannot switch to [%s]: no patient selected') % self.name())
 			return None
 		return 1
 	#-----------------------------------------------------
-	def _set_status_txt(self, txt):
-		set_statustext = self.gb['main.statustext']
-		set_statustext(txt)
-		return 1
-	#-----------------------------------------------------
 	def Raise(self):
 		"""Raise ourselves."""
 		nb_pages = self.gb['horstspace.notebook.pages']
@@ -351,7 +345,7 @@ def GetPluginLoadList(option, plugin_dir = '', defaults = None):
 	FIXME: look at gmRichardSpace to see how to load plugins
 	FIXME: NOT from files in directories (important for py2exe)
 	"""
-	curr_workplace = gmPerson.gmCurrentProvider().get_workplace()
+	curr_workplace = gmPerson.gmCurrentProvider().workplace
 
 	dbcfg = gmCfg.cCfgSQL()
 	p_list = dbcfg.get2 (
@@ -395,7 +389,7 @@ def GetPluginLoadList(option, plugin_dir = '', defaults = None):
 			return defaults
 		# now scan it
 		files = os.listdir(search_path)
-		_log.Log(gmLog.lData, "plugin set: %s, gnumed_dir: %s" % (plugin_dir, gb['gnumed_dir']))
+		_log.Log(gmLog.lData, "plugin set: %s" % plugin_dir)
 		_log.Log(gmLog.lInfo, "scanning plugin directory [%s]" % search_path)
 		_log.Log(gmLog.lData, "files found: %s" % str(files))
 		p_list = []
@@ -433,6 +427,21 @@ if __name__ == '__main__':
 
 #==================================================================
 # $Log: gmPlugin.py,v $
+# Revision 1.70  2007/05/08 11:16:32  ncq
+# - need to import gmTools
+#
+# Revision 1.69  2007/05/07 12:35:20  ncq
+# - improve use of gmTools.cPaths()
+#
+# Revision 1.68  2007/04/11 20:47:13  ncq
+# - no more 'resource dir' and 'gnumed_dir'
+#
+# Revision 1.67  2007/03/02 15:40:58  ncq
+# - status text now set by signal
+#
+# Revision 1.66  2007/02/17 14:13:11  ncq
+# - gmPerson.gmCurrentProvider().workplace now property
+#
 # Revision 1.65  2006/11/07 00:34:52  ncq
 # - fix logic error in _on_raise_by_signal()
 #
