@@ -2,8 +2,8 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmProviderInboxWidgets.py,v $
-# $Id: gmProviderInboxWidgets.py,v 1.12 2007/01/04 22:52:34 ncq Exp $
-__version__ = "$Revision: 1.12 $"
+# $Id: gmProviderInboxWidgets.py,v 1.13 2007/05/14 13:11:25 ncq Exp $
+__version__ = "$Revision: 1.13 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
 #import os.path, sys, re, time
@@ -125,9 +125,7 @@ Leaving message in inbox.""") % handler_key,
 	def _on_delete_focussed_msg(self, evt):
 		inbox = gmProviderInbox.cProviderInbox()
 		if not inbox.delete_message(self.__focussed_msg[8]):
-			gmGuiHelpers.gm_statustext (
-				_('Cannot remove message from Inbox.')
-			)
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot remove message from Inbox.'))
 			return False
 		self.repopulate_ui()
 		return True
@@ -147,6 +145,9 @@ Leaving message in inbox.""") % handler_key,
 		return True
 #============================================================
 # $Log: gmProviderInboxWidgets.py,v $
+# Revision 1.13  2007/05/14 13:11:25  ncq
+# - use statustext() signal
+#
 # Revision 1.12  2007/01/04 22:52:34  ncq
 # - show proper salutation for people without title
 #
