@@ -4,22 +4,19 @@ Design by Richard Terry and Ian Haywood.
 """
 #====================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmResizingWidgets.py,v $
-# $Id: gmResizingWidgets.py,v 1.45 2007/01/20 22:52:27 ncq Exp $
-__version__ = "$Revision: 1.45 $"
+# $Id: gmResizingWidgets.py,v 1.47 2007/05/21 13:06:12 ncq Exp $
+__version__ = "$Revision: 1.47 $"
 __author__ = "Ian Haywood, Karsten Hilbert, Richard Terry"
 __license__ = 'GPL  (details at http://www.gnu.org)'
 
 import sys
 
-try:
-	import wxversion
-	import wx
-	import wx.stc
-except ImportError:
-	from wxPython import wx
-	from wxPython import stc
 
-from Gnumed.pycommon import gmI18N, gmLog
+import wx
+import wx.stc
+
+
+from Gnumed.pycommon import gmI18N, gmLog, gmDispatcher, gmSignals
 from Gnumed.wxpython import gmGuiHelpers, gmTimer
 
 _log = gmLog.gmDefLog
@@ -647,29 +644,19 @@ class cResizingSTC(wx.stc.StyledTextCtrl):
 		# - after last character in widget:
 		#	- if after ';': go to next in tab order
 		#	- f no ';' there: add one
-		if event.GetKeyCode() == wx.WXK_RETURN and not event.m_shiftDown:
-#			if (self.list is not None) and self.list.alive:
-#				self.list.Enter()
+#		if event.GetKeyCode() == wx.WXK_RETURN and not event.m_shiftDown:
+#			if self.GetLength() == 0:
+#				if self.next_in_tab_order is not None:
+#					self.next_in_tab_order.SetFocus()
+#				return
+#			if curs_pos == self.GetLength():
+#				# FIXME: make this smarter to deal with whitespace after ';'
+#				if self.GetCharAt(curs_pos-1) == ord(';'):
+#					if self.next_in_tab_order:
+#						self.next_in_tab_order.SetFocus()
+#				else:
+#					self.AddText (';')
 #				return
-			if self.GetLength() == 0:
-				if self.next_in_tab_order is not None:
-					self.next_in_tab_order.SetFocus()
-				return
-			if curs_pos == self.GetLength():
-				# FIXME: make this smarter to deal with whitespace after ';'
-				if self.GetCharAt(curs_pos-1) == ord(';'):
-					if self.next_in_tab_order:
-						self.next_in_tab_order.SetFocus()
-					# FIXME: why ?
-#					elif self.__parent.complete:
-#						self.__parent.complete()
-				else:
-					self.AddText (';')
-				return
-
-		# FIXME: why ?
-#		if event.GetKeyCode() == wx.WXK_F12 and self.__parent.complete:
-#			self.__parent.complete()
 
 		event.Skip()	# skip to next event handler to keep processing
 	#------------------------------------------------
@@ -796,10 +783,7 @@ class cResizingSTC(wx.stc.StyledTextCtrl):
 		try:
 			create_widget = self.__popup_keywords[kwd]['widget_factory']
 		except KeyError:
-			gmGuiHelpers.gm_statustext (
-				aMessage = _('No action configured for keyword [%s].') % kwd,
-				aLogLevel = gmLog.lWarn
-			)
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('No action configured for keyword [%s].') % kwd)
 			return False
 
 #		best_pos, best_size = self.__get_best_popup_geom()
@@ -823,9 +807,7 @@ class cResizingSTC(wx.stc.StyledTextCtrl):
 			return False
 
 		if not isinstance(popup, wx.Dialog):
-			gmGuiHelpers.gm_statustext (
-				aMessage = _('Action [%s] on keyword [%s] is invalid.') % (create_widget, kwd)
-			)
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Action [%s] on keyword [%s] is invalid.') % (create_widget, kwd))
 			_log.Log(gmLog.lErr, 'keyword [%s] triggered action [%s]' % (kwd, create_widget))
 			_log.Log(gmLog.lErr, 'the result (%s) is not a wx.Dialog subclass instance, however' % str(popup))
 			return False
@@ -1068,6 +1050,13 @@ if __name__ == '__main__':
 	app.MainLoop()
 #====================================================================
 # $Log: gmResizingWidgets.py,v $
+# Revision 1.47  2007/05/21 13:06:12  ncq
+# - make ENTER start new line in STC rather than appending ;
+#   - user request
+#
+# Revision 1.46  2007/05/14 13:11:25  ncq
+# - use statustext() signal
+#
 # Revision 1.45  2007/01/20 22:52:27  ncq
 # - .KeyCode -> GetKeyCode()
 #
