@@ -2,8 +2,8 @@
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmSOAPWidgets.py,v $
-# $Id: gmSOAPWidgets.py,v 1.88 2007/01/15 20:22:46 ncq Exp $
-__version__ = "$Revision: 1.88 $"
+# $Id: gmSOAPWidgets.py,v 1.93 2007/05/14 13:11:25 ncq Exp $
+__version__ = "$Revision: 1.93 $"
 __author__ = "Carlos Moro <cfmoro1976@yahoo.es>, K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -115,7 +115,7 @@ class cProgressNoteInputNotebook(wx.Notebook, gmRegetMixin.cRegetOnPaintMixin):
 			id = id,
 			pos = pos,
 			size = size,
-			style = wx.NB_TOP | wx.NB_MULTILINE | wx.NO_BORDER | wx.VSCROLL | wx.HSCROLL,
+			style = wx.NB_TOP | wx.NB_MULTILINE | wx.NO_BORDER,
 			name = self.__class__.__name__
 		)
 		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
@@ -227,7 +227,7 @@ class cProgressNoteInputNotebook(wx.Notebook, gmRegetMixin.cRegetOnPaintMixin):
 #		print "- ask user about unsaved data"
 		pass
 #============================================================
-class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixin):
+class cNotebookedProgressNoteInputPanel(wx.Panel):
 	"""A progress note input panel.
 
 	Left hand side:
@@ -235,6 +235,8 @@ class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixi
 
 	Right hand side:
 	- progress note editors notebook
+
+	Expects to live in a notebook.
 	"""
 	#--------------------------------------------------------
 	def __init__(self, parent, id):
@@ -252,8 +254,6 @@ class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixi
 			size = wx.DefaultSize,
 			style = wx.NO_BORDER
 		)
-		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
-
 		self.__pat = gmPerson.gmCurrentPatient()
 
 		# ui contruction and event handling set up
@@ -365,7 +365,12 @@ class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixi
 					last = epi['episode_modified_when'].strftime('%m/%Y')
 				else:
 					last = last_encounter['last_affirmed'].strftime('%m/%Y')
-				label = u'%s: %s "%s"%s' % (last, problem['l10n_type'], problem['problem'], gmTools.coalesce(epi['health_issue'], '', ' (%s)'))
+				label = u'%s: %s "%s"%s' % (
+					last,
+					problem['l10n_type'],
+					problem['problem'],
+					gmTools.coalesce(initial = epi['health_issue'], instead = '', template_initial = ' (%s)')
+				)
 			self.__LST_problems.Append(label, problem)
 		splitter_width = self.__splitter.GetSizeTuple()[0]
 		self.__splitter.SetSashPosition((splitter_width / 2), True)
@@ -392,12 +397,12 @@ class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixi
 	#--------------------------------------------------------
 	def _on_post_patient_selection(self):
 		"""Patient changed."""
-		self._schedule_data_reget()
+		if self.GetParent().GetCurrentPage() == self:
+			self.reset_ui_content()
 	#--------------------------------------------------------
 	def _on_episodes_modified(self):
-		# FIXME: this should rather *schedule* a reget which would
-		# FIXME: then happen immediately in visible widgets
-		self._schedule_data_reget()
+		if self.GetParent().GetCurrentPage() == self:
+			self.__refresh_problem_list()
 	#--------------------------------------------------------
 	def __on_clear(self, event):
 		"""Clear raised SOAP input widget.
@@ -448,7 +453,7 @@ class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixi
 		page_idx = self.__soap_notebook.GetSelection()
 		soap_nb_page = self.__soap_notebook.GetPage(page_idx)
 		if not soap_nb_page.save():
-			gmGuiHelpers.gm_statustext(_('Problem saving progress note: duplicate information ?'))
+			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Problem saving progress note: duplicate information ?'))
 			return False
 		self.__soap_notebook.DeletePage(page_idx)
 		# always keep one unassociated editor open
@@ -456,16 +461,10 @@ class cNotebookedProgressNoteInputPanel(wx.Panel, gmRegetMixin.cRegetOnPaintMixi
 		self.__refresh_problem_list()
 		return True
 	#--------------------------------------------------------
-	# reget mixin API
+	# notebook plugin API
 	#--------------------------------------------------------
-	def _populate_with_data(self):
-		"""
-		Fills UI with data.
-		"""
-#		self.reset_ui_content()
-		if self.__refresh_problem_list():
-			return True
-		return False
+	def repopulate_ui(self):
+		self.__refresh_problem_list()
 #============================================================
 class cSOAPLineDef:
 	def __init__(self):
@@ -909,7 +908,6 @@ if __name__ == "__main__":
 	_log = gmLog.gmDefLog
 	_log.SetAllLogLevels(gmLog.lData)
 	from Gnumed.pycommon import gmPG2
-	gmPG2.set_default_client_encoding('UNICODE')
 	#--------------------------------------------------------
 	def get_narrative(pk_encounter=None, pk_health_issue = None, default_labels=None):
 		"""
@@ -1064,6 +1062,21 @@ if __name__ == "__main__":
 
 #============================================================
 # $Log: gmSOAPWidgets.py,v $
+# Revision 1.93  2007/05/14 13:11:25  ncq
+# - use statustext() signal
+#
+# Revision 1.92  2007/03/08 11:53:59  ncq
+# - cleanup
+#
+# Revision 1.91  2007/03/02 15:39:13  ncq
+# - properly refresh widgets
+#
+# Revision 1.90  2007/02/17 14:02:11  ncq
+# - use improved coalesce()
+#
+# Revision 1.89  2007/02/04 16:14:23  ncq
+# - remove VSCROLL/HSCROLL for Mac
+#
 # Revision 1.88  2007/01/15 20:22:46  ncq
 # - move_episode_to_issue() is in gmEMRStructWidgets
 #
