@@ -2,8 +2,8 @@
 
 #===========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmTopPanel.py,v $
-# $Id: gmTopPanel.py,v 1.76 2006/11/05 16:04:45 ncq Exp $
-__version__ = "$Revision: 1.76 $"
+# $Id: gmTopPanel.py,v 1.84 2007/05/21 17:13:43 ncq Exp $
+__version__ = "$Revision: 1.84 $"
 __author__  = "R.Terry <rterry@gnumed.net>, I.Haywood <i.haywood@ugrad.unimelb.edu.au>, K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -11,9 +11,9 @@ import sys, os.path
 
 import wx
 
-from Gnumed.pycommon import gmGuiBroker, gmPG2, gmSignals, gmDispatcher, gmLog, gmCLI
-from Gnumed.business import gmPerson, gmEMRStructItems
-from Gnumed.wxpython import gmGuiHelpers, gmPatPicWidgets, gmPatSearchWidgets
+from Gnumed.pycommon import gmGuiBroker, gmPG2, gmSignals, gmDispatcher, gmLog, gmCLI, gmTools
+from Gnumed.business import gmPerson, gmEMRStructItems, gmAllergy
+from Gnumed.wxpython import gmGuiHelpers, gmPatPicWidgets, gmPatSearchWidgets, gmAllergyWidgets
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
@@ -111,7 +111,7 @@ class cMainTopPanel(wx.Panel):
 		self.szr_top_row.Add (self.patient_selector, 5, wx.BOTTOM, 3)
 		#  - age
 		self.txt_age = wx.TextCtrl(self, -1, '', size = (50,-1), style = wx.TE_READONLY)
-		self.txt_age.SetFont (wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD, False, ''))
+		self.txt_age.SetFont (wx.Font(11, wx.SWISS, wx.NORMAL, wx.BOLD, False, ''))
 		self.txt_age.SetBackgroundColour(bg_col)
 		self.szr_top_row.Add (self.txt_age, 0, wx.BOTTOM | wx.LEFT | wx.RIGHT, 3)
 		#  - allergies (substances only, like "makrolides, penicillins, eggs")
@@ -120,7 +120,7 @@ class cMainTopPanel(wx.Panel):
 		self.lbl_allergies.SetBackgroundColour(bg_col)
 		self.lbl_allergies.SetForegroundColour(col_brightred)
 		self.txt_allergies = wx.TextCtrl (self, -1, "", style = wx.TE_READONLY)
-		self.txt_allergies.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD, False, ''))
+		self.txt_allergies.SetFont(wx.Font(10, wx.SWISS, wx.NORMAL, wx.BOLD, False, ''))
 		#self.txt_allergies.SetBackgroundColour(bg_col)
 		self.txt_allergies.SetForegroundColour (col_brightred)
 		self.szr_top_row.Add (self.lbl_allergies, 0, wx.ALL, 3)
@@ -246,6 +246,8 @@ class cMainTopPanel(wx.Panel):
 		tools_menu.Append(ID_LOCKMENU, _("lock client"), _("locks client and hides data"))
 		wx.EVT_MENU(main_frame, ID_LOCKMENU, self._on_lock)
 
+		wx.EVT_LEFT_DCLICK(self.txt_allergies, self._on_allergies_dclicked)
+
 		# client internal signals
 		gmDispatcher.connect(signal=gmSignals.post_patient_selection(), receiver=self._on_post_patient_selection)
 		gmDispatcher.connect(signal=gmSignals.allergy_updated(), receiver=self._update_allergies)
@@ -255,6 +257,15 @@ class cMainTopPanel(wx.Panel):
 		print "and popping up a modal dialog box asking for a"
 		print "password to reactivate"
 	#----------------------------------------------
+	def _on_allergies_dclicked(self, evt):
+		pat = gmPerson.gmCurrentPatient()
+		if not pat.is_connected():
+			gmDispatcher.send(gmSignals.statustext(), msg = _('Cannot activate Allergy Manager. No active patient.'))
+			return
+		dlg = gmAllergyWidgets.cAllergyManagerDlg(parent=self, id=-1)
+		dlg.ShowModal()
+		return
+	#----------------------------------------------
 #	def _on_show_BMI(self, evt):
 		# FIXME: update patient ID ?
 #		bmi = gmBMIWidgets.BMI_Frame(self)
@@ -287,12 +298,11 @@ class cMainTopPanel(wx.Panel):
 		wx.CallAfter(self.__update_allergies, **kwargs)
 	#----------------------------------------------
 	def __on_post_patient_selection(self, **kwargs):
-		ident = self.curr_pat.get_identity()
-		age = ident['medical_age']
+		age = self.curr_pat['medical_age']
 		# FIXME: if the age is below, say, 2 hours we should fire
 		# a timer here that updates the age in increments of 1 minute ... :-)
 		self.txt_age.SetValue(age)
-		self.patient_selector.SetValue(ident['description'])
+		self.patient_selector.SetValue(self.curr_pat['description'])
 	#-------------------------------------------------------
 	def __on_display_demographics(self, evt):
 		print "display patient demographic window now"
@@ -301,19 +311,36 @@ class cMainTopPanel(wx.Panel):
 		wx.CallAfter(self.__update_allergies)
 	#-------------------------------------------------------
 	def __update_allergies(self, **kwargs):
-		epr = self.curr_pat.get_emr()
-		allergies = epr.get_allergies(remove_sensitivities=1)
-		if allergies is None:
-			self.txt_allergies.SetValue(_('error getting allergies'))
-			return False
+		emr = self.curr_pat.get_emr()
+		allergies = emr.get_allergies()
+
 		if len(allergies) == 0:
-			self.txt_allergies.SetValue(_('no allergies recorded'))
+			self.txt_allergies.SetValue('')
+			self.txt_allergies.SetToolTipString(gmAllergy.allergic_state2str(state = emr.allergic_state))
 			return True
+
 		tmp = []
+		tt = u'%-70s\n\n' % _('Allergies:')
 		for allergy in allergies:
-			tmp.append(allergy['descriptor'])
+			if allergy['type'] == 'allergy':
+				tmp.append(allergy['descriptor'][:10])
+			if allergy['definite']:
+				certainty = _('definite')
+			else:
+				certainty = _('likely')
+			reaction = gmTools.coalesce(allergy['reaction'], _('reaction not recorded'))
+			if len(reaction) > 50:
+				reaction = reaction[:50] + u'...'
+			tt += u'%s - %s (%s): %s\n' % (
+				allergy['descriptor'],
+				allergy['l10n_type'],
+				certainty,
+				reaction
+			)
+
 		data = ','.join(tmp)
 		self.txt_allergies.SetValue(data)
+		self.txt_allergies.SetToolTipString(tt)
 	#-------------------------------------------------------
 	# remote layout handling
 	#-------------------------------------------------------
@@ -400,13 +427,39 @@ class cMainTopPanel(wx.Panel):
 #===========================================================	
 if __name__ == "__main__":
 	wx.InitAllImageHandlers()
-	gb = gmGuiBroker.GuiBroker()
-	gb['gnumed_dir'] = '..'
 	app = wxPyWidgetTester(size = (400, 200))
 	app.SetWidget(cMainTopPanel, -1)
 	app.MainLoop()
 #===========================================================
 # $Log: gmTopPanel.py,v $
+# Revision 1.84  2007/05/21 17:13:43  ncq
+# - translate "Allergies" in allergy field tooltip
+#
+# Revision 1.83  2007/04/11 20:47:13  ncq
+# - no more 'resource dir' and 'gnumed_dir'
+#
+# Revision 1.82  2007/03/26 16:50:14  ncq
+# - allergy['reaction'] can be empty
+#
+# Revision 1.81  2007/03/26 14:44:36  ncq
+# - left align first line of allergies list tooltip
+#
+# Revision 1.80  2007/03/23 15:39:02  ncq
+# - show allergy manager on double-clicking allergies field
+#
+# Revision 1.79  2007/03/23 15:03:02  ncq
+# - improved allergies display
+#   - smaller font
+#   - 10 char truncation
+#   - align properly
+#   - patient dependant tooltip listing allergy details including sensitivities
+#
+# Revision 1.78  2007/03/21 08:14:32  ncq
+# - use proper no-allergies string
+#
+# Revision 1.77  2007/02/22 17:41:13  ncq
+# - adjust to gmPerson changes
+#
 # Revision 1.76  2006/11/05 16:04:45  ncq
 # - some cleanup
 #
