@@ -3,21 +3,18 @@
 # gnumed.py - launcher for the main GNUmed GUI client module
 #===========================================================
 
-__doc__ = """
-<gnumed.py> is the launcher for the main GNUmed GUI client. It
-is intended to be used as a standalone program.
+__doc__ = """GNUmed client launcher.
+
+This is the launcher for the GNUmed GUI client. It takes
+care of all the pre- and post-GUI runtime environment setup.
 
 --quiet
  Be extra quiet and show only _real_ errors in the log.
 --debug
- Be extra verbose and report nearly everything that's going
- on. Useful for, well, debugging :-)
+ Pre-set the [debug mode] checkbox in the login dialog to
+ increase verbosity in the log file. Useful for, well, debugging :-)
 --profile=<file>
  Activate profiling and write profile data to <file>.
---talkback
- Run the client and upon exiting run a talkback client where
- you can enter a comment and send the log off to the bug hunters.
- Very useful when used in conjunction with --debug.
 --text-domain=<text domain>
  Set this to change the name of the language file to be loaded.
  Note, this does not change the directory the file is searched in,
@@ -42,47 +39,43 @@ is intended to be used as a standalone program.
 """
 #==========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gnumed.py,v $
-# $Id: gnumed.py,v 1.105 2006/12/21 17:54:43 ncq Exp $
-__version__ = "$Revision: 1.105 $"
+# $Id: gnumed.py,v 1.118 2007/05/21 14:49:42 ncq Exp $
+__version__ = "$Revision: 1.118 $"
 __author__  = "H. Herb <hherb@gnumed.net>, K. Hilbert <Karsten.Hilbert@gmx.net>, I. Haywood <i.haywood@ugrad.unimelb.edu.au>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
 
 # standard library
-import sys, os, os.path, signal
+import sys, os, os.path, signal, warnings
 
-#==========================================================
-# don't run as module
+
+# 1) don't run as module
 if __name__ != "__main__":
 	print "GNUmed startup: This should not be imported as a module !"
 	print "---------------------------------------------------------"
 	print __doc__
 	sys.exit(0)
 
-#==========================================================
-# advise not to run as root
+
+# 2) advise not to run as root
 if os.name in ['posix'] and os.geteuid() == 0:
 	print """
 GNUmed startup: GNUmed should not be run as root.
 -------------------------------------------------
 
-Running GNUmed as root can potentially put all
+Running GNUmed as <root> can potentially put all
 your medical data at risk. It is strongly advised
 against. Please run GNUmed as a non-root user.
 """
 	sys.exit(1)
 
-#==========================================================
+
 # Python 2.3 on Mandrake turns True/False deprecation warnings
 # into exceptions, so revert them to warnings again
-try:
-	import warnings
-	warnings.filterwarnings("default", "Use\sPython.s\sFalse\sinstead", DeprecationWarning)
-	warnings.filterwarnings("default", "Use\sPython.s\sTrue\sinstead", DeprecationWarning)
-except:
-	pass
+warnings.filterwarnings("default", "Use\sPython.s\sFalse\sinstead", DeprecationWarning)
+warnings.filterwarnings("default", "Use\sPython.s\sTrue\sinstead", DeprecationWarning)
+
 
-#==========================================================
 _log = None
 _cfg = None
 _email_logger = None
@@ -91,19 +84,9 @@ _old_sig_hup = None
 _old_sig_term = None
 
 #==========================================================
-def handle_uncaught_exception(t, v, tb):
-
-	print ",========================================================"
-	print "| Unhandled exception caught !"
-	print "| Type :", t
-	print "| Value:", v
-	print "`========================================================"
-	_log.LogException('unhandled exception caught', (t,v,tb), verbose=True)
-	# FIXME: allow user to mail report to developers from here
-	sys.__excepthook__(t,v,tb)
-
+# convenience functions
 #==========================================================
-def setup_logging():
+def setup_console_exption_handler():
 	import_error_sermon = """
 CRITICAL ERROR: Cannot load GNUmed Python modules ! - Program halted.
 
@@ -124,45 +107,28 @@ did run gnumed/check-prerequisites.sh with good results.
 If you still encounter errors after checking the above
 requirements please ask on the mailing list.
 """ % '\n '.join(sys.path)
+
 	try:
-		from Gnumed.pycommon import gmLog as _gmLog
-		from Gnumed.pycommon import gmCLI as _gmCLI
+		from Gnumed.pycommon import gmTools
 	except ImportError:
 		sys.exit(import_error_sermon)
 
+	sys.excepthook = gmTools.handle_uncaught_exception
+#==========================================================
+def setup_logging():
+	from Gnumed.pycommon import gmLog as _gmLog
+
 	global gmLog
 	gmLog = _gmLog
 	global _log
 	_log = gmLog.gmDefLog
-	global gmCLI
-	gmCLI = _gmCLI
 
-	# talkback mode ?
-	if gmCLI.has_arg('--talkback'):
-		# email logger as a loop device
-		global _email_logger
-		_email_logger = gmLog.cLogTargetEMail(gmLog.lInfo, aFrom = "GNUmed client", aTo = ("fixme@gnumed.net",), anSMTPServer = "mail.best1-host.com")
-		_log.AddTarget (_email_logger)
+	# always start with debugging enabled
+	_log.SetAllLogLevels(gmLog.lData)
 
-	# debug level logging ?
-	if gmCLI.has_arg("--debug"):
-		print "GNUmed startup: Activating verbose log level for debugging."
-		_log.SetAllLogLevels(gmLog.lData)
-	elif gmCLI.has_arg ("--quiet"):
-		_log.SetAllLogLevels(gmLog.lErr)
-	else:
-		_log.SetAllLogLevels(gmLog.lInfo)
-
-	# Console Is Good(tm)
-	# ... but only for Panics and important messages
-	aLogTarget = gmLog.cLogTargetConsole(gmLog.lErr)
-	_log.AddTarget(aLogTarget)
-
-	return 1
+	return True
 #==========================================================
 def setup_locale():
-	from Gnumed.pycommon import gmI18N
-
 	gmI18N.activate_locale()
 
 	td = None
@@ -177,12 +143,30 @@ def setup_locale():
 
 	return True
 #==========================================================
+def setup_paths():
+	"""Create needed paths in user home directory."""
+
+	from Gnumed.pycommon import gmTools
+
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', '.gnumed', 'scripts')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', '.gnumed', 'spellcheck')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'docs')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'xDT')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'EMR')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'tmp', 'docs')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'xDT')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'logs')))
+
+	paths = gmTools.cPaths()
+#==========================================================
 def setup_date_time():
 	from Gnumed.pycommon import gmDateTime
+
 	gmDateTime.init()
 #==========================================================
-def setup_cfg_file():
+def setup_cfg_files():
 	from Gnumed.pycommon import gmCfg, gmNull
+
 	if isinstance(gmCfg.gmDefCfgFile, gmNull.cNull):
 		if gmCfg.create_default_cfg_file():
 			# now that we got the file we can reopen it as a config file :-)
@@ -197,6 +181,7 @@ def setup_cfg_file():
 		else:
 			print "GNUmed startup: Cannot open or create config file by any means.\nPlease see the log for details."
 			sys.exit(0)
+
 	global _cfg
 	_cfg = gmCfg.gmDefCfgFile
 #==========================================================
@@ -224,207 +209,10 @@ def setup_signal_handlers():
 	global _old_sig_term
 	old_sig_term = signal.signal(signal.SIGTERM, handle_sig_term)
 #==========================================================
-def get_resource_dir():
-	"""Detect resource directory base.
+def log_object_refcounts():
+	if not gmCLI.has_arg('--debug'):
+		return
 
-	1) resource directory defined in config file
-	  - this will allow people to start GNUmed from any
-	    dir they want on any OS they happen to run
-    2) assume /usr/share/gnumed/ as resource dir
-	  - this will work on POSIX/LSB systems and may work
-	    on Cygwin systems
-	  - this is the no-brainer for stock UN*X
-    3) finally try one level below path to binary
-      - last resort for lesser systems
-	  - this is the no-brainer for DOS/Windows
-	  - it also allows running from a local CVS copy
-	"""
-	print "GNUmed startup: Determining GNUmed resource directory ..."
-	# config file
-	candidate = _cfg.get('client', 'resource directory')
-	if candidate not in [None, '']:
-		# expand ~/... and ~*/...
-		# normalize case
-		# connect to / dir
-		tmp = os.path.normcase(os.path.abspath(os.path.expanduser(candidate)))
-		if os.access(tmp, os.R_OK):
-			return tmp
-		print "- resource path [%s] not accessible" % tmp
-		print '- adjust [client] -> "resource directory"'
-		print "  in the config file"
-		return None
-
-	# - normalize and convert slashes to local filesystem convention
-	tmp = os.path.normcase('/usr/share/gnumed/')
-	if os.access(tmp, os.R_OK):
-		return tmp
-
-	print '- standard resource path [%s] not accessible' % tmp
-	print '- seems like we are running from an arbitrary'
-	print '  directory (like a CVS tree or on Windows)'
-
-	# get path to binary
-	tmp = os.path.abspath(os.path.dirname(sys.argv[0]))
-	# strip one directory level
-	# this is a rather neat trick :-)
-	tmp = os.path.normpath(os.path.join(tmp, '..'))
-	# sanity check (paranoia rulez)
-	if os.access(tmp, os.R_OK):
-		return tmp
-
-	print '- resource path [%s] not accessible' % tmp
-	print ''
-	print 'GNUmed startup: Something is really rotten here. We better'
-	print 'GNUmed startup: fail gracefully ! Please ask your administrator'
-	print 'GNUmed startup: for help.'
-
-	return None
-#----------------------------------------------------------
-def get_base_dir():
-	"""Retrieve the global base directory.
-
-	   The most preferable approach would be to just let
-	   the user specify the name of a config file on the
-	   command line but for that we'd have to load some
-	   non-standard modules already unless we want to
-	   duplicate the entire config file infrastructure
-	   right here.
-
-	   1) regardless of OS if the environment variable GNUMED_DIR
-		  is set this directory will be tried as a base dir
-		  - this will allow people to start GNUmed from any dir
-		    they want on any OS they happen to run
-		  - the variable name has been chosen to be descriptive
-		    but still not waste too many resources
-	   2) assume /usr/share/gnumed/ as base dir
-		  - this will work on POSIX systems and may work on
-		    Cygwin systems
-		  - this is the no-brainer for stock UN*X
-	   3) finally try one level below path to binary
-	      - last resort for lesser systems
-		  - this is the no-brainer for DOS/Windows
-		  - it also allows running from a local CVS copy
-	"""
-	print "GNUmed startup: Determining GNUmed base directory ..."
-	# environment variable
-	if os.environ.has_key('GNUMED_DIR'):
-		var = os.environ['GNUMED_DIR']
-		# - expand '~' and '~user'
-		# - expand '$var' and '${var}'
-		# - make absolute (normalizes slashes, too)
-		# - normalize case
-		tmp = os.path.normcase (os.path.abspath (
-			os.path.expandvars(os.path.expanduser(var))
-		))
-		print '- environment variable GNUMED_DIR contains [%s]' % tmp
-		print '  this expands to [%s]' % tmp
-		# - however, we don't want any random rogue to throw us off
-		#   balance so we check whether that's a valid path
-		# - note that it may still be the wrong directory
-		if os.path.exists(tmp):
-			return tmp
-		print '  (this is not a valid path, however)'
-	else:
-		print '- environment variable GNUMED_DIR not set'
-		print '  (only necessary if nothing else works, though)'
-
-	# standard POSIX path
-	# - only works on POSIX where the given string is a valid path definition
-	tmp = '/usr/share/gnumed/'
-	# - sanity check
-	if os.path.exists(tmp):
-		return tmp
-
-	print '- standard path [%s] not accessible' % tmp
-	print '- seems like we are running from an arbitrary'
-	print '  directory (like a CVS tree or on Windows), namely:'
-
-	# get path to binary
-	bin = sys.argv[0]
-	tmp = os.path.dirname(os.path.abspath(bin))
-	# strip one directory level
-	tmp = os.path.normpath(os.path.join(tmp, '..'))
-	print '  [%s] -> [%s]' % (bin, tmp)
-	# sanity check (paranoia rulez)
-	if os.path.exists(tmp):
-		return tmp
-
-	print '- application installation path [%s] not accessible' % tmp
-	print ''
-	print 'GNUmed startup: Something is really rotten here. We better'
-	print 'GNUmed startup: fail gracefully ! This may be one of those'
-	print 'GNUmed startup: cases where setting GNUMED_DIR might help.'
-
-	return None
-
-#==========================================================
-# main - launch the GNUmed wxPython GUI client
-#----------------------------------------------------------
-# set up top level exception handler
-sys.excepthook = handle_uncaught_exception
-
-setup_logging()
-
-setup_locale()
-
-# help requested ?
-if gmCLI.has_arg("--help") or gmCLI.has_arg("-h") or gmCLI.has_arg("-?"):
-	print _(
-		'Help requested\n'
-		'--------------'
-	)
-	print __doc__
-	sys.exit(0)
-
-#setup_signal_handlers()
-
-_log.Log(gmLog.lInfo, 'Starting up as main module (%s).' % __version__)
-_log.Log(gmLog.lInfo, 'command line is: %s' % str(gmCLI.arg))
-_log.Log(gmLog.lInfo, 'Python %s on %s (%s)' % (sys.version, sys.platform, os.name))
-
-setup_date_time()
-setup_cfg_file()
-
-appPath = get_base_dir()
-if appPath is None:
-	sys.exit("CRITICAL ERROR: Cannot determine base path.")
-_log.Log(gmLog.lData, "old-style resource path: %s" % appPath)
-
-resPath = get_resource_dir()
-if resPath is None:
-	sys.exit("CRITICAL ERROR: Cannot determine resouce path.")
-_log.Log(gmLog.lData, "new-style resource path: %s" % resPath)
-
-# import more of our stuff
-from Gnumed.pycommon import gmI18N, gmGuiBroker
-
-gb = gmGuiBroker.GuiBroker()
-gb['gnumed_dir'] = appPath
-gb['resource dir'] = resPath
-
-# now actually run GNUmed
-try:
-	from Gnumed.wxpython import gmGuiMain
-	# do we do profiling ?
-	if gmCLI.has_arg('--profile'):
-		profile_file = gmCLI.arg['--profile']
-		_log.Log(gmLog.lInfo, 'writing profiling data into %s' % profile_file)
-		import profile
-		profile.run('gmGuiMain.main()', profile_file)
-	else:
-		gmGuiMain.main()
-# and intercept almost all exceptions
-except StandardError:
-	exc = sys.exc_info()
-	_log.LogException ("Exception: Unhandled exception encountered.", exc, verbose=1)
-	if gmCLI.has_arg('--talkback'):
-		import gmTalkback
-		gmTalkback.run(_email_logger)
-	# but reraise them ...
-	raise
-
-# do object refcounting
-if gmCLI.has_arg('--debug'):
 	import types
 
 	def get_refcounts():
@@ -447,15 +235,105 @@ if gmCLI.has_arg('--debug'):
 #			rcfile.write('%10d %s\n' % (refcount, class_.__name__))
 	rcfile.close()
 
-# do we do talkback ?
-if gmCLI.has_arg('--talkback'):
-	import gmTalkback
-	gmTalkback.run(_email_logger)
+#==========================================================
+def check_help_request():
+	if gmCLI.has_arg("--help") or gmCLI.has_arg("-h") or gmCLI.has_arg("-?"):
+		print _(
+			'Help requested\n'
+			'--------------'
+		)
+		print __doc__
+		sys.exit(0)
+
+#==========================================================
+# main - launch the GNUmed wxPython GUI client
+#----------------------------------------------------------
+setup_console_exption_handler()
+setup_logging()
+
+from Gnumed.pycommon import gmCLI, gmI18N
+
+setup_locale()
+check_help_request()
+#setup_signal_handlers()
+
+_log.Log(gmLog.lInfo, 'Starting up as main module (%s).' % __version__)
+_log.Log(gmLog.lInfo, 'command line is: %s' % str(gmCLI.arg))
+_log.Log(gmLog.lInfo, 'Python %s on %s (%s)' % (sys.version, sys.platform, os.name))
+
+setup_paths()
+setup_date_time()
+setup_cfg_files()
+
+# import more of our stuff
+from Gnumed.pycommon import gmGuiBroker, gmHooks
+
+gmHooks.run_hook_script(hook = u'startup-before-GUI')
+
+# now actually run GNUmed
+from Gnumed.wxpython import gmGuiMain
+# do we do profiling ?
+if gmCLI.has_arg('--profile'):
+	profile_file = gmCLI.arg['--profile']
+	_log.Log(gmLog.lInfo, 'writing profiling data into %s' % profile_file)
+	import profile
+	profile.run('gmGuiMain.main()', profile_file)
+else:
+	gmGuiMain.main()
+
+gmHooks.run_hook_script(hook = u'shutdown-post-GUI')
+
+log_object_refcounts()
 
 _log.Log(gmLog.lInfo, 'Normally shutting down as main module.')
 
 #==========================================================
 # $Log: gnumed.py,v $
+# Revision 1.118  2007/05/21 14:49:42  ncq
+# - create gnumed/export/EMR/
+#
+# Revision 1.117  2007/05/08 16:07:00  ncq
+# - console exception display handler factored out
+# - cleanup
+#
+# Revision 1.116  2007/05/08 11:16:51  ncq
+# - cleanup
+#
+# Revision 1.115  2007/05/07 12:34:41  ncq
+# - better --debug docs
+# - cleanup
+# - always startup with --debug enabled
+#
+# Revision 1.114  2007/04/19 13:14:50  ncq
+# - init paths
+#
+# Revision 1.113  2007/04/11 20:47:13  ncq
+# - no more 'resource dir' and 'gnumed_dir'
+#
+# Revision 1.112  2007/03/27 10:29:49  ncq
+# - better placement for default word list
+#
+# Revision 1.111  2007/03/26 14:45:36  ncq
+# - cleanup
+# - remove --talkback handling (it will be better supported next version)
+# - create path gnumed/logs/ at startup
+#
+# Revision 1.110  2007/03/18 14:11:34  ncq
+# - a bit of clenaup/refactoring
+# - add hooks before/after GUI
+#
+# Revision 1.109  2007/03/08 11:54:18  ncq
+# - no more ~/.gnumed/user-preferences.conf
+#
+# Revision 1.108  2007/02/22 17:38:09  ncq
+# - add gnumed/export/xDT/
+#
+# Revision 1.107  2007/01/30 17:50:14  ncq
+# - improved doc string
+#
+# Revision 1.106  2007/01/30 17:41:03  ncq
+# - setup needed pathes in home dir of user at startup
+#
 # Revision 1.105  2006/12/21 17:54:43  ncq
 # - init date/time handling early on
 #
