@@ -6,7 +6,7 @@ a clean-room implementation).
 @license: GPL"""
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gui/gmConfigRegistry.py,v $
-__version__ = "$Revision: 1.40 $"
+__version__ = "$Revision: 1.41 $"
 __author__ = "H.Berger, S.Hilbert, K.Hilbert"
 
 import sys, os, string, types
@@ -521,7 +521,7 @@ else:
 
 		def GetWidget (self, parent):
 			# get current workplace name
-			workplace = gmPerson.gmCurrentProvider().get_workplace()
+			workplace = gmPerson.gmCurrentProvider().workplace
 			currUser = gmPerson.gmCurrentProvider()['db_user']
 			_log.Log (gmLog.lInfo, "ConfigReg: %s@%s" % (currUser,workplace))
 			self._widget = gmConfigEditorPanel(parent,currUser,workplace)
@@ -534,11 +534,14 @@ else:
 		"""Wrapper to load this module from an environment that wants a panel
 		"""
 		currUser = gmPerson.gmCurrentProvider()['db_user']
-		workplace = gmPerson.gmCurrentProvider().get_workplace()
+		workplace = gmPerson.gmCurrentProvider().workplace
 		return gmConfigEditorPanel(parent,currUser,workplace)
 
 #------------------------------------------------------------                   
 # $Log: gmConfigRegistry.py,v $
+# Revision 1.41  2007/02/17 14:13:11  ncq
+# - gmPerson.gmCurrentProvider().workplace now property
+#
 # Revision 1.40  2006/12/13 14:58:03  ncq
 # - a bit of cleanup
 #
