@@ -12,21 +12,20 @@ The manuals should reside where the manual_path points to.
 """
 #===========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gui/gmManual.py,v $
-# $Id: gmManual.py,v 1.36 2006/11/26 17:46:42 ncq Exp $
-__version__ = "$Revision: 1.36 $"
+# $Id: gmManual.py,v 1.40 2007/05/08 11:17:09 ncq Exp $
+__version__ = "$Revision: 1.40 $"
 __author__ = "H.Herb, I.Haywood, H.Berger, K.Hilbert"
 
-import os
+import os, sys, os.path
 
 import wx
 import wx.html
 
-from Gnumed.pycommon import gmLog, gmGuiBroker, gmI18N
+from Gnumed.pycommon import gmLog, gmTools
 from Gnumed.wxpython import gmPlugin, images_for_gnumed_browser16_16, images_gnuMedGP_Toolbar
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
-_manual_path = 'user-manual/index.html'
 
 ID_MANUALCONTENTS = wx.NewId()
 ID_MANUALBACK = wx.NewId()
@@ -53,14 +52,17 @@ class ManualHtmlPanel(wx.Panel):
 	def __init__(self, parent, frame):
 		wx.Panel.__init__(self, parent, -1)
 		self.frame = frame
+
 		# get base directory for manuals from broker
-		# Ideally this should be something like "/usr/doc/gnumed/"
-		# try standard location
-		# FIXME: this should be a) configurable, b) not hardcoded here (?)
-		if os.name == 'posix':
-			self.docdir = '/usr/share/doc/gnumed-client/user-manual/'
-		else:
-			self.docdir = os.path.join(gmGuiBroker.GuiBroker()['resource dir'], 'doc', 'user-manual')
+		paths = gmTools.cPaths(app_name = 'gnumed', wx = wx)
+		candidates = [
+			os.path.join(paths.local_base_dir, 'doc', 'user-manual'),
+			'/usr/share/doc/gnumed/user-manual/',
+			os.path.join(paths.system_app_data_dir, 'doc', 'user-manual')
+		]
+		for self.docdir in candidates:
+			if os.access(self.docdir, os.R_OK):
+				break
 
 		self.box = wx.BoxSizer(wx.VERTICAL)
 
@@ -242,6 +244,18 @@ class gmManual (gmPlugin.cNotebookPlugin):
 		wx.EVT_TOOL (tb, ID_MANUALPRINTER, widget.OnPrint) 
 #===========================================================
 # $Log: gmManual.py,v $
+# Revision 1.40  2007/05/08 11:17:09  ncq
+# - need to import gmTools
+#
+# Revision 1.39  2007/05/07 12:35:20  ncq
+# - improve use of gmTools.cPaths()
+#
+# Revision 1.38  2007/04/11 20:47:34  ncq
+# - nore more 'resource dir'
+#
+# Revision 1.37  2007/02/19 17:21:18  ncq
+# - docs are in /usr/share/doc/gnumed/
+#
 # Revision 1.36  2006/11/26 17:46:42  ncq
 # - if loading from the web use template viewprint for better results
 #
