@@ -11,7 +11,7 @@ hand it over to an appropriate viewer.
 For that it relies on proper mime type handling at the OS level.
 """
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gui/gmShowMedDocs.py,v $
-__version__ = "$Revision: 1.69 $"
+__version__ = "$Revision: 1.70 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 #================================================================
 import os.path, sys
@@ -44,7 +44,7 @@ if __name__ == '__main__':
 			# set up database connectivity
 			auth_data = gmLoginInfo.LoginInfo(
 				user = _cfg.get('database', 'user'),
-				passwd = _cfg.get('database', 'password'),
+				password = _cfg.get('database', 'password'),
 				host = _cfg.get('database', 'host'),
 				port = _cfg.get('database', 'port'),
 				database = _cfg.get('database', 'database')
@@ -229,6 +229,9 @@ if __name__ == '__main__':
 	_log.Log (gmLog.lInfo, "closing display handler")
 #================================================================
 # $Log: gmShowMedDocs.py,v $
+# Revision 1.70  2007/03/08 11:54:44  ncq
+# - cleanup
+#
 # Revision 1.69  2006/11/07 00:35:28  ncq
 # - cleanup
 #
